import { EasyField } from '../baseClasses/easyField';
import { EasyAutocompleteField } from '../factories/easyAutocompleteFieldFactory';
import { EasyAutocompleteKeyValueField } from '../factories/easyAutocompleteKeyValueFieldFactory';
import { EasyInputField } from '../factories/easyInputFieldFactory';
import { EasyRecordField } from '../factories/easyRecordFieldFactory';
import { EasyCheckboxField } from '../factories/easyCheckBoxFieldFactory';
import { EasyCheckBoxGroupField } from '../factories/easyCheckBoxGroupFieldFactory';
import { ContainerValidation } from '../services/validation.service';
import { EasyForm } from '../baseClasses/easyForm';
import { FieldOptions } from '../classes/field-options';
import { SelectOption } from '../classes/selectOption';
import { TableFieldOptions } from '../classes/table-field-options';
import { CheckboxListItem } from '../controls/easy-checkbox-group.component';
import { EasyDatePickerField } from '../factories/easyDatePickerFieldFactory';
import { EasySelectField } from '../factories/easySelectFieldFactory';
import { EasySelectKeyValueField } from '../factories/easySelectKeyValueFieldFactory';
import { EasyTableField } from '../factories/easyTableFieldFactory';
import { EasyButtonField } from '../factories/easyButtonFieldFactory';
import { EasyRadioButtonField } from '../factories/easyRadioButtonFieldFactory';
import { EasyFileUploadField } from '../factories/easyFileUploadFactory';
import { EasyDateTimePickerField } from '../factories/easyDateTimePickerFactory';
import { EasyDividerField } from '../factories/easyDividerFieldFactory';
export declare class EasyContainer extends ContainerValidation {
    header: string;
    form: EasyForm;
    useGrid: boolean;
    fields: EasyField[];
    actions: EasyField[];
    show: boolean;
    containers: EasyContainer[];
    controlType: string;
    readonly: boolean;
    xsColumnSize: string;
    smColumnSize: string;
    mdColumnSize: string;
    lgColumnSize: string;
    xlColumnSize: string;
    xsSize: string;
    smSize: string;
    mdSize: string;
    lgSize: string;
    xlSize: string;
    order: number;
    marginRight: string;
    marginLeft: string;
    paddingRight: string;
    paddingLeft: string;
    constructor(header: string, options: FieldOptions<any>, form: EasyForm, controlType: string);
    validateFields(): {
        valid: boolean;
        invalidFields: Array<EasyField>;
    };
    showContainer(): void;
    hideContainer(): void;
    protected addContainer(container: EasyContainer): void;
    getXlColumnSize(field: EasyField): string;
    getLgColumnSize(field: EasyField): string;
    getMdColumnSize(field: EasyField): string;
    getSmColumnSize(field: EasyField): string;
    getXsColumnSize(field: EasyField): string;
    addField(field: EasyField): void;
    addActionField(field: EasyField): void;
    addAutocompleteKeyValueField<T>(label: string, items: Array<SelectOption<T>>, options?: FieldOptions<T>): EasyAutocompleteKeyValueField<T>;
    addAutocompleteField<T>(label: string, items: Array<T>, options?: FieldOptions<T>): EasyAutocompleteField;
    addInputField<T>(label: string, options?: FieldOptions<T>): EasyInputField;
    addFileUploadField(label: string, options?: FieldOptions<any>): EasyFileUploadField;
    addRecordField(url: string, options?: FieldOptions<string>): EasyRecordField;
    addTextAreaField(label: string, options?: FieldOptions<string>): EasyInputField;
    addTableField(options?: TableFieldOptions): EasyTableField;
    addCheckBoxField(label: string, options?: FieldOptions<boolean>): EasyCheckboxField;
    addCheckBoxGroupField(label: string, items: Array<CheckboxListItem>, options?: FieldOptions<Array<string>>): EasyCheckBoxGroupField;
    addSelectField(label: string, items: Array<string>, options?: FieldOptions<string>): EasySelectField;
    addSelectKeyValueField<T>(label: string, items: Array<SelectOption<T>>, options?: FieldOptions<T>): EasySelectKeyValueField<T>;
    addRadioButtonField<T>(label: string, items: Array<SelectOption<T>>, options?: FieldOptions<T>): EasyRadioButtonField;
    addButtonField(label: string, action: Function, options?: FieldOptions<any>): EasyButtonField;
    addDividerField(options?: FieldOptions<any>): EasyDividerField;
    addAction(label: string, action: Function, options?: FieldOptions<any>): EasyButtonField;
    addDatePickerField(label: string, options?: FieldOptions<Date>): EasyDatePickerField;
    addDateTimePickerField(label: string, options?: FieldOptions<Date>): EasyDateTimePickerField;
    addLabelField(label: string, options?: FieldOptions<string>): EasyInputField;
    addTextLabelField(label: string, options?: FieldOptions<string>): EasyInputField;
    mapFields<T>(dto: T): void;
    mapFieldsFromDto<T>(dto: T): void;
    fetchField(key: string): EasyField;
}
export declare class ModalContainer extends EasyContainer {
    addField(field: EasyField): void;
}
