import { Injectable, Input, Component, Output, EventEmitter, Inject, NgModule, IterableDiffers, ViewEncapsulation, ElementRef, ViewChild, HostBinding, Directive } from '@angular/core';
import { FormControl, Validators, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { Subject } from 'rxjs/Rx';
import { LoaderService, HttpIntegrationService } from 'easy-core';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialog, MatSnackBar, MatSnackBarConfig, MatAutocompleteModule, MatButtonModule, MatButtonToggleModule, MatCardModule, MatCheckboxModule, MatChipsModule, MatDatepickerModule, MatDialogModule, MatExpansionModule, MatGridListModule, MatIconModule, MatInputModule, MatListModule, MatMenuModule, MatNativeDateModule, MatPaginatorModule, MatProgressBarModule, MatProgressSpinnerModule, MatRadioModule, MatRippleModule, MatSelectModule, MatSidenavModule, MatSliderModule, MatSlideToggleModule, MatSnackBarModule, MatSortModule, MatTableModule, MatTabsModule, MatToolbarModule, MatTooltipModule, MatStepperModule, MatSort, MatPaginator, DateAdapter } from '@angular/material';
import { ObservableMedia, FlexLayoutModule } from '@angular/flex-layout';
import { CdkTableModule, DataSource } from '@angular/cdk/table';
import { Subject as Subject$1 } from 'rxjs/Subject';
import { Http, ResponseContentType } from '@angular/http';
import { saveAs } from 'file-saver';
import { Observable } from 'rxjs/Observable';
import { BehaviorSubject } from 'rxjs/BehaviorSubject';
import 'rxjs/add/operator/startWith';
import 'rxjs/add/observable/merge';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/debounceTime';
import 'rxjs/add/operator/distinctUntilChanged';
import 'rxjs/add/observable/fromEvent';
import { CommonModule } from '@angular/common';
import { FileUploadModule } from 'ng2-file-upload';
import { PdfViewerModule } from 'ng2-pdf-viewer';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ValidatorService {
    /**
     * @param {?=} validators
     * @param {?=} formControl
     * @return {?}
     */
    buildValidators(validators = [], formControl) {
        let /** @type {?} */ formValidators = Array();
        for (let /** @type {?} */ validator of validators) {
            switch (validator.validatorType) {
                case ValidatorType.required:
                    formValidators.push(Validators.required);
                    break;
                case ValidatorType.maxlength:
                    formValidators.push(Validators.maxLength(validator.maxlength));
                    break;
                case ValidatorType.minlength:
                    formValidators.push(Validators.minLength(validator.minlength));
                    break;
                case ValidatorType.pattern:
                    formValidators.push(Validators.pattern(validator.pattern));
                    break;
            }
        }
        formControl.setValidators(formValidators);
    }
    /**
     * @param {?} name
     * @param {?} validators
     * @return {?}
     */
    getError(name, validators) {
        let /** @type {?} */ matchingValidators = validators.filter(x => x.validatorType == name);
        if (matchingValidators.length == 0)
            return "No message configured.";
        Validators.required;
        return matchingValidators[0].message;
    }
}
ValidatorService.decorators = [
    { type: Injectable },
];
class EasyFormComponent {
    /**
     * @param {?} validatorService
     */
    constructor(validatorService) {
        this.validatorService = validatorService;
        this.validators = [];
        this.formControl = new FormControl('', []);
    }
    /**
     * @param {?} name
     * @return {?}
     */
    getError(name) {
        return this.validatorService.getError(name, this.validators);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.readonly)
            this.formControl.disable();
        else
            this.formControl.enable();
        this.validatorService.buildValidators(this.validators, this.formControl);
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        if (changes == null || changes.options == null || changes.options.currentValue)
            return;
        this.formControl.markAsTouched();
        this.formControl.markAsDirty();
        this.formControl.updateValueAndValidity();
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        if (this.readonly)
            this.formControl.disable();
        else
            this.formControl.enable();
    }
}
EasyFormComponent.propDecorators = {
    "validators": [{ type: Input, args: ['validators',] },],
    "options": [{ type: Input, args: ['options',] },],
    "readonly": [{ type: Input, args: ['readonly',] },],
    "key": [{ type: Input, args: ['key',] },],
};
class EasyValidator {
    /**
     * @param {?} message
     * @return {?}
     */
    static Required(message) {
        return new EasyFieldValidator().requiredValidator(message);
    }
    /**
     * @param {?} length
     * @param {?} message
     * @return {?}
     */
    static MinLength(length, message) {
        return new EasyFieldValidator().minLengthValidator(length, message);
    }
    /**
     * @param {?} length
     * @param {?} message
     * @return {?}
     */
    static MaxLength(length, message) {
        return new EasyFieldValidator().maxLengthValidator(length, message);
    }
    /**
     * @param {?} pattern
     * @param {?} message
     * @return {?}
     */
    static Pattern(pattern, message) {
        return new EasyFieldValidator().patternValidator(pattern, message);
    }
    /**
     * @param {?} message
     * @return {?}
     */
    static Email(message) {
        if (message == "" || message == null)
            message = "Email is not in correct format";
        return new EasyFieldValidator().patternValidator(/^\w+([\.-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,3})+$/, message);
    }
    /**
     * @param {?} message
     * @return {?}
     */
    static TelephoneNumber(message) {
        if (message == "" || message == null)
            message = "Telephone number is not in correct format";
        return new EasyFieldValidator().patternValidator(/^[(]{0,1}[0-9]{3}[)]{0,1}[-\s\.]{0,1}[0-9]{3}[-\s\.]{0,1}[0-9]{4}$/, message);
    }
    /**
     * @param {?} message
     * @return {?}
     */
    static IdentityNumber(message) {
        if (message == "" || message == null)
            message = "Identity number is not in correct format";
        return new EasyFieldValidator().patternValidator(/^([0-9]){2}([0-1][0-9])([0-3][0-9])([0-9]){4}([0-1])([0-9]){2}?$/, message);
    }
}
class ContainerValidation {
    /**
     * @param {?} fields
     * @return {?}
     */
    validateContainerFields(fields) {
        let /** @type {?} */ invalidFields = [];
        this.validateTableFields(fields, invalidFields);
        invalidFields.addRange(fields.filter(x => !this.validateField(x)));
        return { valid: invalidFields.length == 0, invalidFields: invalidFields };
    }
    /**
     * @param {?} fields
     * @param {?} invalidFields
     * @return {?}
     */
    validateTableFields(fields, invalidFields) {
        let /** @type {?} */ tableFields = /** @type {?} */ (fields.where(x => x.controlType == "table"));
        tableFields.forEach(x => {
            x.columns.forEach(field => {
                var /** @type {?} */ validationResult = this.validateField(field);
                if (!validationResult)
                    invalidFields.add(field);
            });
        });
    }
    /**
     * @param {?} field
     * @return {?}
     */
    validateField(field) {
        let /** @type {?} */ result = true;
        if (field.value == null)
            field.value = "";
        field.value = field.value.toString().trim();
        if (field.hide) {
            result = true;
        }
        else if (!field.required && field.value == "") {
            result = true;
        }
        else if (field.easyValidators != null && field.easyValidators.any()) {
            result = this.runFieldValidation(field);
        }
        if (!result && field.easyValidators.any()) {
            field.pristine = false;
        }
        return result;
    }
    /**
     * @param {?} field
     * @return {?}
     */
    runFieldValidation(field) {
        for (let /** @type {?} */ validator of field.easyValidators) {
            switch (validator.validatorType) {
                case ValidatorType.required:
                    if (field.value == null || field.value == "" || field.value == "0")
                        return false;
                    break;
                case ValidatorType.minlength:
                    if (field.value == null || field.value.length < validator.minlength)
                        return false;
                    break;
                case ValidatorType.maxlength:
                    if (field.value == null || field.value.length > validator.maxlength)
                        return false;
                    break;
                case ValidatorType.pattern:
                    let /** @type {?} */ pattern = new RegExp(validator.pattern);
                    var /** @type {?} */ result = pattern.test(field.value);
                    if (!result)
                        return result;
                    break;
            }
        }
        return true;
    }
}
class EasyFieldValidator {
    /**
     * @param {?} message
     * @return {?}
     */
    requiredValidator(message) {
        this.validatorType = ValidatorType.required;
        this.message = message;
        return this;
    }
    /**
     * @param {?} length
     * @param {?} message
     * @return {?}
     */
    maxLengthValidator(length, message) {
        this.validatorType = ValidatorType.maxlength;
        this.maxlength = length;
        this.message = message;
        return this;
    }
    /**
     * @param {?} length
     * @param {?} message
     * @return {?}
     */
    minLengthValidator(length, message) {
        this.validatorType = ValidatorType.minlength;
        this.minlength = length;
        this.message = message;
        return this;
    }
    /**
     * @param {?} pattern
     * @param {?} message
     * @return {?}
     */
    patternValidator(pattern, message) {
        this.validatorType = ValidatorType.pattern;
        this.pattern = pattern;
        this.message = message;
        return this;
    }
}
class ValidatorType {
}
ValidatorType.required = 'required';
ValidatorType.maxlength = 'maxlength';
ValidatorType.minlength = 'minlength';
ValidatorType.pattern = 'pattern';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        this.value = "";
        this.selectedItem = "";
        this.key = "";
        this.hide = false;
        this.columnSpan = 1;
        this.validators = [];
        this.pristine = true;
        this.items = [];
        this.showPaginator = false;
        this.showFilter = false;
        this.url = "";
        this.options = {};
        this.subject = new Subject();
        this.onChange = this.subject.asObservable();
        this.options = options;
        this.type = options.type;
        this.controlType = options.controlType;
        this.value = options.value || '';
        this.key = options.key || '';
        this.label = options.label || '';
        this.required = !!options.required;
        this.order = options.order === undefined ? 1 : options.order;
        this.columnSpan = options.columnSpan || 1;
        this.xsColumnSize = options.xsColumnSize;
        this.smColumnSize = options.smColumnSize;
        this.mdColumnSize = options.mdColumnSize;
        this.lgColumnSize = options.lgColumnSize;
        this.xlColumnSize = options.xlColumnSize;
        this.hide = options.hide;
        this.readonly = options.readonly;
        this.maxLength = options.maxLength;
        this.validators = options.validators || [];
        this.updateAction = options.updateAction;
        this.skipFormValidation = options.skipFormValidation;
        this.items = options.items;
        this.action = options.action;
        this.showLoader = options.showLoader;
        this.hint = options.hint;
        this.onEnter = options.onEnter;
        this.showFilter = options.showFilter;
        this.showPaginator = options.showPaginator;
        this.url = options.url;
        this.marginLeft = options.marginLeft;
        this.marginRight = options.marginRight;
        this.format = options.format;
        this.width = options.width;
        this.minWidth = options.minWidth;
        this.maxWidth = options.maxWidth;
        this.textAlign = options.textAlign;
        this.height = options.height;
        this.minHeight = options.minHeight;
        this.maxHeight = options.maxHeight;
        this.allowedExtensions = options.allowedExtensions;
        this.addAdditionalProprtiesFromValidators();
    }
    /**
     * @return {?}
     */
    get easyValidators() {
        return this.validators;
    }
    /**
     * @param {?} validator
     * @return {?}
     */
    addValidator(validator) {
        this.validators.add(validator);
        this.addAdditionalProprtiesFromValidators();
    }
    /**
     * @return {?}
     */
    addAdditionalProprtiesFromValidators() {
        if (this.maxLength == null || this.maxLength == 0) {
            if (this.validators != null && this.validators.length > 0) {
                let /** @type {?} */ maxLengthValidator = this.validators.filter(x => x.validatorType == ValidatorType.maxlength);
                if (maxLengthValidator.length > 0)
                    this.maxLength = maxLengthValidator[0].maxlength;
            }
        }
        if (this.required) {
            let /** @type {?} */ requiredValidator = this.validators.singleOrDefault(x => x.validatorType == ValidatorType.required);
            if (requiredValidator == null)
                this.validators.add(EasyValidator.Required(this.label + " is required"));
        }
        else {
            if (this.validators.any(x => x.validatorType == ValidatorType.required))
                this.required = true;
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    valueChanged(event) {
        this.valid = event.valid;
        this.value = event.value;
        this.pristine = false;
        this.selectedItem = event.selectedItem;
        this.subject.next(/** @type {?} */ ({ value: this.value, key: this.key, valid: this.valid, selectedItem: this.selectedItem }));
    }
    /**
     * @template T
     * @param {?} dto
     * @param {?} fields
     * @return {?}
     */
    static mapFields(dto, fields) {
        Object.keys(dto).forEach(key => {
            let /** @type {?} */ field = fields.singleOrDefault(x => x.key == key);
            if (field != null)
                dto[key] = field.value;
        });
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyAutocompleteField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'autocomplete';
        options.controlType = this.controlType;
    }
    /**
     * @param {?} items
     * @return {?}
     */
    setItems(items) {
        this.items = items;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @template T
 */
class EasyAutocompleteKeyValueField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'autocomplete-key-value';
        options.controlType = this.controlType;
    }
    /**
     * @param {?} items
     * @return {?}
     */
    setItems(items) {
        this.items = items;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyInputField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'textbox';
        options.controlType = this.controlType;
        this.type = options['type'] || '';
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyRecordField extends EasyField {
    /**
     * @param {?} url
     * @param {?=} options
     */
    constructor(url, options = {}) {
        super(options);
        this.controlType = 'record';
        options.url = url;
        this.url = url;
        this.authorizationHeader = options.authorizationHeader;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyCheckboxField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'checkbox';
        options.controlType = this.controlType;
        this.type = options['type'] || '';
        this.marginLeft = options.marginLeft;
        this.marginTop = options.marginTop;
        this.marginRight = options.marginRight;
        this.marginBottom = options.marginBottom;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyCheckBoxGroupField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'checkbox-group';
        this.type = options['type'] || [];
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyDatePickerField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'date-picker';
        options.controlType = this.controlType;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasySelectField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'select';
        options.controlType = this.controlType;
    }
    /**
     * @param {?} items
     * @return {?}
     */
    setItems(items) {
        this.items = items;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @template T
 */
class EasySelectKeyValueField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'select-key-value';
        options.controlType = this.controlType;
    }
    /**
     * @param {?} items
     * @return {?}
     */
    setItems(items) {
        this.items = items;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyTableField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'table';
        this.columns = [];
        this.rows = [];
        this.actions = [];
        this.pageChangeSubject = new Subject();
        this.onPageChange = this.pageChangeSubject.asObservable();
        this.pageIndex = options.pageIndex;
        this.pageSize = options.pageSize;
        this.totalItems = options.totalItems;
    }
    /**
     * \@deprecated. Please use addAction.
     * @param {?} label
     * @param {?} action
     * @param {?=} options
     * @return {?}
     */
    addButton(label, action, options = {}) {
        options.action = action;
        options.label = label;
        this.actions.push(new EasyButtonField(options));
    }
    /**
     * @param {?} label
     * @param {?} action
     * @param {?=} options
     * @return {?}
     */
    addAction(label, action, options = {}) {
        options.action = action;
        options.label = label;
        this.actions.push(new EasyButtonField(options));
    }
    /**
     * @param {?} key
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addColumn(key, label, options = {}) {
        options.key = key;
        options.label = label;
        this.columns.push(new EasyField(options));
    }
    /**
     * @template T
     * @param {?} key
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addInputField(key, label, options = {}) {
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        let /** @type {?} */ field = new EasyInputField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} key
     * @param {?} label
     * @param {?} items
     * @param {?=} options
     * @return {?}
     */
    addSelectField(key, label, items, options = {}) {
        options.items = items;
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        let /** @type {?} */ field = new EasySelectField(options);
        this.addField(field);
        return field;
    }
    /**
     * @template T
     * @param {?} key
     * @param {?} label
     * @param {?} items
     * @param {?=} options
     * @return {?}
     */
    addAutocompleteKeyValueField(key, label, items, options = {}) {
        options.items = items;
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        let /** @type {?} */ field = new EasyAutocompleteKeyValueField(options);
        this.addField(field);
        return field;
    }
    /**
     * @template T
     * @param {?} key
     * @param {?} label
     * @param {?} items
     * @param {?=} options
     * @return {?}
     */
    addAutocompleteField(key, label, items, options = {}) {
        options.items = items;
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        let /** @type {?} */ field = new EasyAutocompleteField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} key
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addFileUploadField(key, label, options = {}) {
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        let /** @type {?} */ field = new EasyFileUploadField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} key
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addCheckboxField(key, label, options = {}) {
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        let /** @type {?} */ field = new EasyCheckboxField(options);
        this.addField(field);
        return field;
    }
    /**
     * @template T
     * @param {?} key
     * @param {?} label
     * @param {?} items
     * @param {?=} options
     * @return {?}
     */
    addSelectKeyValueField(key, label, items, options = {}) {
        options.items = items;
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        let /** @type {?} */ field = new EasySelectKeyValueField(options);
        this.addField(field);
        return field;
    }
    /**
     * @template T
     * @param {?} key
     * @param {?} label
     * @param {?} items
     * @param {?=} options
     * @return {?}
     */
    addRadioButtonField(key, label, items, options = {}) {
        options.items = items;
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        let /** @type {?} */ field = new EasyRadioButtonField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} key
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addDatePickerField(key, label, options = {}) {
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        let /** @type {?} */ field = new EasyDatePickerField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} key
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addTextLabelField(key, label, options = {}) {
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        options.readonly = true;
        let /** @type {?} */ field = new EasyInputField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} field
     * @return {?}
     */
    addField(field) {
        this.setDefaultKey(field);
        this.columns.push(field);
    }
    /**
     * @param {?} field
     * @return {?}
     */
    setDefaultKey(field) {
        if (field.key == "") {
            let /** @type {?} */ similarFields = this.columns.filter(x => x.controlType == field.controlType);
            field.key = field.controlType + "_" + similarFields.length;
        }
    }
    /**
     * @param {?} rows
     * @return {?}
     */
    setRows(rows) {
        this.rows = rows;
    }
    /**
     * @param {?} rows
     * @return {?}
     */
    addRows(rows) {
        for (let /** @type {?} */ row of rows) {
            this.rows.push(row);
        }
    }
    /**
     * @param {?} event
     * @return {?}
     */
    pageChanged(event) {
        this.pageIndex = event.pageIndex;
        this.pageSize = event.pageSize;
        this.totalItems = event.length;
        this.pageChangeSubject.next(/** @type {?} */ ({ columns: this.columns, rows: this.rows, actions: this.actions, pageIndex: this.pageIndex, pageSize: this.pageSize, totalItems: this.totalItems }));
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyButtonField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'button';
        this.action = options.action;
        this.color = options.color || '';
        this.icon = options.icon || '';
        this.type = options.type || 'mat-button';
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyTextAreaField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'textArea';
        this.type = options['type'] || '';
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyRadioButtonField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'radio-button';
        options.controlType = this.controlType;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyFileUploadField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'fileupload';
        this.key = '';
        this.icon = '';
        this.color = '';
        this.hint = '';
        this.allowedExtensions = '';
        this.type = options.type || ButtonTypes.button_icon;
        this.key = options.key || '';
        this.icon = options.icon || Icons.icon_attach_file;
        this.color = options.color || "";
        this.hint = options.hint || '';
        this.allowedExtensions = options.allowedExtensions || '';
        options.controlType = this.controlType;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyDateTimePickerField extends EasyField {
    /**
     * @param {?} options
     */
    constructor(options) {
        super(options);
        this.controlType = 'date-time-picker';
        options.controlType = this.controlType;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyDividerField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'divider';
        options.controlType = this.controlType;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyContainer extends ContainerValidation {
    /**
     * @param {?} header
     * @param {?} options
     * @param {?} form
     * @param {?} controlType
     */
    constructor(header, options, form, controlType) {
        super();
        this.header = header;
        this.useGrid = false;
        this.fields = [];
        this.actions = [];
        this.show = true;
        this.containers = [];
        this.xsColumnSize = "100%";
        this.smColumnSize = "100%";
        this.mdColumnSize = "100%";
        this.lgColumnSize = "100%";
        this.xlColumnSize = "100%";
        this.xsSize = "100%";
        this.smSize = "100%";
        this.mdSize = "100%";
        this.lgSize = "100%";
        this.xlSize = "100%";
        this.order = 0;
        this.controlType = controlType;
        this.useGrid = this.fields.filter(x => x.controlType == 'table').length == 0;
        this.form = form;
        this.order = options.order || 0;
        this.xsColumnSize = options.xsColumnSize || "100%";
        this.smColumnSize = options.smColumnSize || "100%";
        this.mdColumnSize = options.mdColumnSize || "100%";
        this.lgColumnSize = options.lgColumnSize || "100%";
        this.xlColumnSize = options.xlColumnSize || "100%";
        this.xsSize = options.xsSize || "100%";
        this.smSize = options.smSize || "100%";
        this.mdSize = options.mdSize || "100%";
        this.lgSize = options.lgSize || "100%";
        this.xlSize = options.xlSize || "100%";
        this.marginRight = options.marginRight || "";
        this.marginLeft = options.marginLeft || "";
        this.paddingLeft = options.paddingLeft || "";
        this.paddingRight = options.paddingRight || "";
        this.show = !options.hide;
    }
    /**
     * @return {?}
     */
    validateFields() {
        return super.validateContainerFields(this.fields);
    }
    /**
     * @return {?}
     */
    showContainer() {
        this.show = true;
    }
    /**
     * @return {?}
     */
    hideContainer() {
        this.show = false;
    }
    /**
     * @param {?} container
     * @return {?}
     */
    addContainer(container) {
        this.containers.add(container);
    }
    /**
     * @param {?} field
     * @return {?}
     */
    getXlColumnSize(field) {
        if (field.xlColumnSize == null || field.xlColumnSize == "")
            return this.xlColumnSize;
        return field.xlColumnSize;
    }
    /**
     * @param {?} field
     * @return {?}
     */
    getLgColumnSize(field) {
        if (field.lgColumnSize == null || field.lgColumnSize == "")
            return this.lgColumnSize;
        return field.lgColumnSize;
    }
    /**
     * @param {?} field
     * @return {?}
     */
    getMdColumnSize(field) {
        if (field.mdColumnSize == null || field.mdColumnSize == "")
            return this.mdColumnSize;
        return field.mdColumnSize;
    }
    /**
     * @param {?} field
     * @return {?}
     */
    getSmColumnSize(field) {
        if (field.smColumnSize == null || field.smColumnSize == "")
            return this.smColumnSize;
        return field.smColumnSize;
    }
    /**
     * @param {?} field
     * @return {?}
     */
    getXsColumnSize(field) {
        if (field.xsColumnSize == null || field.xsColumnSize == "")
            return this.xsColumnSize;
        return field.xsColumnSize;
    }
    /**
     * @param {?} field
     * @return {?}
     */
    addField(field) {
        this.form.setDefaultKey(field);
        this.fields.push(field);
        this.form.addField(field);
    }
    /**
     * @param {?} field
     * @return {?}
     */
    addActionField(field) {
        this.form.setDefaultKey(field);
        this.actions.push(field);
        this.form.addField(field);
    }
    /**
     * @template T
     * @param {?} label
     * @param {?} items
     * @param {?=} options
     * @return {?}
     */
    addAutocompleteKeyValueField(label, items, options = {}) {
        options.items = items;
        options.label = label;
        let /** @type {?} */ field = new EasyAutocompleteKeyValueField(options);
        this.addField(field);
        return field;
    }
    /**
     * @template T
     * @param {?} label
     * @param {?} items
     * @param {?=} options
     * @return {?}
     */
    addAutocompleteField(label, items, options = {}) {
        options.items = items;
        options.label = label;
        let /** @type {?} */ field = new EasyAutocompleteField(options);
        this.addField(field);
        return field;
    }
    /**
     * @template T
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addInputField(label, options = {}) {
        options.label = label;
        let /** @type {?} */ field = new EasyInputField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addFileUploadField(label, options = {}) {
        options.label = label;
        let /** @type {?} */ field = new EasyFileUploadField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} url
     * @param {?=} options
     * @return {?}
     */
    addRecordField(url, options = {}) {
        let /** @type {?} */ field = new EasyRecordField(url, options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addTextAreaField(label, options = {}) {
        options.label = label;
        let /** @type {?} */ field = new EasyTextAreaField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?=} options
     * @return {?}
     */
    addTableField(options = {}) {
        let /** @type {?} */ field = new EasyTableField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addCheckBoxField(label, options = {}) {
        options.label = label;
        let /** @type {?} */ field = new EasyCheckboxField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?} items
     * @param {?=} options
     * @return {?}
     */
    addCheckBoxGroupField(label, items, options = {}) {
        options.label = label;
        options.items = items;
        let /** @type {?} */ field = new EasyCheckBoxGroupField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?} items
     * @param {?=} options
     * @return {?}
     */
    addSelectField(label, items, options = {}) {
        options.items = items;
        options.label = label;
        let /** @type {?} */ field = new EasySelectField(options);
        this.addField(field);
        return field;
    }
    /**
     * @template T
     * @param {?} label
     * @param {?} items
     * @param {?=} options
     * @return {?}
     */
    addSelectKeyValueField(label, items, options = {}) {
        options.items = items;
        options.label = label;
        let /** @type {?} */ field = new EasySelectKeyValueField(options);
        this.addField(field);
        return field;
    }
    /**
     * @template T
     * @param {?} label
     * @param {?} items
     * @param {?=} options
     * @return {?}
     */
    addRadioButtonField(label, items, options = {}) {
        options.items = items;
        options.label = label;
        let /** @type {?} */ field = new EasyRadioButtonField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?} action
     * @param {?=} options
     * @return {?}
     */
    addButtonField(label, action, options = {}) {
        options.label = label;
        options.action = action;
        let /** @type {?} */ field = new EasyButtonField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?=} options
     * @return {?}
     */
    addDividerField(options = {}) {
        let /** @type {?} */ field = new EasyDividerField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?} action
     * @param {?=} options
     * @return {?}
     */
    addAction(label, action, options = {}) {
        options.label = label;
        options.action = action;
        let /** @type {?} */ field = new EasyButtonField(options);
        this.addActionField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addDatePickerField(label, options = {}) {
        options.label = label;
        let /** @type {?} */ field = new EasyDatePickerField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addDateTimePickerField(label, options = {}) {
        options.label = label;
        let /** @type {?} */ field = new EasyDateTimePickerField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addLabelField(label, options = {}) {
        options.label = label;
        options.readonly = true;
        let /** @type {?} */ field = new EasyInputField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addTextLabelField(label, options = {}) {
        options.label = label;
        options.readonly = true;
        let /** @type {?} */ field = new EasyInputField(options);
        this.addField(field);
        return field;
    }
    /**
     * @template T
     * @param {?} dto
     * @return {?}
     */
    mapFields(dto) {
        Object.keys(dto).forEach(key => {
            let /** @type {?} */ field = this.fetchField(key);
            if (field != null)
                dto[key] = field.value;
        });
    }
    /**
     * @template T
     * @param {?} dto
     * @return {?}
     */
    mapFieldsFromDto(dto) {
        Object.keys(dto).forEach(key => {
            let /** @type {?} */ field = this.fetchField(key);
            if (field != null)
                field.value = dto[key];
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    fetchField(key) {
        let /** @type {?} */ field = this.fields.singleOrDefault(x => x.key == key);
        return field;
    }
}
class ModalContainer extends EasyContainer {
    /**
     * @param {?} field
     * @return {?}
     */
    addField(field) {
        this.form.setDefaultKey(field);
        this.fields.push(field);
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyCardField extends EasyContainer {
    /**
     * @param {?} header
     * @param {?=} options
     * @param {?=} form
     */
    constructor(header, options = {}, form) {
        super(header, options, form, 'card');
        this.controlType = 'card';
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addCardContainer(header, options = {}) {
        let /** @type {?} */ container = new EasyCardField(header, options, this.form);
        this.addContainer(container);
        return container;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addTabContainer(header, options = {}) {
        let /** @type {?} */ tabs = new EasyTabField(this.form, options);
        this.addContainer(tabs);
        return tabs;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addAccordionContainer(header, options = {}) {
        let /** @type {?} */ accordion = new EasyAccordionField(this.form, options);
        this.addContainer(accordion);
        return accordion;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addExpansionPanelContainer(header, options = {}) {
        let /** @type {?} */ container = new EasyExpansionPanelField(header, options, this.form);
        this.addContainer(container);
        return container;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyAccordionField extends EasyContainer {
    /**
     * @param {?} form
     * @param {?=} options
     */
    constructor(form, options = {}) {
        super("", options, form, 'accordion');
        this.controlType = 'accordion';
        this.form = form;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addExpansionPanel(header, options = {}) {
        let /** @type {?} */ container = new EasyExpansionPanelField(header, options, this.form);
        this.containers.add(container);
        return container;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyToolbarTextField extends EasyField {
    /**
     * @param {?=} options
     */
    constructor(options = {}) {
        super(options);
        this.controlType = 'toolbar-text';
        this.color = options.color || '';
        this.icon = options.icon || '';
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyExpansionPanelField extends EasyContainer {
    /**
     * @param {?} header
     * @param {?=} options
     * @param {?=} form
     */
    constructor(header, options = {}, form) {
        super(header, options, form, 'expansion-panel');
        this.controlType = 'expansion-panel';
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addCardContainer(header, options = {}) {
        let /** @type {?} */ container = new EasyCardField(header, options, this.form);
        this.addContainer(container);
        return container;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addTabContainer(header, options = {}) {
        let /** @type {?} */ tabs = new EasyTabField(this.form, options);
        this.addContainer(tabs);
        return tabs;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addAccordionContainer(header, options = {}) {
        let /** @type {?} */ accordion = new EasyAccordionField(this.form, options);
        this.addContainer(accordion);
        return accordion;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addExpansionPanelContainer(header, options = {}) {
        let /** @type {?} */ container = new EasyExpansionPanelField(header, options, this.form);
        this.addContainer(container);
        return container;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyTabField extends EasyContainer {
    /**
     * @param {?} form
     * @param {?=} options
     */
    constructor(form, options = {}) {
        super("", options, form, 'tabs');
        this.controlType = 'tabs';
        this.form = form;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addTabToTabContainer(header, options = {}) {
        let /** @type {?} */ container = new EasyCardField(header, options, this.form);
        this.addContainer(container);
        return container;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyToolbar {
    /**
     * @param {?} form
     */
    constructor(form) {
        this.form = form;
        this.fields = [];
        this.menus = [];
    }
    /**
     * @param {?} label
     * @param {?} action
     * @param {?=} options
     * @return {?}
     */
    addButtonField(label, action, options = {}) {
        options.label = label;
        options.action = action;
        let /** @type {?} */ field = new EasyButtonField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} label
     * @param {?=} options
     * @return {?}
     */
    addTextField(label, options = {}) {
        options.label = label;
        let /** @type {?} */ field = new EasyToolbarTextField(options);
        this.addField(field);
        return field;
    }
    /**
     * @param {?} field
     * @return {?}
     */
    addField(field) {
        this.form.setDefaultKey(field);
        this.fields.push(field);
        this.form.addField(field);
    }
    /**
     * @param {?} fields
     * @return {?}
     */
    addMenu(fields) {
        this.menus.add(fields);
    }
}
class EasyToolbarContainer {
    constructor() {
        this.toolbars = [];
    }
    /**
     * @param {?} form
     * @return {?}
     */
    addToolBar(form) {
        let /** @type {?} */ toolbar = new EasyToolbar(form);
        this.toolbars.push(toolbar);
        return toolbar;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyCardField$1 extends EasyContainer {
    /**
     * @param {?} header
     * @param {?=} options
     * @param {?=} form
     */
    constructor(header, options = {}, form) {
        super(header, options, form, 'card');
        this.controlType = 'card';
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addCardContainer(header, options = {}) {
        let /** @type {?} */ container = new EasyCardField$1(header, options, this.form);
        this.addContainer(container);
        return container;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addTabContainer(header, options = {}) {
        let /** @type {?} */ tabs = new EasyTabField(this.form, options);
        this.addContainer(tabs);
        return tabs;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addAccordionContainer(header, options = {}) {
        let /** @type {?} */ accordion = new EasyAccordionField(this.form, options);
        this.addContainer(accordion);
        return accordion;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addExpansionPanelContainer(header, options = {}) {
        let /** @type {?} */ container = new EasyExpansionPanelField(header, options, this.form);
        this.addContainer(container);
        return container;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyExpansionPanelField$1 extends EasyContainer {
    /**
     * @param {?} header
     * @param {?=} options
     * @param {?=} form
     */
    constructor(header, options = {}, form) {
        super(header, options, form, 'expansion-panel');
        this.controlType = 'expansion-panel';
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addCardContainer(header, options = {}) {
        let /** @type {?} */ container = new EasyCardField(header, options, this.form);
        this.addContainer(container);
        return container;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addTabContainer(header, options = {}) {
        let /** @type {?} */ tabs = new EasyTabField(this.form, options);
        this.addContainer(tabs);
        return tabs;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addAccordionContainer(header, options = {}) {
        let /** @type {?} */ accordion = new EasyAccordionField(this.form, options);
        this.addContainer(accordion);
        return accordion;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addExpansionPanelContainer(header, options = {}) {
        let /** @type {?} */ container = new EasyExpansionPanelField$1(header, options, this.form);
        this.addContainer(container);
        return container;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyStepperField extends EasyContainer {
    /**
     * @param {?} form
     * @param {?=} options
     */
    constructor(form, options = {}) {
        super("", options, form, 'stepper');
        this.controlType = 'stepper';
        this.form = form;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addStepToStepperContainer(header, options = {}) {
        let /** @type {?} */ container = new EasyCardField(header, options, this.form);
        this.addContainer(container);
        return container;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FieldWithSameKeyAlreadyExistsException {
    /**
     * @param {?} message
     */
    constructor(message) {
        this.message = message;
    }
    /**
     * @return {?}
     */
    toString() {
        return "FieldWithSameKeyAlreadyExistsException " + this.message;
    }
}
class FieldWithKeyDoesNotExistException {
    /**
     * @param {?} message
     */
    constructor(message) {
        this.message = message;
    }
    /**
     * @return {?}
     */
    toString() {
        return "FieldWithKeyDoesNotExistException " + this.message;
    }
}
class MultipleFieldsWithSameKeyExistException {
    /**
     * @param {?} message
     */
    constructor(message) {
        this.message = message;
    }
    /**
     * @return {?}
     */
    toString() {
        return "MultipleFieldsWithSameKeyExistException " + this.message;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyForm {
    constructor() {
        this.toolbarContainers = [];
        this.containers = [];
        this.subscriptions = [];
        this.fields = [];
        this.data = {};
        this.xsSize = "100%";
        this.smSize = "100%";
        this.mdSize = "80%";
        this.lgSize = "60%";
        this.xlSize = "60%";
        this.actions = [];
        this.layout = "space-between center";
    }
    /**
     * @return {?}
     */
    getContainers() {
        return this.containers.orderBy(x => x.order);
    }
    /**
     * @param {?} size
     * @return {?}
     */
    setSize(size) {
        this.mdSize = size;
        this.lgSize = size;
        this.xlSize = size;
    }
    /**
     * @param {?} layout
     * @return {?}
     */
    setLayout(layout) {
        this.layout = layout;
    }
    /**
     * @param {?} label
     * @param {?} action
     * @param {?=} options
     * @return {?}
     */
    addAction(label, action, options = {}) {
        options.label = label;
        options.action = action;
        let /** @type {?} */ field = new EasyButtonField(options);
        this.actions.push(field);
        return field;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addCardContainer(header, options = {}) {
        let /** @type {?} */ container = new EasyCardField$1(header, options, this);
        this.addContainer(container);
        return container;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addTabContainer(header, options = {}) {
        let /** @type {?} */ tabs = new EasyTabField(this, options);
        this.addContainer(tabs);
        return tabs;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addStepperContainer(header, options = {}) {
        let /** @type {?} */ tabs = new EasyStepperField(this, options);
        this.addContainer(tabs);
        return tabs;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addAccordionContainer(header, options = {}) {
        let /** @type {?} */ accordion = new EasyAccordionField(this, options);
        this.addContainer(accordion);
        return accordion;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addExpansionPanelContainer(header, options = {}) {
        let /** @type {?} */ tabs = new EasyExpansionPanelField$1(header, options, this);
        this.addContainer(tabs);
        return tabs;
    }
    /**
     * @param {?} header
     * @param {?=} options
     * @return {?}
     */
    addModalContainer(header, options = {}) {
        let /** @type {?} */ subContainer = new ModalContainer(header, options, this, "modal");
        return subContainer;
    }
    /**
     * @return {?}
     */
    addToolBarContainer() {
        let /** @type {?} */ easyToolbarContainer = new EasyToolbarContainer();
        this.toolbarContainers.push(easyToolbarContainer);
        let /** @type {?} */ toolbar = easyToolbarContainer.addToolBar(this);
        return toolbar;
    }
    /**
     * @return {?}
     */
    validateForm() {
        let /** @type {?} */ invalidFields = this.validateContainers(this.containers);
        return { valid: invalidFields.length == 0, invalidFields: invalidFields };
    }
    /**
     * @param {?} containers
     * @return {?}
     */
    validateContainers(containers) {
        let /** @type {?} */ invalidFields = [];
        for (let /** @type {?} */ container of containers) {
            let /** @type {?} */ validationResult = container.validateFields();
            invalidFields.addRange(validationResult.invalidFields);
            invalidFields.addRange(this.validateContainers(container.containers));
        }
        return invalidFields;
    }
    /**
     * @param {?} container
     * @return {?}
     */
    addContainer(container) {
        this.containers.push(container);
        this.addSubscriptions(container.fields);
        this.addFields(container.fields);
        if (container.containers != null && container.containers.any()) {
            container.containers.forEach(x => this.addContainer(x));
        }
    }
    /**
     * @param {?} fields
     * @return {?}
     */
    addSubscriptions(fields) {
        for (let /** @type {?} */ field of fields) {
            let /** @type {?} */ subscription = field.onChange.subscribe(x => {
                this.updateField(x);
                if (this.data != null) {
                    Object.keys(this.data).forEach(key => {
                        let /** @type {?} */ field = this.fields.singleOrDefault(x => x.key == key);
                        if (field != null)
                            this.data[key] = field.value;
                    });
                }
            });
            this.subscriptions.push(subscription);
        }
    }
    /**
     * @param {?} fields
     * @return {?}
     */
    addFields(fields) {
        fields.forEach(x => this.addField(x));
    }
    /**
     * @template T
     * @param {?} dto
     * @return {?}
     */
    mapFields(dto) {
        Object.keys(dto).forEach(key => {
            let /** @type {?} */ field = this.fetchField(key);
            if (field != null)
                dto[key] = field.value;
        });
    }
    /**
     * @param {?} key
     * @return {?}
     */
    fetchField(key) {
        let /** @type {?} */ fields = this.fields.filter(x => x.key == key);
        if (fields.length > 1)
            throw new MultipleFieldsWithSameKeyExistException(key);
        if (fields.length == 0)
            return null;
        return fields[0];
    }
    /**
     * @param {?} key
     * @return {?}
     */
    fetchFieldValue(key) {
        let /** @type {?} */ fields = this.fields.filter(x => x.key == key);
        if (fields.length > 1)
            throw new MultipleFieldsWithSameKeyExistException(key);
        if (fields.length == 0)
            return null;
        return fields[0].value;
    }
    /**
     * @param {?} field
     * @return {?}
     */
    addField(field) {
        if (field.controlType == "button")
            return;
        this.checkFieldAlreadyExists(field.key);
        this.fields.push(field);
        this.addSubscription(field);
    }
    /**
     * @param {?} key
     * @return {?}
     */
    checkFieldAlreadyExists(key) {
        let /** @type {?} */ existingFields = this.fields.filter(x => x.key == key);
        if (existingFields.length > 0)
            throw new FieldWithSameKeyAlreadyExistsException(key);
    }
    /**
     * @param {?} field
     * @return {?}
     */
    addSubscription(field) {
        let /** @type {?} */ subscription = field.onChange.subscribe(x => {
            this.updateField(x);
        });
    }
    /**
     * @param {?} field
     * @return {?}
     */
    updateField(field) {
        let /** @type {?} */ fields = this.fields.filter(x => x.key == field.key);
        if (fields.length > 1)
            throw new MultipleFieldsWithSameKeyExistException(field.key);
        if (fields.length == 0)
            throw new FieldWithKeyDoesNotExistException(field.key);
        fields[0].value = field.value;
        if (fields[0].updateAction != null)
            fields[0].updateAction(field);
    }
    /**
     * @param {?} field
     * @return {?}
     */
    setDefaultKey(field) {
        if (field.key == "") {
            let /** @type {?} */ similarFields = this.fields.filter(x => x.controlType == field.controlType);
            field.key = field.controlType + "_" + similarFields.length;
        }
    }
    /**
     * @param {?} data
     * @return {?}
     */
    setData(data) {
        if (data != null) {
            this.data = data;
            Object.keys(this.data).forEach(key => {
                let /** @type {?} */ field = this.fetchField(key);
                if (field != null)
                    field.value = this.data[key];
            });
        }
    }
    /**
     * @return {?}
     */
    enableReadonlyMode() {
        this.containers.forEach(x => {
            x.readonly = true;
        });
    }
    /**
     * @return {?}
     */
    disableReadonlyMode() {
        this.containers.forEach(x => {
            x.readonly = false;
        });
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        for (let /** @type {?} */ subscription of this.subscriptions) {
            subscription.unsubscribe();
        }
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ButtonTypes {
}
ButtonTypes.button_mini_fab = 'mat-mini-fab';
ButtonTypes.button_fab = 'mat-fab';
ButtonTypes.button_raised = 'mat-raised-button';
ButtonTypes.button_flat = 'mat-button';
ButtonTypes.button_toolbar = 'mat-button-toolbar';
ButtonTypes.button_icon = 'mat-icon-button';
ButtonTypes.button_menu_item = 'mat-menu-item';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Colors {
}
Colors.color_primary = 'primary';
Colors.color_accent = 'accent';
Colors.color_warn = 'warn';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class ColumnTypes {
}
ColumnTypes.column_type_hidden = 'hidden';
ColumnTypes.column_type_date = 'date';
ColumnTypes.column_type_actions = 'actions';
ColumnTypes.column_type_control = 'control';
ColumnTypes.column_type_checkbox = 'checkbox';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class DateFormats {
}
/**
 * equivalent to 'yMMMdjms' (e.g. Sep 3, 2010, 12:05:08 PM for en-US)
 */
DateFormats.date_format_medium = 'medium';
/**
 * equivalent to 'yMdjm' (e.g. 9/3/2010, 12:05 PM for en-US)
 */
DateFormats.date_format_short = 'short';
/**
 * equivalent to 'yMMMMEEEEd' (e.g. Friday, September 3, 2010 for en-US)
 */
DateFormats.date_format_fullDate = 'fullDate';
/**
 * equivalent to 'yMMMMd' (e.g. September 3, 2010 for en-US)
 */
DateFormats.date_format_longDate = 'longDate';
/**
 * equivalent to 'yMMMd' (e.g. Sep 3, 2010 for en-US)
 */
DateFormats.date_format_mediumDate = 'mediumDate';
/**
 * equivalent to 'yMd' (e.g. 9/3/2010 for en-US)
 */
DateFormats.date_format_shortDate = 'shortDate';
/**
 * equivalent to 'jms' (e.g. 12:05:08 PM for en-US)
 */
DateFormats.date_format_mediumTime = 'mediumTime';
/**
 * equivalent to 'jm' (e.g. 12:05 PM for en-US)
 */
DateFormats.date_format_shortTime = 'shortTime';
/**
 * equivalent to 'dd/MM/yyyy' (e.g. 21/09/2014)
 */
DateFormats.date_format_ddMMyyyy = 'dd/MM/yyyy';
/**
 * equivalent to 'yyyy/MM/dd' (e.g. 2014/08-31)
 */
DateFormats.date_format_yyyyMMdd = 'yyyy/MM/dd';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @template T
 */
class FieldOptions {
    constructor() {
        this.order = 0;
        this.items = [];
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FieldChangeDto {
    /**
     * @param {?} key
     * @param {?=} value
     * @param {?=} valid
     * @param {?=} selectedItem
     */
    constructor(key, value = "", valid, selectedItem = "") {
        this.key = key;
        this.value = value;
        this.valid = valid;
        this.selectedItem = selectedItem;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FileUploadOptions {
    constructor() {
        this.hasBaseDropZoneOver = false;
        this.hasAnotherDropZoneOver = false;
        this.url = "";
        this.authToken = "";
        this.itemAlias = "";
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Icons {
}
Icons.icon_3d_rotation = '3d_rotation';
Icons.icon_ac_unit = 'ac_unit';
Icons.icon_access_alarm = 'access_alarm';
Icons.icon_access_alarms = 'access_alarms';
Icons.icon_access_time = 'access_time';
Icons.icon_accessibility = 'accessibility';
Icons.icon_accessible = 'accessible';
Icons.icon_account_balance = 'account_balance';
Icons.icon_account_balance_wallet = 'account_balance_wallet';
Icons.icon_account_box = 'account_box';
Icons.icon_account_circle = 'account_circle';
Icons.icon_adb = 'adb';
Icons.icon_add = 'add';
Icons.icon_add_a_photo = 'add_a_photo';
Icons.icon_add_alarm = 'add_alarm';
Icons.icon_add_alert = 'add_alert';
Icons.icon_add_box = 'add_box';
Icons.icon_add_circle = 'add_circle';
Icons.icon_add_circle_outline = 'add_circle_outline';
Icons.icon_add_location = 'add_location';
Icons.icon_add_shopping_cart = 'add_shopping_cart';
Icons.icon_add_to_photos = 'add_to_photos';
Icons.icon_add_to_queue = 'add_to_queue';
Icons.icon_adjust = 'adjust';
Icons.icon_airline_seat_flat = 'airline_seat_flat';
Icons.icon_airline_seat_flat_angled = 'airline_seat_flat_angled';
Icons.icon_airline_seat_individual_suite = 'airline_seat_individual_suite';
Icons.icon_airline_seat_legroom_extra = 'airline_seat_legroom_extra';
Icons.icon_airline_seat_legroom_normal = 'airline_seat_legroom_normal';
Icons.icon_airline_seat_legroom_reduced = 'airline_seat_legroom_reduced';
Icons.icon_airline_seat_recline_extra = 'airline_seat_recline_extra';
Icons.icon_airline_seat_recline_normal = 'airline_seat_recline_normal';
Icons.icon_airplanemode_active = 'airplanemode_active';
Icons.icon_airplanemode_inactive = 'airplanemode_inactive';
Icons.icon_airplay = 'airplay';
Icons.icon_airport_shuttle = 'airport_shuttle';
Icons.icon_alarm = 'alarm';
Icons.icon_alarm_add = 'alarm_add';
Icons.icon_alarm_off = 'alarm_off';
Icons.icon_alarm_on = 'alarm_on';
Icons.icon_album = 'album';
Icons.icon_all_inclusive = 'all_inclusive';
Icons.icon_all_out = 'all_out';
Icons.icon_android = 'android';
Icons.icon_announcement = 'announcement';
Icons.icon_apps = 'apps';
Icons.icon_archive = 'archive';
Icons.icon_arrow_back = 'arrow_back';
Icons.icon_arrow_downward = 'arrow_downward';
Icons.icon_arrow_drop_down = 'arrow_drop_down';
Icons.icon_arrow_drop_down_circle = 'arrow_drop_down_circle';
Icons.icon_arrow_drop_up = 'arrow_drop_up';
Icons.icon_arrow_forward = 'arrow_forward';
Icons.icon_arrow_upward = 'arrow_upward';
Icons.icon_art_track = 'art_track';
Icons.icon_aspect_ratio = 'aspect_ratio';
Icons.icon_assessment = 'assessment';
Icons.icon_assignment = 'assignment';
Icons.icon_assignment_ind = 'assignment_ind';
Icons.icon_assignment_late = 'assignment_late';
Icons.icon_assignment_return = 'assignment_return';
Icons.icon_assignment_returned = 'assignment_returned';
Icons.icon_assignment_turned_in = 'assignment_turned_in';
Icons.icon_assistant = 'assistant';
Icons.icon_assistant_photo = 'assistant_photo';
Icons.icon_attach_file = 'attach_file';
Icons.icon_attach_money = 'attach_money';
Icons.icon_attachment = 'attachment';
Icons.icon_audiotrack = 'audiotrack';
Icons.icon_autorenew = 'autorenew';
Icons.icon_av_timer = 'av_timer';
Icons.icon_backspace = 'backspace';
Icons.icon_backup = 'backup';
Icons.icon_battery_alert = 'battery_alert';
Icons.icon_battery_charging_full = 'battery_charging_full';
Icons.icon_battery_full = 'battery_full';
Icons.icon_battery_std = 'battery_std';
Icons.icon_battery_unknown = 'battery_unknown';
Icons.icon_beach_access = 'beach_access';
Icons.icon_beenhere = 'beenhere';
Icons.icon_block = 'block';
Icons.icon_bluetooth = 'bluetooth';
Icons.icon_bluetooth_audio = 'bluetooth_audio';
Icons.icon_bluetooth_connected = 'bluetooth_connected';
Icons.icon_bluetooth_disabled = 'bluetooth_disabled';
Icons.icon_bluetooth_searching = 'bluetooth_searching';
Icons.icon_blur_circular = 'blur_circular';
Icons.icon_blur_linear = 'blur_linear';
Icons.icon_blur_off = 'blur_off';
Icons.icon_blur_on = 'blur_on';
Icons.icon_book = 'book';
Icons.icon_bookmark = 'bookmark';
Icons.icon_bookmark_border = 'bookmark_border';
Icons.icon_border_all = 'border_all';
Icons.icon_border_bottom = 'border_bottom';
Icons.icon_border_clear = 'border_clear';
Icons.icon_border_color = 'border_color';
Icons.icon_border_horizontal = 'border_horizontal';
Icons.icon_border_inner = 'border_inner';
Icons.icon_border_left = 'border_left';
Icons.icon_border_outer = 'border_outer';
Icons.icon_border_right = 'border_right';
Icons.icon_border_style = 'border_style';
Icons.icon_border_top = 'border_top';
Icons.icon_border_vertical = 'border_vertical';
Icons.icon_branding_watermark = 'branding_watermark';
Icons.icon_brightness_1 = 'brightness_1';
Icons.icon_brightness_2 = 'brightness_2';
Icons.icon_brightness_3 = 'brightness_3';
Icons.icon_brightness_4 = 'brightness_4';
Icons.icon_brightness_5 = 'brightness_5';
Icons.icon_brightness_6 = 'brightness_6';
Icons.icon_brightness_7 = 'brightness_7';
Icons.icon_brightness_auto = 'brightness_auto';
Icons.icon_brightness_high = 'brightness_high';
Icons.icon_brightness_low = 'brightness_low';
Icons.icon_brightness_medium = 'brightness_medium';
Icons.icon_broken_image = 'broken_image';
Icons.icon_brush = 'brush';
Icons.icon_bubble_chart = 'bubble_chart';
Icons.icon_bug_report = 'bug_report';
Icons.icon_build = 'build';
Icons.icon_burst_mode = 'burst_mode';
Icons.icon_business = 'business';
Icons.icon_business_center = 'business_center';
Icons.icon_cached = 'cached';
Icons.icon_cake = 'cake';
Icons.icon_call = 'call';
Icons.icon_call_end = 'call_end';
Icons.icon_call_made = 'call_made';
Icons.icon_call_merge = 'call_merge';
Icons.icon_call_missed = 'call_missed';
Icons.icon_call_missed_outgoing = 'call_missed_outgoing';
Icons.icon_call_received = 'call_received';
Icons.icon_call_split = 'call_split';
Icons.icon_call_to_action = 'call_to_action';
Icons.icon_camera = 'camera';
Icons.icon_camera_alt = 'camera_alt';
Icons.icon_camera_enhance = 'camera_enhance';
Icons.icon_camera_front = 'camera_front';
Icons.icon_camera_rear = 'camera_rear';
Icons.icon_camera_roll = 'camera_roll';
Icons.icon_cancel = 'cancel';
Icons.icon_card_giftcard = 'card_giftcard';
Icons.icon_card_membership = 'card_membership';
Icons.icon_card_travel = 'card_travel';
Icons.icon_casino = 'casino';
Icons.icon_cast = 'cast';
Icons.icon_cast_connected = 'cast_connected';
Icons.icon_center_focus_strong = 'center_focus_strong';
Icons.icon_center_focus_weak = 'center_focus_weak';
Icons.icon_change_history = 'change_history';
Icons.icon_chat = 'chat';
Icons.icon_chat_bubble = 'chat_bubble';
Icons.icon_chat_bubble_outline = 'chat_bubble_outline';
Icons.icon_check = 'check';
Icons.icon_check_box = 'check_box';
Icons.icon_check_box_outline_blank = 'check_box_outline_blank';
Icons.icon_check_circle = 'check_circle';
Icons.icon_chevron_left = 'chevron_left';
Icons.icon_chevron_right = 'chevron_right';
Icons.icon_child_care = 'child_care';
Icons.icon_child_friendly = 'child_friendly';
Icons.icon_chrome_reader_mode = 'chrome_reader_mode';
Icons.icon_class = 'class';
Icons.icon_clear = 'clear';
Icons.icon_clear_all = 'clear_all';
Icons.icon_close = 'close';
Icons.icon_closed_caption = 'closed_caption';
Icons.icon_cloud = 'cloud';
Icons.icon_cloud_circle = 'cloud_circle';
Icons.icon_cloud_done = 'cloud_done';
Icons.icon_cloud_download = 'cloud_download';
Icons.icon_cloud_off = 'cloud_off';
Icons.icon_cloud_queue = 'cloud_queue';
Icons.icon_cloud_upload = 'cloud_upload';
Icons.icon_code = 'code';
Icons.icon_collections = 'collections';
Icons.icon_collections_bookmark = 'collections_bookmark';
Icons.icon_color_lens = 'color_lens';
Icons.icon_colorize = 'colorize';
Icons.icon_comment = 'comment';
Icons.icon_compare = 'compare';
Icons.icon_compare_arrows = 'compare_arrows';
Icons.icon_computer = 'computer';
Icons.icon_confirmation_number = 'confirmation_number';
Icons.icon_contact_mail = 'contact_mail';
Icons.icon_contact_phone = 'contact_phone';
Icons.icon_contacts = 'contacts';
Icons.icon_content_copy = 'content_copy';
Icons.icon_content_cut = 'content_cut';
Icons.icon_content_paste = 'content_paste';
Icons.icon_control_point = 'control_point';
Icons.icon_control_point_duplicate = 'control_point_duplicate';
Icons.icon_copyright = 'copyright';
Icons.icon_create = 'create';
Icons.icon_create_new_folder = 'create_new_folder';
Icons.icon_credit_card = 'credit_card';
Icons.icon_crop = 'crop';
Icons.icon_crop_16_9 = 'crop_16_9';
Icons.icon_crop_3_2 = 'crop_3_2';
Icons.icon_crop_5_4 = 'crop_5_4';
Icons.icon_crop_7_5 = 'crop_7_5';
Icons.icon_crop_din = 'crop_din';
Icons.icon_crop_free = 'crop_free';
Icons.icon_crop_landscape = 'crop_landscape';
Icons.icon_crop_original = 'crop_original';
Icons.icon_crop_portrait = 'crop_portrait';
Icons.icon_crop_rotate = 'crop_rotate';
Icons.icon_crop_square = 'crop_square';
Icons.icon_dashboard = 'dashboard';
Icons.icon_data_usage = 'data_usage';
Icons.icon_date_range = 'date_range';
Icons.icon_dehaze = 'dehaze';
Icons.icon_delete = 'delete';
Icons.icon_delete_forever = 'delete_forever';
Icons.icon_delete_sweep = 'delete_sweep';
Icons.icon_description = 'description';
Icons.icon_desktop_mac = 'desktop_mac';
Icons.icon_desktop_windows = 'desktop_windows';
Icons.icon_details = 'details';
Icons.icon_developer_board = 'developer_board';
Icons.icon_developer_mode = 'developer_mode';
Icons.icon_device_hub = 'device_hub';
Icons.icon_devices = 'devices';
Icons.icon_devices_other = 'devices_other';
Icons.icon_dialer_sip = 'dialer_sip';
Icons.icon_dialpad = 'dialpad';
Icons.icon_directions = 'directions';
Icons.icon_directions_bike = 'directions_bike';
Icons.icon_directions_boat = 'directions_boat';
Icons.icon_directions_bus = 'directions_bus';
Icons.icon_directions_car = 'directions_car';
Icons.icon_directions_railway = 'directions_railway';
Icons.icon_directions_run = 'directions_run';
Icons.icon_directions_subway = 'directions_subway';
Icons.icon_directions_transit = 'directions_transit';
Icons.icon_directions_walk = 'directions_walk';
Icons.icon_disc_full = 'disc_full';
Icons.icon_dns = 'dns';
Icons.icon_do_not_disturb = 'do_not_disturb';
Icons.icon_do_not_disturb_alt = 'do_not_disturb_alt';
Icons.icon_do_not_disturb_off = 'do_not_disturb_off';
Icons.icon_do_not_disturb_on = 'do_not_disturb_on';
Icons.icon_dock = 'dock';
Icons.icon_domain = 'domain';
Icons.icon_done = 'done';
Icons.icon_done_all = 'done_all';
Icons.icon_donut_large = 'donut_large';
Icons.icon_donut_small = 'donut_small';
Icons.icon_drafts = 'drafts';
Icons.icon_drag_handle = 'drag_handle';
Icons.icon_drive_eta = 'drive_eta';
Icons.icon_dvr = 'dvr';
Icons.icon_edit = 'edit';
Icons.icon_edit_location = 'edit_location';
Icons.icon_eject = 'eject';
Icons.icon_email = 'email';
Icons.icon_enhanced_encryption = 'enhanced_encryption';
Icons.icon_equalizer = 'equalizer';
Icons.icon_error = 'error';
Icons.icon_error_outline = 'error_outline';
Icons.icon_euro_symbol = 'euro_symbol';
Icons.icon_ev_station = 'ev_station';
Icons.icon_event = 'event';
Icons.icon_event_available = 'event_available';
Icons.icon_event_busy = 'event_busy';
Icons.icon_event_note = 'event_note';
Icons.icon_event_seat = 'event_seat';
Icons.icon_exit_to_app = 'exit_to_app';
Icons.icon_expand_less = 'expand_less';
Icons.icon_expand_more = 'expand_more';
Icons.icon_explicit = 'explicit';
Icons.icon_explore = 'explore';
Icons.icon_exposure = 'exposure';
Icons.icon_exposure_neg_1 = 'exposure_neg_1';
Icons.icon_exposure_neg_2 = 'exposure_neg_2';
Icons.icon_exposure_plus_1 = 'exposure_plus_1';
Icons.icon_exposure_plus_2 = 'exposure_plus_2';
Icons.icon_exposure_zero = 'exposure_zero';
Icons.icon_extension = 'extension';
Icons.icon_face = 'face';
Icons.icon_fast_forward = 'fast_forward';
Icons.icon_fast_rewind = 'fast_rewind';
Icons.icon_favorite = 'favorite';
Icons.icon_favorite_border = 'favorite_border';
Icons.icon_featured_play_list = 'featured_play_list';
Icons.icon_featured_video = 'featured_video';
Icons.icon_feedback = 'feedback';
Icons.icon_fiber_dvr = 'fiber_dvr';
Icons.icon_fiber_manual_record = 'fiber_manual_record';
Icons.icon_fiber_new = 'fiber_new';
Icons.icon_fiber_pin = 'fiber_pin';
Icons.icon_fiber_smart_record = 'fiber_smart_record';
Icons.icon_file_download = 'file_download';
Icons.icon_file_upload = 'file_upload';
Icons.icon_filter = 'filter';
Icons.icon_filter_1 = 'filter_1';
Icons.icon_filter_2 = 'filter_2';
Icons.icon_filter_3 = 'filter_3';
Icons.icon_filter_4 = 'filter_4';
Icons.icon_filter_5 = 'filter_5';
Icons.icon_filter_6 = 'filter_6';
Icons.icon_filter_7 = 'filter_7';
Icons.icon_filter_8 = 'filter_8';
Icons.icon_filter_9 = 'filter_9';
Icons.icon_filter_9_plus = 'filter_9_plus';
Icons.icon_filter_b_and_w = 'filter_b_and_w';
Icons.icon_filter_center_focus = 'filter_center_focus';
Icons.icon_filter_drama = 'filter_drama';
Icons.icon_filter_frames = 'filter_frames';
Icons.icon_filter_hdr = 'filter_hdr';
Icons.icon_filter_list = 'filter_list';
Icons.icon_filter_none = 'filter_none';
Icons.icon_filter_tilt_shift = 'filter_tilt_shift';
Icons.icon_filter_vintage = 'filter_vintage';
Icons.icon_find_in_page = 'find_in_page';
Icons.icon_find_replace = 'find_replace';
Icons.icon_fingerprint = 'fingerprint';
Icons.icon_first_page = 'first_page';
Icons.icon_fitness_center = 'fitness_center';
Icons.icon_flag = 'flag';
Icons.icon_flare = 'flare';
Icons.icon_flash_auto = 'flash_auto';
Icons.icon_flash_off = 'flash_off';
Icons.icon_flash_on = 'flash_on';
Icons.icon_flight = 'flight';
Icons.icon_flight_land = 'flight_land';
Icons.icon_flight_takeoff = 'flight_takeoff';
Icons.icon_flip = 'flip';
Icons.icon_flip_to_back = 'flip_to_back';
Icons.icon_flip_to_front = 'flip_to_front';
Icons.icon_folder = 'folder';
Icons.icon_folder_open = 'folder_open';
Icons.icon_folder_shared = 'folder_shared';
Icons.icon_folder_special = 'folder_special';
Icons.icon_font_download = 'font_download';
Icons.icon_format_align_center = 'format_align_center';
Icons.icon_format_align_justify = 'format_align_justify';
Icons.icon_format_align_left = 'format_align_left';
Icons.icon_format_align_right = 'format_align_right';
Icons.icon_format_bold = 'format_bold';
Icons.icon_format_clear = 'format_clear';
Icons.icon_format_color_fill = 'format_color_fill';
Icons.icon_format_color_reset = 'format_color_reset';
Icons.icon_format_color_text = 'format_color_text';
Icons.icon_format_indent_decrease = 'format_indent_decrease';
Icons.icon_format_indent_increase = 'format_indent_increase';
Icons.icon_format_italic = 'format_italic';
Icons.icon_format_line_spacing = 'format_line_spacing';
Icons.icon_format_list_bulleted = 'format_list_bulleted';
Icons.icon_format_list_numbered = 'format_list_numbered';
Icons.icon_format_paint = 'format_paint';
Icons.icon_format_quote = 'format_quote';
Icons.icon_format_shapes = 'format_shapes';
Icons.icon_format_size = 'format_size';
Icons.icon_format_strikethrough = 'format_strikethrough';
Icons.icon_format_textdirection_l_to_r = 'format_textdirection_l_to_r';
Icons.icon_format_textdirection_r_to_l = 'format_textdirection_r_to_l';
Icons.icon_format_underlined = 'format_underlined';
Icons.icon_forum = 'forum';
Icons.icon_forward = 'forward';
Icons.icon_forward_10 = 'forward_10';
Icons.icon_forward_30 = 'forward_30';
Icons.icon_forward_5 = 'forward_5';
Icons.icon_free_breakfast = 'free_breakfast';
Icons.icon_fullscreen = 'fullscreen';
Icons.icon_fullscreen_exit = 'fullscreen_exit';
Icons.icon_functions = 'functions';
Icons.icon_g_translate = 'g_translate';
Icons.icon_gamepad = 'gamepad';
Icons.icon_games = 'games';
Icons.icon_gavel = 'gavel';
Icons.icon_gesture = 'gesture';
Icons.icon_get_app = 'get_app';
Icons.icon_gif = 'gif';
Icons.icon_golf_course = 'golf_course';
Icons.icon_gps_fixed = 'gps_fixed';
Icons.icon_gps_not_fixed = 'gps_not_fixed';
Icons.icon_gps_off = 'gps_off';
Icons.icon_grade = 'grade';
Icons.icon_gradient = 'gradient';
Icons.icon_grain = 'grain';
Icons.icon_graphic_eq = 'graphic_eq';
Icons.icon_grid_off = 'grid_off';
Icons.icon_grid_on = 'grid_on';
Icons.icon_group = 'group';
Icons.icon_group_add = 'group_add';
Icons.icon_group_work = 'group_work';
Icons.icon_hd = 'hd';
Icons.icon_hdr_off = 'hdr_off';
Icons.icon_hdr_on = 'hdr_on';
Icons.icon_hdr_strong = 'hdr_strong';
Icons.icon_hdr_weak = 'hdr_weak';
Icons.icon_headset = 'headset';
Icons.icon_headset_mic = 'headset_mic';
Icons.icon_healing = 'healing';
Icons.icon_hearing = 'hearing';
Icons.icon_help = 'help';
Icons.icon_help_outline = 'help_outline';
Icons.icon_high_quality = 'high_quality';
Icons.icon_highlight = 'highlight';
Icons.icon_highlight_off = 'highlight_off';
Icons.icon_history = 'history';
Icons.icon_home = 'home';
Icons.icon_hot_tub = 'hot_tub';
Icons.icon_hotel = 'hotel';
Icons.icon_hourglass_empty = 'hourglass_empty';
Icons.icon_hourglass_full = 'hourglass_full';
Icons.icon_http = 'http';
Icons.icon_https = 'https';
Icons.icon_image = 'image';
Icons.icon_image_aspect_ratio = 'image_aspect_ratio';
Icons.icon_import_contacts = 'import_contacts';
Icons.icon_import_export = 'import_export';
Icons.icon_important_devices = 'important_devices';
Icons.icon_inbox = 'inbox';
Icons.icon_indeterminate_check_box = 'indeterminate_check_box';
Icons.icon_info = 'info';
Icons.icon_info_outline = 'info_outline';
Icons.icon_input = 'input';
Icons.icon_insert_chart = 'insert_chart';
Icons.icon_insert_comment = 'insert_comment';
Icons.icon_insert_drive_file = 'insert_drive_file';
Icons.icon_insert_emoticon = 'insert_emoticon';
Icons.icon_insert_invitation = 'insert_invitation';
Icons.icon_insert_link = 'insert_link';
Icons.icon_insert_photo = 'insert_photo';
Icons.icon_invert_colors = 'invert_colors';
Icons.icon_invert_colors_off = 'invert_colors_off';
Icons.icon_iso = 'iso';
Icons.icon_keyboard = 'keyboard';
Icons.icon_keyboard_arrow_down = 'keyboard_arrow_down';
Icons.icon_keyboard_arrow_left = 'keyboard_arrow_left';
Icons.icon_keyboard_arrow_right = 'keyboard_arrow_right';
Icons.icon_keyboard_arrow_up = 'keyboard_arrow_up';
Icons.icon_keyboard_backspace = 'keyboard_backspace';
Icons.icon_keyboard_capslock = 'keyboard_capslock';
Icons.icon_keyboard_hide = 'keyboard_hide';
Icons.icon_keyboard_return = 'keyboard_return';
Icons.icon_keyboard_tab = 'keyboard_tab';
Icons.icon_keyboard_voice = 'keyboard_voice';
Icons.icon_kitchen = 'kitchen';
Icons.icon_label = 'label';
Icons.icon_label_outline = 'label_outline';
Icons.icon_landscape = 'landscape';
Icons.icon_language = 'language';
Icons.icon_laptop = 'laptop';
Icons.icon_laptop_chromebook = 'laptop_chromebook';
Icons.icon_laptop_mac = 'laptop_mac';
Icons.icon_laptop_windows = 'laptop_windows';
Icons.icon_last_page = 'last_page';
Icons.icon_launch = 'launch';
Icons.icon_layers = 'layers';
Icons.icon_layers_clear = 'layers_clear';
Icons.icon_leak_add = 'leak_add';
Icons.icon_leak_remove = 'leak_remove';
Icons.icon_lens = 'lens';
Icons.icon_library_add = 'library_add';
Icons.icon_library_books = 'library_books';
Icons.icon_library_music = 'library_music';
Icons.icon_lightbulb_outline = 'lightbulb_outline';
Icons.icon_line_style = 'line_style';
Icons.icon_line_weight = 'line_weight';
Icons.icon_linear_scale = 'linear_scale';
Icons.icon_link = 'link';
Icons.icon_linked_camera = 'linked_camera';
Icons.icon_list = 'list';
Icons.icon_live_help = 'live_help';
Icons.icon_live_tv = 'live_tv';
Icons.icon_local_activity = 'local_activity';
Icons.icon_local_airport = 'local_airport';
Icons.icon_local_atm = 'local_atm';
Icons.icon_local_bar = 'local_bar';
Icons.icon_local_cafe = 'local_cafe';
Icons.icon_local_car_wash = 'local_car_wash';
Icons.icon_local_convenience_store = 'local_convenience_store';
Icons.icon_local_dining = 'local_dining';
Icons.icon_local_drink = 'local_drink';
Icons.icon_local_florist = 'local_florist';
Icons.icon_local_gas_station = 'local_gas_station';
Icons.icon_local_grocery_store = 'local_grocery_store';
Icons.icon_local_hospital = 'local_hospital';
Icons.icon_local_hotel = 'local_hotel';
Icons.icon_local_laundry_service = 'local_laundry_service';
Icons.icon_local_library = 'local_library';
Icons.icon_local_mall = 'local_mall';
Icons.icon_local_movies = 'local_movies';
Icons.icon_local_offer = 'local_offer';
Icons.icon_local_parking = 'local_parking';
Icons.icon_local_pharmacy = 'local_pharmacy';
Icons.icon_local_phone = 'local_phone';
Icons.icon_local_pizza = 'local_pizza';
Icons.icon_local_play = 'local_play';
Icons.icon_local_post_office = 'local_post_office';
Icons.icon_local_printshop = 'local_printshop';
Icons.icon_local_see = 'local_see';
Icons.icon_local_shipping = 'local_shipping';
Icons.icon_local_taxi = 'local_taxi';
Icons.icon_location_city = 'location_city';
Icons.icon_location_disabled = 'location_disabled';
Icons.icon_location_off = 'location_off';
Icons.icon_location_on = 'location_on';
Icons.icon_location_searching = 'location_searching';
Icons.icon_lock = 'lock';
Icons.icon_lock_open = 'lock_open';
Icons.icon_lock_outline = 'lock_outline';
Icons.icon_looks = 'looks';
Icons.icon_looks_3 = 'looks_3';
Icons.icon_looks_4 = 'looks_4';
Icons.icon_looks_5 = 'looks_5';
Icons.icon_looks_6 = 'looks_6';
Icons.icon_looks_one = 'looks_one';
Icons.icon_looks_two = 'looks_two';
Icons.icon_loop = 'loop';
Icons.icon_loupe = 'loupe';
Icons.icon_low_priority = 'low_priority';
Icons.icon_loyalty = 'loyalty';
Icons.icon_mail = 'mail';
Icons.icon_mail_outline = 'mail_outline';
Icons.icon_map = 'map';
Icons.icon_markunread = 'markunread';
Icons.icon_markunread_mailbox = 'markunread_mailbox';
Icons.icon_memory = 'memory';
Icons.icon_menu = 'menu';
Icons.icon_merge_type = 'merge_type';
Icons.icon_message = 'message';
Icons.icon_mic = 'mic';
Icons.icon_mic_none = 'mic_none';
Icons.icon_mic_off = 'mic_off';
Icons.icon_mms = 'mms';
Icons.icon_mode_comment = 'mode_comment';
Icons.icon_mode_edit = 'mode_edit';
Icons.icon_monetization_on = 'monetization_on';
Icons.icon_money_off = 'money_off';
Icons.icon_monochrome_photos = 'monochrome_photos';
Icons.icon_mood = 'mood';
Icons.icon_mood_bad = 'mood_bad';
Icons.icon_more = 'more';
Icons.icon_more_horiz = 'more_horiz';
Icons.icon_more_vert = 'more_vert';
Icons.icon_motorcycle = 'motorcycle';
Icons.icon_mouse = 'mouse';
Icons.icon_move_to_inbox = 'move_to_inbox';
Icons.icon_movie = 'movie';
Icons.icon_movie_creation = 'movie_creation';
Icons.icon_movie_filter = 'movie_filter';
Icons.icon_multiline_chart = 'multiline_chart';
Icons.icon_music_note = 'music_note';
Icons.icon_music_video = 'music_video';
Icons.icon_my_location = 'my_location';
Icons.icon_nature = 'nature';
Icons.icon_nature_people = 'nature_people';
Icons.icon_navigate_before = 'navigate_before';
Icons.icon_navigate_next = 'navigate_next';
Icons.icon_navigation = 'navigation';
Icons.icon_near_me = 'near_me';
Icons.icon_network_cell = 'network_cell';
Icons.icon_network_check = 'network_check';
Icons.icon_network_locked = 'network_locked';
Icons.icon_network_wifi = 'network_wifi';
Icons.icon_new_releases = 'new_releases';
Icons.icon_next_week = 'next_week';
Icons.icon_nfc = 'nfc';
Icons.icon_no_encryption = 'no_encryption';
Icons.icon_no_sim = 'no_sim';
Icons.icon_not_interested = 'not_interested';
Icons.icon_note = 'note';
Icons.icon_note_add = 'note_add';
Icons.icon_notifications = 'notifications';
Icons.icon_notifications_active = 'notifications_active';
Icons.icon_notifications_none = 'notifications_none';
Icons.icon_notifications_off = 'notifications_off';
Icons.icon_notifications_paused = 'notifications_paused';
Icons.icon_offline_pin = 'offline_pin';
Icons.icon_ondemand_video = 'ondemand_video';
Icons.icon_opacity = 'opacity';
Icons.icon_open_in_browser = 'open_in_browser';
Icons.icon_open_in_new = 'open_in_new';
Icons.icon_open_with = 'open_with';
Icons.icon_pages = 'pages';
Icons.icon_pageview = 'pageview';
Icons.icon_palette = 'palette';
Icons.icon_pan_tool = 'pan_tool';
Icons.icon_panorama = 'panorama';
Icons.icon_panorama_fish_eye = 'panorama_fish_eye';
Icons.icon_panorama_horizontal = 'panorama_horizontal';
Icons.icon_panorama_vertical = 'panorama_vertical';
Icons.icon_panorama_wide_angle = 'panorama_wide_angle';
Icons.icon_party_mode = 'party_mode';
Icons.icon_pause = 'pause';
Icons.icon_pause_circle_filled = 'pause_circle_filled';
Icons.icon_pause_circle_outline = 'pause_circle_outline';
Icons.icon_payment = 'payment';
Icons.icon_people = 'people';
Icons.icon_people_outline = 'people_outline';
Icons.icon_perm_camera_mic = 'perm_camera_mic';
Icons.icon_perm_contact_calendar = 'perm_contact_calendar';
Icons.icon_perm_data_setting = 'perm_data_setting';
Icons.icon_perm_device_information = 'perm_device_information';
Icons.icon_perm_identity = 'perm_identity';
Icons.icon_perm_media = 'perm_media';
Icons.icon_perm_phone_msg = 'perm_phone_msg';
Icons.icon_perm_scan_wifi = 'perm_scan_wifi';
Icons.icon_person = 'person';
Icons.icon_person_add = 'person_add';
Icons.icon_person_outline = 'person_outline';
Icons.icon_person_pin = 'person_pin';
Icons.icon_person_pin_circle = 'person_pin_circle';
Icons.icon_personal_video = 'personal_video';
Icons.icon_pets = 'pets';
Icons.icon_phone = 'phone';
Icons.icon_phone_android = 'phone_android';
Icons.icon_phone_bluetooth_speaker = 'phone_bluetooth_speaker';
Icons.icon_phone_forwarded = 'phone_forwarded';
Icons.icon_phone_in_talk = 'phone_in_talk';
Icons.icon_phone_iphone = 'phone_iphone';
Icons.icon_phone_locked = 'phone_locked';
Icons.icon_phone_missed = 'phone_missed';
Icons.icon_phone_paused = 'phone_paused';
Icons.icon_phonelink = 'phonelink';
Icons.icon_phonelink_erase = 'phonelink_erase';
Icons.icon_phonelink_lock = 'phonelink_lock';
Icons.icon_phonelink_off = 'phonelink_off';
Icons.icon_phonelink_ring = 'phonelink_ring';
Icons.icon_phonelink_setup = 'phonelink_setup';
Icons.icon_photo = 'photo';
Icons.icon_photo_album = 'photo_album';
Icons.icon_photo_camera = 'photo_camera';
Icons.icon_photo_filter = 'photo_filter';
Icons.icon_photo_library = 'photo_library';
Icons.icon_photo_size_select_actual = 'photo_size_select_actual';
Icons.icon_photo_size_select_large = 'photo_size_select_large';
Icons.icon_photo_size_select_small = 'photo_size_select_small';
Icons.icon_picture_as_pdf = 'picture_as_pdf';
Icons.icon_picture_in_picture = 'picture_in_picture';
Icons.icon_picture_in_picture_alt = 'picture_in_picture_alt';
Icons.icon_pie_chart = 'pie_chart';
Icons.icon_pie_chart_outlined = 'pie_chart_outlined';
Icons.icon_pin_drop = 'pin_drop';
Icons.icon_place = 'place';
Icons.icon_play_arrow = 'play_arrow';
Icons.icon_play_circle_filled = 'play_circle_filled';
Icons.icon_play_circle_outline = 'play_circle_outline';
Icons.icon_play_for_work = 'play_for_work';
Icons.icon_playlist_add = 'playlist_add';
Icons.icon_playlist_add_check = 'playlist_add_check';
Icons.icon_playlist_play = 'playlist_play';
Icons.icon_plus_one = 'plus_one';
Icons.icon_poll = 'poll';
Icons.icon_polymer = 'polymer';
Icons.icon_pool = 'pool';
Icons.icon_portable_wifi_off = 'portable_wifi_off';
Icons.icon_portrait = 'portrait';
Icons.icon_power = 'power';
Icons.icon_power_input = 'power_input';
Icons.icon_power_settings_new = 'power_settings_new';
Icons.icon_pregnant_woman = 'pregnant_woman';
Icons.icon_present_to_all = 'present_to_all';
Icons.icon_print = 'print';
Icons.icon_priority_high = 'priority_high';
Icons.icon_public = 'public';
Icons.icon_publish = 'publish';
Icons.icon_query_builder = 'query_builder';
Icons.icon_question_answer = 'question_answer';
Icons.icon_queue = 'queue';
Icons.icon_queue_music = 'queue_music';
Icons.icon_queue_play_next = 'queue_play_next';
Icons.icon_radio = 'radio';
Icons.icon_radio_button_checked = 'radio_button_checked';
Icons.icon_radio_button_unchecked = 'radio_button_unchecked';
Icons.icon_rate_review = 'rate_review';
Icons.icon_receipt = 'receipt';
Icons.icon_recent_actors = 'recent_actors';
Icons.icon_record_voice_over = 'record_voice_over';
Icons.icon_redeem = 'redeem';
Icons.icon_redo = 'redo';
Icons.icon_refresh = 'refresh';
Icons.icon_remove = 'remove';
Icons.icon_remove_circle = 'remove_circle';
Icons.icon_remove_circle_outline = 'remove_circle_outline';
Icons.icon_remove_from_queue = 'remove_from_queue';
Icons.icon_remove_red_eye = 'remove_red_eye';
Icons.icon_remove_shopping_cart = 'remove_shopping_cart';
Icons.icon_reorder = 'reorder';
Icons.icon_repeat = 'repeat';
Icons.icon_repeat_one = 'repeat_one';
Icons.icon_replay = 'replay';
Icons.icon_replay_10 = 'replay_10';
Icons.icon_replay_30 = 'replay_30';
Icons.icon_replay_5 = 'replay_5';
Icons.icon_reply = 'reply';
Icons.icon_reply_all = 'reply_all';
Icons.icon_report = 'report';
Icons.icon_report_problem = 'report_problem';
Icons.icon_restaurant = 'restaurant';
Icons.icon_restaurant_menu = 'restaurant_menu';
Icons.icon_restore = 'restore';
Icons.icon_restore_page = 'restore_page';
Icons.icon_ring_volume = 'ring_volume';
Icons.icon_room = 'room';
Icons.icon_room_service = 'room_service';
Icons.icon_rotate_90_degrees_ccw = 'rotate_90_degrees_ccw';
Icons.icon_rotate_left = 'rotate_left';
Icons.icon_rotate_right = 'rotate_right';
Icons.icon_rounded_corner = 'rounded_corner';
Icons.icon_router = 'router';
Icons.icon_rowing = 'rowing';
Icons.icon_rss_feed = 'rss_feed';
Icons.icon_rv_hookup = 'rv_hookup';
Icons.icon_satellite = 'satellite';
Icons.icon_save = 'save';
Icons.icon_scanner = 'scanner';
Icons.icon_schedule = 'schedule';
Icons.icon_school = 'school';
Icons.icon_screen_lock_landscape = 'screen_lock_landscape';
Icons.icon_screen_lock_portrait = 'screen_lock_portrait';
Icons.icon_screen_lock_rotation = 'screen_lock_rotation';
Icons.icon_screen_rotation = 'screen_rotation';
Icons.icon_screen_share = 'screen_share';
Icons.icon_sd_card = 'sd_card';
Icons.icon_sd_storage = 'sd_storage';
Icons.icon_search = 'search';
Icons.icon_security = 'security';
Icons.icon_select_all = 'select_all';
Icons.icon_send = 'send';
Icons.icon_sentiment_dissatisfied = 'sentiment_dissatisfied';
Icons.icon_sentiment_neutral = 'sentiment_neutral';
Icons.icon_sentiment_satisfied = 'sentiment_satisfied';
Icons.icon_sentiment_very_dissatisfied = 'sentiment_very_dissatisfied';
Icons.icon_sentiment_very_satisfied = 'sentiment_very_satisfied';
Icons.icon_settings = 'settings';
Icons.icon_settings_applications = 'settings_applications';
Icons.icon_settings_backup_restore = 'settings_backup_restore';
Icons.icon_settings_bluetooth = 'settings_bluetooth';
Icons.icon_settings_brightness = 'settings_brightness';
Icons.icon_settings_cell = 'settings_cell';
Icons.icon_settings_ethernet = 'settings_ethernet';
Icons.icon_settings_input_antenna = 'settings_input_antenna';
Icons.icon_settings_input_component = 'settings_input_component';
Icons.icon_settings_input_composite = 'settings_input_composite';
Icons.icon_settings_input_hdmi = 'settings_input_hdmi';
Icons.icon_settings_input_svideo = 'settings_input_svideo';
Icons.icon_settings_overscan = 'settings_overscan';
Icons.icon_settings_phone = 'settings_phone';
Icons.icon_settings_power = 'settings_power';
Icons.icon_settings_remote = 'settings_remote';
Icons.icon_settings_system_daydream = 'settings_system_daydream';
Icons.icon_settings_voice = 'settings_voice';
Icons.icon_share = 'share';
Icons.icon_shop = 'shop';
Icons.icon_shop_two = 'shop_two';
Icons.icon_shopping_basket = 'shopping_basket';
Icons.icon_shopping_cart = 'shopping_cart';
Icons.icon_short_text = 'short_text';
Icons.icon_show_chart = 'show_chart';
Icons.icon_shuffle = 'shuffle';
Icons.icon_signal_cellular_4_bar = 'signal_cellular_4_bar';
Icons.icon_signal_cellular_connected_no_internet_4_bar = 'signal_cellular_connected_no_internet_4_bar';
Icons.icon_signal_cellular_no_sim = 'signal_cellular_no_sim';
Icons.icon_signal_cellular_null = 'signal_cellular_null';
Icons.icon_signal_cellular_off = 'signal_cellular_off';
Icons.icon_signal_wifi_4_bar = 'signal_wifi_4_bar';
Icons.icon_signal_wifi_4_bar_lock = 'signal_wifi_4_bar_lock';
Icons.icon_signal_wifi_off = 'signal_wifi_off';
Icons.icon_sim_card = 'sim_card';
Icons.icon_sim_card_alert = 'sim_card_alert';
Icons.icon_skip_next = 'skip_next';
Icons.icon_skip_previous = 'skip_previous';
Icons.icon_slideshow = 'slideshow';
Icons.icon_slow_motion_video = 'slow_motion_video';
Icons.icon_smartphone = 'smartphone';
Icons.icon_smoke_free = 'smoke_free';
Icons.icon_smoking_rooms = 'smoking_rooms';
Icons.icon_sms = 'sms';
Icons.icon_sms_failed = 'sms_failed';
Icons.icon_snooze = 'snooze';
Icons.icon_sort = 'sort';
Icons.icon_sort_by_alpha = 'sort_by_alpha';
Icons.icon_spa = 'spa';
Icons.icon_space_bar = 'space_bar';
Icons.icon_speaker = 'speaker';
Icons.icon_speaker_group = 'speaker_group';
Icons.icon_speaker_notes = 'speaker_notes';
Icons.icon_speaker_notes_off = 'speaker_notes_off';
Icons.icon_speaker_phone = 'speaker_phone';
Icons.icon_spellcheck = 'spellcheck';
Icons.icon_star = 'star';
Icons.icon_star_border = 'star_border';
Icons.icon_star_half = 'star_half';
Icons.icon_stars = 'stars';
Icons.icon_stay_current_landscape = 'stay_current_landscape';
Icons.icon_stay_current_portrait = 'stay_current_portrait';
Icons.icon_stay_primary_landscape = 'stay_primary_landscape';
Icons.icon_stay_primary_portrait = 'stay_primary_portrait';
Icons.icon_stop = 'stop';
Icons.icon_stop_screen_share = 'stop_screen_share';
Icons.icon_storage = 'storage';
Icons.icon_store = 'store';
Icons.icon_store_mall_directory = 'store_mall_directory';
Icons.icon_straighten = 'straighten';
Icons.icon_streetview = 'streetview';
Icons.icon_strikethrough_s = 'strikethrough_s';
Icons.icon_style = 'style';
Icons.icon_subdirectory_arrow_left = 'subdirectory_arrow_left';
Icons.icon_subdirectory_arrow_right = 'subdirectory_arrow_right';
Icons.icon_subject = 'subject';
Icons.icon_subscriptions = 'subscriptions';
Icons.icon_subtitles = 'subtitles';
Icons.icon_subway = 'subway';
Icons.icon_supervisor_account = 'supervisor_account';
Icons.icon_surround_sound = 'surround_sound';
Icons.icon_swap_calls = 'swap_calls';
Icons.icon_swap_horiz = 'swap_horiz';
Icons.icon_swap_vert = 'swap_vert';
Icons.icon_swap_vertical_circle = 'swap_vertical_circle';
Icons.icon_switch_camera = 'switch_camera';
Icons.icon_switch_video = 'switch_video';
Icons.icon_sync = 'sync';
Icons.icon_sync_disabled = 'sync_disabled';
Icons.icon_sync_problem = 'sync_problem';
Icons.icon_system_update = 'system_update';
Icons.icon_system_update_alt = 'system_update_alt';
Icons.icon_tab = 'tab';
Icons.icon_tab_unselected = 'tab_unselected';
Icons.icon_tablet = 'tablet';
Icons.icon_tablet_android = 'tablet_android';
Icons.icon_tablet_mac = 'tablet_mac';
Icons.icon_tag_faces = 'tag_faces';
Icons.icon_tap_and_play = 'tap_and_play';
Icons.icon_terrain = 'terrain';
Icons.icon_text_fields = 'text_fields';
Icons.icon_text_format = 'text_format';
Icons.icon_textsms = 'textsms';
Icons.icon_texture = 'texture';
Icons.icon_theaters = 'theaters';
Icons.icon_thumb_down = 'thumb_down';
Icons.icon_thumb_up = 'thumb_up';
Icons.icon_thumbs_up_down = 'thumbs_up_down';
Icons.icon_time_to_leave = 'time_to_leave';
Icons.icon_timelapse = 'timelapse';
Icons.icon_timeline = 'timeline';
Icons.icon_timer = 'timer';
Icons.icon_timer_10 = 'timer_10';
Icons.icon_timer_3 = 'timer_3';
Icons.icon_timer_off = 'timer_off';
Icons.icon_title = 'title';
Icons.icon_toc = 'toc';
Icons.icon_today = 'today';
Icons.icon_toll = 'toll';
Icons.icon_tonality = 'tonality';
Icons.icon_touch_app = 'touch_app';
Icons.icon_toys = 'toys';
Icons.icon_track_changes = 'track_changes';
Icons.icon_traffic = 'traffic';
Icons.icon_train = 'train';
Icons.icon_tram = 'tram';
Icons.icon_transfer_within_a_station = 'transfer_within_a_station';
Icons.icon_transform = 'transform';
Icons.icon_translate = 'translate';
Icons.icon_trending_down = 'trending_down';
Icons.icon_trending_flat = 'trending_flat';
Icons.icon_trending_up = 'trending_up';
Icons.icon_tune = 'tune';
Icons.icon_turned_in = 'turned_in';
Icons.icon_turned_in_not = 'turned_in_not';
Icons.icon_tv = 'tv';
Icons.icon_unarchive = 'unarchive';
Icons.icon_undo = 'undo';
Icons.icon_unfold_less = 'unfold_less';
Icons.icon_unfold_more = 'unfold_more';
Icons.icon_update = 'update';
Icons.icon_usb = 'usb';
Icons.icon_verified_user = 'verified_user';
Icons.icon_vertical_align_bottom = 'vertical_align_bottom';
Icons.icon_vertical_align_center = 'vertical_align_center';
Icons.icon_vertical_align_top = 'vertical_align_top';
Icons.icon_vibration = 'vibration';
Icons.icon_video_call = 'video_call';
Icons.icon_video_label = 'video_label';
Icons.icon_video_library = 'video_library';
Icons.icon_videocam = 'videocam';
Icons.icon_videocam_off = 'videocam_off';
Icons.icon_videogame_asset = 'videogame_asset';
Icons.icon_view_agenda = 'view_agenda';
Icons.icon_view_array = 'view_array';
Icons.icon_view_carousel = 'view_carousel';
Icons.icon_view_column = 'view_column';
Icons.icon_view_comfy = 'view_comfy';
Icons.icon_view_compact = 'view_compact';
Icons.icon_view_day = 'view_day';
Icons.icon_view_headline = 'view_headline';
Icons.icon_view_list = 'view_list';
Icons.icon_view_module = 'view_module';
Icons.icon_view_quilt = 'view_quilt';
Icons.icon_view_stream = 'view_stream';
Icons.icon_view_week = 'view_week';
Icons.icon_vignette = 'vignette';
Icons.icon_visibility = 'visibility';
Icons.icon_visibility_off = 'visibility_off';
Icons.icon_voice_chat = 'voice_chat';
Icons.icon_voicemail = 'voicemail';
Icons.icon_volume_down = 'volume_down';
Icons.icon_volume_mute = 'volume_mute';
Icons.icon_volume_off = 'volume_off';
Icons.icon_volume_up = 'volume_up';
Icons.icon_vpn_key = 'vpn_key';
Icons.icon_vpn_lock = 'vpn_lock';
Icons.icon_wallpaper = 'wallpaper';
Icons.icon_warning = 'warning';
Icons.icon_watch = 'watch';
Icons.icon_watch_later = 'watch_later';
Icons.icon_wb_auto = 'wb_auto';
Icons.icon_wb_cloudy = 'wb_cloudy';
Icons.icon_wb_incandescent = 'wb_incandescent';
Icons.icon_wb_iridescent = 'wb_iridescent';
Icons.icon_wb_sunny = 'wb_sunny';
Icons.icon_wc = 'wc';
Icons.icon_web = 'web';
Icons.icon_web_asset = 'web_asset';
Icons.icon_weekend = 'weekend';
Icons.icon_whatshot = 'whatshot';
Icons.icon_widgets = 'widgets';
Icons.icon_wifi = 'wifi';
Icons.icon_wifi_lock = 'wifi_lock';
Icons.icon_wifi_tethering = 'wifi_tethering';
Icons.icon_work = 'work';
Icons.icon_wrap_text = 'wrap_text';
Icons.icon_youtube_searched_for = 'youtube_searched_for';
Icons.icon_zoom_in = 'zoom_in';
Icons.icon_zoom_out = 'zoom_out';
Icons.icon_zoom_out_map = 'zoom_out_map';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class InputTypes {
}
InputTypes.input_type_date = 'date';
InputTypes.input_type_datetime_local = 'datetime-local';
InputTypes.input_type_email = 'email';
InputTypes.input_type_month = 'month';
InputTypes.input_type_number = 'number';
InputTypes.input_type_password = 'password';
InputTypes.input_type_search = 'search';
InputTypes.input_type_tel = 'tel';
InputTypes.input_type_text = 'text';
InputTypes.input_type_time = 'time';
InputTypes.input_type_url = 'url';
InputTypes.input_type_week = 'week';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class KeyValue {
    /**
     * @param {?} key
     * @param {?} value
     */
    constructor(key, value) {
        this.key = key;
        this.value = value;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * @template T
 */
class SelectOption {
    /**
     * @param {?} key
     * @param {?} value
     */
    constructor(key, value) {
        this.key = key;
        this.value = value;
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TableFieldOptions {
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TextAlign {
}
TextAlign.text_align_right = 'right';
TextAlign.text_align_left = 'left';
TextAlign.text_align_center = 'center';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyButtonComponent {
    /**
     * @param {?} loaderService
     */
    constructor(loaderService) {
        this.loaderService = loaderService;
        this.color = '';
        this.icon = '';
        this.key = '';
        this.type = 'mat-button';
        this.showLoader = false;
        this.onClicked = new EventEmitter();
        this.show = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.showLoader) {
            this.subscription = this.loaderService.loaderState
                .subscribe((state) => {
                this.show = state.show;
            });
        }
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        if (this.showLoader) {
            this.subscription.unsubscribe();
        }
    }
    /**
     * @return {?}
     */
    click() {
        this.onClicked.emit(true);
    }
}
EasyButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-button',
                template: `<div [ngSwitch]="type">
    
        <button [id]="key" *ngSwitchCase="'mat-button-toolbar'" [disabled]="show" mat-button class='easy-button' (click)="click(); $event.stopPropagation();">
            <mat-icon *ngIf="icon !='' && icon != null && !show">{{icon}}</mat-icon>
            <easy-spinner *ngIf="show" [thickness]="4" [size]="30" style="vertical-align: middle"></easy-spinner>
            <span *ngIf="!show">{{displayValue}}</span>
        </button>
    
        <button [id]="key" *ngSwitchCase="'mat-button'" [disabled]="show" mat-button [color]="color" class='easy-button' (click)="click(); $event.stopPropagation();">
            <mat-icon *ngIf="icon !='' && icon != null && !show">{{icon}}</mat-icon>
            <easy-spinner *ngIf="show" [thickness]="4" [size]="30" style="vertical-align: middle"></easy-spinner>
            <span *ngIf="!show">{{displayValue}}</span>
        </button>
    
        <button [id]="key" *ngSwitchCase="'mat-raised-button'" [disabled]="show" mat-raised-button [color]="color" class='easy-button'
            (click)="click(); $event.stopPropagation();">
            <mat-icon *ngIf="icon !='' && icon != null && !show">{{icon}}</mat-icon>
            <easy-spinner *ngIf="show" [thickness]="4" [size]="30" style="vertical-align: middle"></easy-spinner>
            <span *ngIf="!show">{{displayValue}}</span>
        </button>
    
        <button [id]="key" *ngSwitchCase="'mat-fab'" mat-fab [disabled]="show" [color]="color" class='easy-button' (click)="click(); $event.stopPropagation();">
            <mat-icon *ngIf="icon !='' && icon != null && !show">{{icon}}</mat-icon>
            <easy-spinner *ngIf="show" [thickness]="4" [size]="56" style="vertical-align: middle"></easy-spinner>
        </button>
    
        <button [id]="key" *ngSwitchCase="'mat-mini-fab'" mat-mini-fab [disabled]="show" [color]="color" class='easy-button' (click)="click(); $event.stopPropagation();">
            <mat-icon *ngIf="icon !='' && icon != null && !show">{{icon}}</mat-icon>
            <easy-spinner *ngIf="show" [thickness]="4" [size]="40" style="vertical-align: middle"></easy-spinner>
        </button>
    
        <button [id]="key" *ngSwitchCase="'mat-menu-item'" mat-menu-item [disabled]="show" (click)="click();">
            <span *ngIf="!show">{{displayValue}}</span>
        </button>
    
        <button [id]="key" *ngSwitchCase="'mat-icon-button'" mat-icon-button [disabled]="show" [color]="color" class='easy-button'
            (click)="click(); $event.stopPropagation();">
            <mat-icon *ngIf="icon !='' && icon != null && !show">{{icon}}</mat-icon>
        </button>`,
                styles: [`.easy-button {
        margin: 8px;
        text-transform: uppercase;
      }`]
            },] },
];
/** @nocollapse */
EasyButtonComponent.ctorParameters = () => [
    { type: LoaderService, },
];
EasyButtonComponent.propDecorators = {
    "displayValue": [{ type: Input },],
    "color": [{ type: Input },],
    "icon": [{ type: Input },],
    "key": [{ type: Input, args: ['key',] },],
    "type": [{ type: Input },],
    "showLoader": [{ type: Input },],
    "onClicked": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyModalDialog {
    /**
     * @param {?} dialogRef
     * @param {?} media
     * @param {?} data
     */
    constructor(dialogRef, media, data) {
        this.dialogRef = dialogRef;
        this.media = media;
        this.data = data;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.setResponsiveStyles();
        this.media.subscribe(x => {
            this.setResponsiveStyles();
        });
        this.setFieldValuesFromData();
    }
    /**
     * @return {?}
     */
    setResponsiveStyles() {
        if (this.dialogRef == null || this.dialogRef.componentInstance == null)
            return;
        if (this.media != null && this.media.isActive('xs')) {
            this.dialogRef.updateSize('100vw');
        }
        else
            this.dialogRef.updateSize('60vw');
    }
    /**
     * @return {?}
     */
    setFieldValuesFromData() {
        if (this.data != null && this.fields != null) {
            Object.keys(this.data).forEach(key => {
                let /** @type {?} */ field = this.fields.singleOrDefault(x => x.key == key);
                if (field != null)
                    field.value = this.data[key];
            });
        }
    }
    /**
     * @param {?} container
     * @return {?}
     */
    setForm(container) {
        this.header = container.header;
        this.fields = container.fields;
        this.actions = container.actions;
        this.container = container;
    }
    /**
     * @param {?} action
     * @param {?} field
     * @return {?}
     */
    click(action, field) {
        if (this.data != null) {
            Object.keys(this.data).forEach(key => {
                let /** @type {?} */ field = this.fields.singleOrDefault(x => x.key == key);
                if (field != null)
                    this.data[key] = field.value;
            });
        }
        if (field.skipFormValidation) {
            this.dialogRef.close(this.fields);
            if (action != null)
                action(this.fields, this.data);
        }
        else {
            let /** @type {?} */ validationResult = this.container.validateFields();
            if (validationResult.valid) {
                this.dialogRef.close(this.fields);
                if (action != null)
                    action(this.fields, this.data);
            }
        }
    }
}
EasyModalDialog.decorators = [
    { type: Component, args: [{
                template: `<h1 mat-dialog-title>{{header}}</h1>
                <div mat-dialog-content flex style="overflow-y: auto;">
                    <div *ngFor="let field of fields" class="form-row">
                        <easy-form-field *ngIf="!field.hide" [field]="field"></easy-form-field>
                    </div>
                </div>
                <div mat-dialog-actions fxLayout="row wrap" fxLayoutAlign="end">
                    <div *ngFor="let action of actions">
                        <easy-button [key]="action.key" *ngIf="!action.hide" [icon]="action.icon" [color]="action.color" [displayValue]="action.label" [type]='action.type' (onClicked)="click(action.action,action)"></easy-button>
                    </div>
               </div>`,
                styles: [`
               .form-row {
                margin-left: 15px;
              }`]
            },] },
];
/** @nocollapse */
EasyModalDialog.ctorParameters = () => [
    { type: MatDialogRef, },
    { type: ObservableMedia, },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyModalService {
    /**
     * @param {?} modal
     */
    constructor(modal) {
        this.modal = modal;
    }
    /**
     * @param {?} container
     * @param {?=} data
     * @param {?=} disableClose
     * @return {?}
     */
    showModal(container, data = {}, disableClose = true) {
        if (container == null)
            return;
        let /** @type {?} */ width = "60vw";
        let /** @type {?} */ dialogRef = this.modal.open(EasyModalDialog, { width: width, disableClose: disableClose, data: data, panelClass: 'full-width-dialog' });
        dialogRef.componentInstance.setForm(container);
        return dialogRef;
    }
}
EasyModalService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EasyModalService.ctorParameters = () => [
    { type: MatDialog, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyNotification {
    /**
     * @param {?} snackBar
     */
    constructor(snackBar) {
        this.snackBar = snackBar;
    }
    /**
     * @param {?} title
     * @param {?} body
     * @return {?}
     */
    showMessage(title, body) {
        this.snackBar.open(title, body, { duration: 3000 });
    }
    /**
     * @param {?} title
     * @param {?} body
     * @param {?=} action
     * @return {?}
     */
    showError(title, body, action = null) {
        let /** @type {?} */ config = new MatSnackBarConfig();
        config.duration = 6000;
        // config.extraClasses = ['notification-error'];
        this.snackBar.open(title, body, config);
        let /** @type {?} */ ref = this.snackBar.open(title, body, config);
        if (action != null)
            ref.onAction().subscribe(x => { action(); });
    }
}
EasyNotification.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EasyNotification.ctorParameters = () => [
    { type: MatSnackBar, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyFormService {
    /**
     * @param {?} easyNotification
     * @param {?} httpIntegrationService
     * @param {?} matDialog
     */
    constructor(easyNotification, httpIntegrationService, matDialog) {
        this.easyNotification = easyNotification;
        this.httpIntegrationService = httpIntegrationService;
        this.easyModal = new EasyModalService(matDialog);
        this.errorSubscription = httpIntegrationService.OnError.subscribe(x => {
            if (x.status == 0) {
                this.easyNotification.showError("Error", "No response from server.", () => this.showErrorModal(x.json().Message));
            }
            else if (x.status == 500) {
                this.easyNotification.showError("Error", x.status + " : " + x.statusText, () => this.showErrorModal(x.json().Message));
            }
        });
    }
    /**
     * @return {?}
     */
    buildModal() {
        this.modal = this.form.addModalContainer("Error");
        this.stackTraceField = this.modal.addTextAreaField("Stack Trace", { readonly: true });
        this.modal.addAction('Back', () => { }, { key: 'Back', color: Colors.color_warn, icon: Icons.icon_arrow_back, showLoader: true, type: ButtonTypes.button_raised, columnSpan: 2 });
    }
    /**
     * @param {?} message
     * @return {?}
     */
    showErrorModal(message) {
        this.stackTraceField.value = message;
        this.easyModal.showModal(this.modal);
    }
    /**
     * @return {?}
     */
    createForm() {
        this.form = new EasyForm();
        this.buildModal();
        return this.form;
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.errorSubscription.unsubscribe();
    }
}
EasyFormService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EasyFormService.ctorParameters = () => [
    { type: EasyNotification, },
    { type: HttpIntegrationService, },
    { type: MatDialog, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyFileUploadComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     */
    constructor(validatorService) {
        super(validatorService);
        this.color = '';
        this.icon = '';
        this.type = '';
        this.placeholder = '';
        this.key = '';
        this.hint = '';
        this.allowedExtensions = '';
        this.onClicked = new EventEmitter();
        this.fieldValueChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        
    }
    /**
     * @return {?}
     */
    uploadClick() {
    }
    /**
     * @return {?}
     */
    click() {
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    fileChanged($event) {
        let /** @type {?} */ files = $event.target.files;
        if (files[0]) {
            this.hint = files[0].name;
            this.fieldValueChange.emit(new FieldChangeDto(this.key, files[0], true));
        }
        else
            this.hint = null;
    }
}
EasyFileUploadComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-fileupload',
                template: `<div>
                <input id={{key}} type='file' #fileUploader style='visibility:hidden' (change)=fileChanged($event) [accept]="allowedExtensions">
                <mat-form-field class='easy-input'>
                    <input id='fileDsplayLabel' type='text' [placeholder]="placeholder" matInput disabled>
                    <mat-hint>{{hint}}</mat-hint>
                    <easy-button matSuffix [color]="color" [icon]="icon" [type]="type" [displayValue]="''" (onClicked)="fileUploader.click();"></easy-button>
                </mat-form-field>
              </div>`,
                styles: [`.easy-input {
                margin-top: 20px;
                width: 100%;
              }`]
            },] },
];
/** @nocollapse */
EasyFileUploadComponent.ctorParameters = () => [
    { type: ValidatorService, },
];
EasyFileUploadComponent.propDecorators = {
    "color": [{ type: Input },],
    "icon": [{ type: Input },],
    "type": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "key": [{ type: Input, args: ['key',] },],
    "hint": [{ type: Input, args: ['hint',] },],
    "allowedExtensions": [{ type: Input },],
    "onClicked": [{ type: Output },],
    "fieldValueChange": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyMaterialModule {
}
EasyMaterialModule.decorators = [
    { type: NgModule, args: [{
                exports: [
                    CdkTableModule,
                    MatAutocompleteModule,
                    MatButtonModule,
                    MatButtonToggleModule,
                    MatCardModule,
                    MatCheckboxModule,
                    MatChipsModule,
                    MatStepperModule,
                    MatDatepickerModule,
                    MatDialogModule,
                    MatExpansionModule,
                    MatGridListModule,
                    MatIconModule,
                    MatInputModule,
                    MatListModule,
                    MatMenuModule,
                    MatNativeDateModule,
                    MatPaginatorModule,
                    MatProgressBarModule,
                    MatProgressSpinnerModule,
                    MatRadioModule,
                    MatRippleModule,
                    MatSelectModule,
                    MatSidenavModule,
                    MatSliderModule,
                    MatSlideToggleModule,
                    MatSnackBarModule,
                    MatSortModule,
                    MatTableModule,
                    MatTabsModule,
                    MatToolbarModule,
                    MatTooltipModule
                ],
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyRadioButtonComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     */
    constructor(validatorService) {
        super(validatorService);
        this.fieldValueChange = new EventEmitter();
        this.key = '';
        this.formControl = new FormControl('', []);
    }
    /**
     * @return {?}
     */
    onChange() {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.selectedValue, this.formControl.valid));
    }
}
EasyRadioButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-radio-button',
                template: `<mat-radio-group [(ngModel)]="selectedValue" (change)="onChange()" [formControl]="formControl">
                <mat-radio-button *ngFor="let item of items" [value]="item.key">
                   {{item.value}}
                 </mat-radio-button>
               </mat-radio-group>`,
                styles: [``],
                inputs: ['easy-required']
            },] },
];
/** @nocollapse */
EasyRadioButtonComponent.ctorParameters = () => [
    { type: ValidatorService, },
];
EasyRadioButtonComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "selectedValue": [{ type: Input, args: ['selectedValue',] },],
    "key": [{ type: Input, args: ['key',] },],
    "items": [{ type: Input, args: ['items',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasySelectKeyValueComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     * @param {?} iterableDiffers
     */
    constructor(validatorService, iterableDiffers) {
        super(validatorService);
        this.iterableDiffers = iterableDiffers;
        this.fieldValueChange = new EventEmitter();
        this.key = '';
        this.iterableDiffer = this.iterableDiffers.find([]).create(null);
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        let /** @type {?} */ changes = this.iterableDiffer.diff(this.items);
        if (changes) {
            var /** @type {?} */ item = this.items.singleOrDefault(x => x.key == this.selectedValue);
            if (item == null)
                return;
            this.selectedValue = item.key;
            if (this.selectedValue != null && this.selectedValue != "")
                this.onChange();
        }
        super.ngDoCheck();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        super.ngOnInit();
        if (this.selectedValue != null && this.selectedValue != "")
            this.onChange();
    }
    /**
     * @return {?}
     */
    onChange() {
        if (this.items == null || !this.items.any())
            return;
        let /** @type {?} */ selectedItem = this.items.single(x => x.key == this.selectedValue);
        if (selectedItem == null) {
            return;
        }
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.selectedValue, this.formControl.valid, selectedItem));
    }
}
EasySelectKeyValueComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-select-key-value',
                template: `<mat-form-field class="easy-select">
                <mat-select id="{{key}}" [placeholder]="placeholder"  [(ngModel)]="selectedValue" (change)="onChange()" [formControl]="formControl">
                    <mat-option *ngFor="let item of items" [value]="item.key" id="{{item.key}}">
                    {{item.value}}
                    </mat-option>
                </mat-select>
               </mat-form-field>`,
                styles: [`.easy-select {
                margin-top: 20px;
                width: 100%;
              }`],
                inputs: ['easy-required']
            },] },
];
/** @nocollapse */
EasySelectKeyValueComponent.ctorParameters = () => [
    { type: ValidatorService, },
    { type: IterableDiffers, },
];
EasySelectKeyValueComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "items": [{ type: Input, args: ['items',] },],
    "selectedValue": [{ type: Input, args: ['selectedValue',] },],
    "key": [{ type: Input, args: ['key',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasySelectComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     */
    constructor(validatorService) {
        super(validatorService);
        this.fieldValueChange = new EventEmitter();
        this.key = '';
    }
    /**
     * @return {?}
     */
    onChange() {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.selectedValue, this.formControl.valid));
    }
}
EasySelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-select',
                template: `<mat-form-field class="easy-select">
                <mat-select [placeholder]="placeholder"  [id]="key" [(ngModel)]="selectedValue" (change)="onChange()" [formControl]="formControl">
                    <mat-option *ngFor="let item of items" [value]="item">
                        {{item}}
                    </mat-option>
                </mat-select>
               </mat-form-field>`,
                styles: [`.easy-select {
                margin-top: 20px;
                width: 100%;
              }`],
                inputs: ['easy-required']
            },] },
];
/** @nocollapse */
EasySelectComponent.ctorParameters = () => [
    { type: ValidatorService, },
];
EasySelectComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "items": [{ type: Input, args: ['items',] },],
    "selectedValue": [{ type: Input, args: ['selectedValue',] },],
    "key": [{ type: Input, args: ['key',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyFabService {
    constructor() {
        this.subject = new Subject$1();
        this.actions = [];
        this.initialized = this.subject.asObservable();
    }
    /**
     * @param {?=} actions
     * @return {?}
     */
    initialize(actions = []) {
        this.actions = actions;
        this.subject.next(true);
    }
    /**
     * @return {?}
     */
    uninitialize() {
        this.actions = [];
        this.subject.next(true);
    }
}
EasyFabService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
EasyFabService.ctorParameters = () => [];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyFabComponent {
    /**
     * @param {?} loaderService
     * @param {?} easyFabService
     */
    constructor(loaderService, easyFabService) {
        this.loaderService = loaderService;
        this.easyFabService = easyFabService;
        this.actions = [];
        this.easyFabSubscription = easyFabService.initialized.subscribe(x => {
            this.actions = easyFabService.actions;
        });
    }
    /**
     * @param {?} field
     * @return {?}
     */
    click(field) {
        field.action();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.easyFabSubscription.unsubscribe();
    }
}
EasyFabComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-fab',
                template: `<div class='full-container'>
               <button [id]="action.key" *ngFor="let action of actions" mat-fab class='sticky-fab easy-button' [color]="action.color" (click)="click(action)" [matTooltip]="action.label" matTooltipPosition="left">
                <mat-icon *ngIf="action.icon !='' && action.icon != null">{{action.icon}}</mat-icon>
               </button>
               </div>`,
                styles: [`
               
               .form-row {
                margin-left: 15px;
              }
              
              .demo-card-container {
                display: flex;
                flex-flow: column nowrap;
              }
              
              .demo-card-container .mat-card {
                margin: 0 16px 16px 0;
                width: 350px;
              }
              
              .demo-card-container img {
                background-color: gray;
              }
              
              .demo-card-blue {
                background-color: #b0becc;
              }
              
              .demo-card-blue .mat-card-actions {
                display: flex;
                flex-direction: column;
              }
              
              .container {
                width: 100%;
                margin-bottom: 15px;
              }
              
              .full-container {
                position: fixed;
                height: 100vh;
                width: 56px;
                right: 30px;
                bottom: 30px;
                z-index: 9999;
                pointer-events: none;
                display: flex;
                flex-direction: column-reverse;
              }
              
              .sticky-fab {
                margin-top: 10px;
                margin-right: 30px;
                margin-left: auto;
                pointer-events: all;
              }
               
               .checkbox-group-container {
                display: flex;
                flex-direction: column;
                margin-top: 20px;
              }
              
              .checkbox-group {
                display: flex;
                flex-direction: column;
                padding-left: 20px;
              }
              
              .easy-checkbox {
                margin-top: 100px;
              }
              
              .button-row {
                display: flex;
                align-items: right;
                justify-content: flex-end;
              }
              
              .easy-date-picker {
                margin-top: 20px;
                width: 100%;
              }
              
              .easy-select {
                margin-top: 20px;
                width: 100%;
              }
              
              .easy-input {
                margin-top: 20px;
                width: 100%;
              }
              
              .easy-autocomplete {
                margin-top: 20px;
                width: 100%;
              }
              
              .easy-button {
                margin: 8px;
                text-transform: uppercase;
              }
              
              .input-icon {
                font-size: 24px;
                height: 24px;
                width: 24px;
              }
              
              .full-width {
                width: 100vw;
              }`]
            },] },
];
/** @nocollapse */
EasyFabComponent.ctorParameters = () => [
    { type: LoaderService, },
    { type: EasyFabService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyFabMobileComponent {
    /**
     * @param {?} loaderService
     * @param {?} easyFabService
     */
    constructor(loaderService, easyFabService) {
        this.loaderService = loaderService;
        this.easyFabService = easyFabService;
        this.actions = [];
        this.easyFabSubscription = easyFabService.initialized.subscribe(x => {
            this.actions = easyFabService.actions;
        });
    }
    /**
     * @param {?} field
     * @return {?}
     */
    click(field) {
        field.action();
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.easyFabSubscription.unsubscribe();
    }
}
EasyFabMobileComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-fab-mobile',
                template: `<button *ngIf="actions != null && actions.length > 0" mat-icon-button [matMenuTriggerFor]="easyFabMobileMenu">
                <mat-menu #easyFabMobileMenu="matMenu">
                    <easy-button type="mat-menu-item" [displayValue]="action.label" (onClicked)="click(action)" *ngFor="let action of actions"></easy-button>
                </mat-menu>
                <mat-icon>more_vert</mat-icon>
            </button>`,
                styles: [`.checkbox-group-container {
                display: flex;
                flex-direction: column;
                margin-top: 20px;
              }
              
              .checkbox-group {
                display: flex;
                flex-direction: column;
                padding-left: 20px;
              }
              
              .easy-checkbox {
                margin-top: 100px;
              }
              
              .button-row {
                display: flex;
                align-items: right;
                justify-content: flex-end;
              }
              
              .easy-date-picker {
                margin-top: 20px;
                width: 100%;
              }
              
              .easy-select {
                margin-top: 20px;
                width: 100%;
              }
              
              .easy-input {
                margin-top: 20px;
                width: 100%;
              }
              
              .easy-autocomplete {
                margin-top: 20px;
                width: 100%;
              }
              
              .easy-button {
                margin: 8px;
                text-transform: uppercase;
              }
              
              .input-icon {
                font-size: 24px;
                height: 24px;
                width: 24px;
              }
              
              .full-width {
                width: 100vw;
              }`]
            },] },
];
/** @nocollapse */
EasyFabMobileComponent.ctorParameters = () => [
    { type: LoaderService, },
    { type: EasyFabService, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyContainerComponent {
    constructor() {
        this.selectedTabIndex = 0;
    }
}
EasyContainerComponent.decorators = [
    { type: Component, args: [{
                encapsulation: ViewEncapsulation.None,
                selector: 'easy-container',
                template: `<div fxLayout="row wrap" fxLayoutAlign="space-around">
    <div *ngFor="let container of containers" [fxFlex.xl]="container.xlSize" [fxFlex.lg]="container.lgSize" [fxFlex.md]="container.mdSize" [fxFlex.sm]="container.smSize" [fxFlex.xs]="container.xsSize" 
    [style.margin-right]="container.marginRight" [style.margin-left]="container.marginLeft" [style.padding-left]="container.paddingLeft" [style.padding-left]="container.paddingLeft">
      <div *ngIf="container.show" [ngSwitch]="container.controlType" class="container">
          <mat-card *ngSwitchCase="'card'">
              <mat-card-header *ngIf="container.header != null && container.header != ''">
                  <mat-card-title class="mat-card-title" style="text-transform:uppercase;">
                      {{container.header}}
                  </mat-card-title>
              </mat-card-header>
              <mat-card-content>
                  <easy-form-content [container]="container"></easy-form-content>
                  <easy-container [containers]='container.containers'></easy-container>
              </mat-card-content>
              <mat-card-actions>
                  <easy-form-content-actions [actions]="container.actions"></easy-form-content-actions>
              </mat-card-actions>
          </mat-card>
          <mat-expansion-panel [id]="container.header" *ngSwitchCase="'expansion-panel'">
              <mat-expansion-panel-header>
                  <mat-panel-title>
                      {{container.header}}
                  </mat-panel-title>
              </mat-expansion-panel-header>
              <easy-form-content [container]="container"></easy-form-content>
              <easy-container [containers]='container.containers'></easy-container>
              <easy-form-content-actions [actions]="container.actions"></easy-form-content-actions>
          </mat-expansion-panel>
          <mat-card *ngSwitchCase="'tabs'">
              <mat-tab-group [(selectedIndex)]="selectedTabIndex">
                  <mat-tab label="{{tab.header}}" *ngFor="let tab of container.containers;let i = index">
                  <div *ngIf="selectedTabIndex == i">
                      <easy-form-content [container]="tab"></easy-form-content>
                      <easy-container [containers]='tab.containers'></easy-container>
                      <easy-form-content-actions [actions]="tab.actions"></easy-form-content-actions>
                  </div>
                  </mat-tab>
              </mat-tab-group>
          </mat-card>
          <mat-horizontal-stepper *ngSwitchCase="'stepper'">
              <mat-step *ngFor="let step of container.containers">
                  <easy-form-content [container]="step"></easy-form-content>
                  <easy-container [containers]='step.containers'></easy-container>
              </mat-step>
          </mat-horizontal-stepper>
          <mat-accordion *ngSwitchCase="'accordion'">
              <mat-expansion-panel [id]="expansionPanel.header" *ngFor="let expansionPanel of container.containers">
                  <mat-expansion-panel-header>
                      <mat-panel-title>
                          {{expansionPanel.header}}
                      </mat-panel-title>
                  </mat-expansion-panel-header>
                  <easy-form-content [container]="expansionPanel"></easy-form-content>
                  <easy-container [containers]='expansionPanel.containers'></easy-container>
                  <easy-form-content-actions [actions]="expansionPanel.actions"></easy-form-content-actions>
              </mat-expansion-panel>
          </mat-accordion>
      </div>
  </div>
</div>`,
                styles: [`
    div.mat-expansion-panel-content:not(.mat-expanded) {
        height: 0px;
        visibility: hidden;
    }
    
    .mat-expansion-panel-header:not(.mat-expanded)  {
        height: 48px;
    }
    
    .mat-expansion-panel-header  {
        height: 64px;
        .mat-content {
            font-weight: 100;
            font-size: 18px;
        }
        &.mat-expanded {        
            .mat-expansion-indicator {
                transform: rotate(180deg);
            }
        }
    }
    
    .checkbox-group-container {
    display: flex;
    flex-direction: column;
    margin-top: 20px;
  }
  
  .checkbox-group {
    display: flex;
    flex-direction: column;
    padding-left: 20px;
  }
  
  .button-row {
    display: flex;
    align-items: right;
    justify-content: flex-end;
  }
  
  .easy-date-picker {
    margin-top: 20px;
    width: 100%;
  }
  
  .easy-select {
    margin-top: 20px;
    width: 100%;
  }
  
  .easy-input {
    margin-top: 20px;
    width: 100%;
  }
  
  .easy-autocomplete {
    margin-top: 20px;
    width: 100%;
  }
  
  .easy-button {
    margin: 8px;
    text-transform: uppercase;
  }
  
  .input-icon {
    font-size: 24px;
    height: 24px;
    width: 24px;
  }
  
  .full-width {
    width: 100vw;
  }`]
            },] },
];
/** @nocollapse */
EasyContainerComponent.propDecorators = {
    "containers": [{ type: Input },],
    "layout": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyInputComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     */
    constructor(validatorService) {
        super(validatorService);
        this.fieldValueChange = new EventEmitter();
        this.key = '';
        this.hint = '';
        this.type = 'text';
        this.maxLength = null;
        this.placeholder = '';
    }
    /**
     * @return {?}
     */
    onChange() {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, this.formControl.valid));
    }
    /**
     * @return {?}
     */
    enterKeyPressed() {
        if (!this.onEnter)
            return;
        this.onEnter();
    }
}
EasyInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-input',
                template: `<mat-form-field class='easy-input'>
                        <input matInput [id]="key" [easy-max-length]="maxLength" [type]="type" [placeholder]="placeholder"  [(ngModel)]="value" (change)="onChange()" (keyup.enter)="enterKeyPressed()" [formControl]="formControl">
                        <mat-hint *ngIf="maxLength != null && maxLength > 0" align="end">{{value.length}} / {{maxLength}}</mat-hint>
                        <mat-hint *ngIf="hint != null && hint.length > 0" align="start">{{hint}}</mat-hint>
                        <mat-error *ngIf="formControl.hasError('required')">{{this.getError('required')}}</mat-error>
                        <mat-error *ngIf="formControl.hasError('maxlength')">{{this.getError('maxlength')}}</mat-error>
                        <mat-error *ngIf="formControl.hasError('minlength')">{{this.getError('minlength')}}</mat-error>
                        <mat-error *ngIf="formControl.hasError('pattern')">{{this.getError('pattern')}}</mat-error>
               </mat-form-field>`,
                styles: [`.easy-input {
                margin-top: 20px;
                width: 100%;
              }`]
            },] },
];
/** @nocollapse */
EasyInputComponent.ctorParameters = () => [
    { type: ValidatorService, },
];
EasyInputComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "value": [{ type: Input, args: ['value',] },],
    "key": [{ type: Input, args: ['key',] },],
    "hint": [{ type: Input, args: ['hint',] },],
    "type": [{ type: Input, args: ['type',] },],
    "onEnter": [{ type: Input, args: ['onEnter',] },],
    "maxLength": [{ type: Input, args: ['maxLength',] },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class FileDownloadService {
    /**
     * @param {?} http
     * @param {?} easyNotification
     */
    constructor(http, easyNotification) {
        this.http = http;
        this.easyNotification = easyNotification;
    }
    /**
     * @param {?} url
     * @param {?=} overriddenFilename
     * @return {?}
     */
    downloadFile(url, overriddenFilename) {
        this.http.get(url, { responseType: ResponseContentType.Blob }).subscribe(x => {
            this.saveToFileSystem(x, overriddenFilename);
        });
    }
    /**
     * @param {?} bytes
     * @param {?} filename
     * @return {?}
     */
    downloadFileFromBytes(bytes, filename) {
        saveAs(new Blob([new Uint8Array(bytes)]), filename);
    }
    /**
     * @param {?} response
     * @param {?=} overriddenFilename
     * @return {?}
     */
    saveToFileSystem(response, overriddenFilename) {
        const /** @type {?} */ contentDispositionHeader = response.headers.get('Content-Disposition');
        const /** @type {?} */ contentType = response.headers.get('Content-Type');
        if (contentDispositionHeader == null || contentDispositionHeader == "" || contentType == null || contentType == "") {
            this.buildError();
            return;
        }
        const /** @type {?} */ parts = contentDispositionHeader.split(';');
        const /** @type {?} */ filename = parts[1].split('=')[1];
        const /** @type {?} */ blob = new Blob([response._body], { type: contentType });
        saveAs(blob, overriddenFilename != null && overriddenFilename != "" ? overriddenFilename : filename);
    }
    /**
     * @return {?}
     */
    buildError() {
        var /** @type {?} */ error = `There seems to be a problem with the server configuration. Please see example below:

        If downloading from record store change url to RecordDownload.
                
        var result = new HttpResponseMessage(HttpStatusCode.OK);
        result.Content = new ByteArrayContent(record.FileData);

        result.Content.Headers.ContentType = new MediaTypeHeaderValue("application/pdf");
        result.Content.Headers.ContentDisposition = new ContentDispositionHeaderValue("attachment");
        result.Content.Headers.ContentDisposition.FileName = record.FileName;

        result.Content.Headers.Add("Access-Control-Expose-Headers", "Content-Disposition");
        result.Content.Headers.Add("Access-Control-Expose-Headers", "Filename");
        result.Content.Headers.Add("Filename", record.FileName);`;
        this.easyNotification.showError("Download failed", "Could not download file. Check console for errors.");
        console.error(error);
    }
}
FileDownloadService.decorators = [
    { type: Injectable },
];
/** @nocollapse */
FileDownloadService.ctorParameters = () => [
    { type: Http, },
    { type: EasyNotification, },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SourceDetail {
    /**
     * @param {?} url
     * @param {?} token
     */
    constructor(url, token) {
        this.url = url;
        this.httpHeaders = { Authorization: token };
    }
}
class EasyRecordComponent {
    /**
     * @param {?} easyNotification
     * @param {?} fileDownloader
     * @param {?} http
     */
    constructor(easyNotification, fileDownloader, http) {
        this.easyNotification = easyNotification;
        this.fileDownloader = fileDownloader;
        this.http = http;
        this.page = 1;
        this.isLoadComplete = false;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.document = new SourceDetail(this.source, this.authorizationHeader);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    loadComplete(event) {
        this.isLoadComplete = true;
        this.pageCount = event.numPages;
    }
    /**
     * @param {?} error
     * @return {?}
     */
    onError(error) {
        this.easyNotification.showError("Error", "Could open load pdf");
    }
    /**
     * @return {?}
     */
    nextPage() {
        this.page++;
    }
    /**
     * @return {?}
     */
    previousPage() {
        if (this.page > 1)
            this.page--;
    }
    /**
     * @param {?} response
     * @return {?}
     */
    getFilename(response) {
        const /** @type {?} */ contentDispositionHeader = response.headers.get('Content-Disposition');
        const /** @type {?} */ contentType = response.headers.get('Content-Type');
        if (contentDispositionHeader == null || contentDispositionHeader == "") {
            if (contentType != null && contentType != "") {
                return "download" + "." + this.getFileExtension(contentType);
            }
            return "";
        }
        const /** @type {?} */ parts = contentDispositionHeader.split(';');
        return parts[1].split('=')[1];
    }
    /**
     * @return {?}
     */
    download() {
        this.http.get(this.source, { responseType: ResponseContentType.ArrayBuffer })
            .subscribe((file) => {
            let /** @type {?} */ bytes = new Uint8Array(file._body);
            this.fileDownloader.downloadFileFromBytes(bytes, this.getFilename(file));
        }, x => {
            this.easyNotification.showError("Error", "Could open load pdf");
        });
    }
    /**
     * @param {?} filename
     * @return {?}
     */
    getFileExtension(filename) {
        return filename.split('/').pop();
    }
}
EasyRecordComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-record',
                template: `<div>
                <div *ngIf="!isLoadComplete">
                    <mat-progress-bar mode="indeterminate">
                    </mat-progress-bar>
                </div>
                <mat-toolbar>
                    <easy-button icon="keyboard_arrow_left" matTooltip="Previous Page" type="mat-icon-button" displayValue="''" (onClicked)="previousPage()"></easy-button>
                    <easy-button icon="keyboard_arrow_right" matTooltip="Next Page" type="mat-icon-button" displayValue="''" (onClicked)="nextPage()"></easy-button>
                    <span class="spacer"></span>
                    <easy-button icon="file_download" matTooltip="Download" type="mat-icon-button" displayValue="''" (onClicked)="download()"></easy-button>
                </mat-toolbar>
                <div [style.visible]="isLoadComplete">               
                    <pdf-viewer [src]="document" [(page)]="page" [show-all]="false" original-size="false"
                        (after-load-complete)="loadComplete($event)" (error)="onError($event)"></pdf-viewer>                
                    </div>
                <div>`,
                styles: [`.spacer { flex: 1 1 auto; }
            `]
            },] },
];
/** @nocollapse */
EasyRecordComponent.ctorParameters = () => [
    { type: EasyNotification, },
    { type: FileDownloadService, },
    { type: Http, },
];
EasyRecordComponent.propDecorators = {
    "source": [{ type: Input, args: ['source',] },],
    "authorizationHeader": [{ type: Input, args: ['authorizationHeader',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyTextAreaComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     */
    constructor(validatorService) {
        super(validatorService);
        this.fieldValueChange = new EventEmitter();
        this.validators = [];
        this.key = '';
        this.formControl = new FormControl('', []);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.readonly)
            this.formControl.disable();
        super.ngOnInit();
    }
    /**
     * @return {?}
     */
    onBlur() {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, this.formControl.valid));
    }
}
EasyTextAreaComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-text-area',
                template: `<mat-form-field class='easy-input'>
                        <textarea matInput [id]="key" [style.height]="height" [style.min-height]="minHeight" [style.max-height]="maxHeight" [easy-max-length]="maxLength" [placeholder]="placeholder"  [(ngModel)]="value" (change)="onBlur()" [formControl]="formControl"></textarea>
                        <mat-hint *ngIf="maxLength != null && maxLength > 0" align="end">{{value.length}} / {{maxLength}}</mat-hint>
                        <mat-error *ngIf="formControl.hasError('required')">{{this.getError('required')}}</mat-error>
                        <mat-error *ngIf="formControl.hasError('maxlength')">{{this.getError('maxlength')}}</mat-error>
                        <mat-error *ngIf="formControl.hasError('minlength')">{{this.getError('minlength')}}</mat-error>
                        <mat-error *ngIf="formControl.hasError('pattern')">{{this.getError('pattern')}}</mat-error>
               </mat-form-field>`,
                styles: [`.easy-input {
                margin-top: 20px;
                width: 100%;
              }`]
            },] },
];
/** @nocollapse */
EasyTextAreaComponent.ctorParameters = () => [
    { type: ValidatorService, },
];
EasyTextAreaComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "value": [{ type: Input, args: ['value',] },],
    "maxLength": [{ type: Input, args: ['maxLength',] },],
    "validators": [{ type: Input, args: ['validators',] },],
    "key": [{ type: Input, args: ['key',] },],
    "readonly": [{ type: Input, args: ['readonly',] },],
    "height": [{ type: Input, args: ['height',] },],
    "minHeight": [{ type: Input, args: ['minHeight',] },],
    "maxHeight": [{ type: Input, args: ['maxHeight',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyCheckBoxComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     */
    constructor(validatorService) {
        super(validatorService);
        this.fieldValueChange = new EventEmitter();
        this.key = '';
        this.marginLeft = '';
        this.marginTop = '';
        this.marginRight = '';
        this.marginBottom = '';
    }
    /**
     * @return {?}
     */
    onChange() {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, true));
    }
    /**
     * @return {?}
     */
    click() {
    }
}
EasyCheckBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-checkbox',
                template: `<div class="easy-checkbox xxxx"><mat-checkbox [id]="key" [(ngModel)]="value" (change)="onChange();" (margin-left)="marginLeft" (margin-top)="marginTop" (margin-right)="marginRight" (margin-bottom)="marginBottom" (click)="click(); $event.stopPropagation();">
                {{placeholder}}
               </mat-checkbox></div>`,
                styles: []
            },] },
];
/** @nocollapse */
EasyCheckBoxComponent.ctorParameters = () => [
    { type: ValidatorService, },
];
EasyCheckBoxComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "value": [{ type: Input, args: ['value',] },],
    "key": [{ type: Input, args: ['key',] },],
    "marginLeft": [{ type: Input, args: ['marginLeft',] },],
    "marginTop": [{ type: Input, args: ['marginTop',] },],
    "marginRight": [{ type: Input, args: ['marginRight',] },],
    "marginBottom": [{ type: Input, args: ['marginBottom',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class CheckboxListItem {
    /**
     * @param {?} displayValue
     * @param {?} value
     */
    constructor(displayValue, value) {
        this.displayValue = displayValue;
        this.value = value;
    }
}
class EasyCheckBoxGroupComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     */
    constructor(validatorService) {
        super(validatorService);
        this.fieldValueChange = new EventEmitter();
        this.value = [];
        this.key = '';
        this.items = [];
        this.checkboxListItems = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.value == null)
            this.value = [];
        for (let /** @type {?} */ item of this.items) {
            let /** @type {?} */ checked = this.value.any(x => x == item.value);
            let /** @type {?} */ checkboxItem = new CheckboxListItem(item.displayValue, item.value);
            checkboxItem.checked = checked;
            this.checkboxListItems.add(checkboxItem);
        }
    }
    /**
     * @return {?}
     */
    onChange() {
        this.value = [];
        for (let /** @type {?} */ item of this.checkboxListItems) {
            if (item.checked)
                this.value.push(item.value);
        }
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, true));
    }
}
EasyCheckBoxGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-checkbox-group',
                template: `<div class="checkbox-group-container">
                <span>{{placeholder}}</span>
                <div *ngFor="let item of checkboxListItems" class="checkbox-group">
                    <mat-checkbox [(ngModel)]="item.checked" (change)="onChange()">
                        {{item.displayValue}} 
                    </mat-checkbox>
               </div>
              </div>`,
                styles: [`.checkbox-group-container {
                display: flex;
                flex-direction: column;
                margin-top: 20px;
              }
              
              .checkbox-group {
                display: flex;
                flex-direction: column;
                padding-left: 20px;
              }`]
            },] },
];
/** @nocollapse */
EasyCheckBoxGroupComponent.ctorParameters = () => [
    { type: ValidatorService, },
];
EasyCheckBoxGroupComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "value": [{ type: Input, args: ['value',] },],
    "key": [{ type: Input, args: ['key',] },],
    "items": [{ type: Input, args: ['items',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class TableDatabase {
    /**
     * @param {?} data
     */
    constructor(data) {
        this.dataChange = new BehaviorSubject([]);
        this.dataChange.next(data);
    }
    /**
     * @return {?}
     */
    get data() { return this.dataChange.value; }
}
class TableDataSource extends DataSource {
    /**
     * @param {?} database
     * @param {?} sort
     * @param {?} columns
     * @param {?} paginator
     */
    constructor(database, sort, columns, paginator) {
        super();
        this.database = database;
        this.sort = sort;
        this.columns = columns;
        this.paginator = paginator;
        this.filterChange = new BehaviorSubject('');
        this.paginatorInitialized = false;
        this.renderedData = [];
        this.displayDataChanges = [
            this.database.dataChange,
            this.sort.sortChange,
            this.filterChange
        ];
    }
    /**
     * @return {?}
     */
    get filter() { return this.filterChange.value; }
    /**
     * @param {?} filter
     * @return {?}
     */
    set filter(filter) { this.filterChange.next(filter); }
    /**
     * @param {?} paginator
     * @return {?}
     */
    setPaginator(paginator) {
        if (paginator != null && !this.paginatorInitialized) {
            this.paginator = paginator;
            this.displayDataChanges.add(this.paginator.page);
            this.paginatorInitialized = true;
            this.filterChange.next(this.filter);
        }
    }
    /**
     * @return {?}
     */
    connect() {
        let /** @type {?} */ page = this.paginator == null ? null : this.paginator.page;
        if (this.paginator != null)
            this.setPaginator(this.paginator);
        return Observable.merge(...this.displayDataChanges).map(() => {
            let /** @type {?} */ data = this.database.data;
            data = data.slice().filter((item) => {
                let /** @type {?} */ searchStr = "";
                for (let /** @type {?} */ column of this.columns) {
                    if (item[column] != undefined) {
                        let /** @type {?} */ sValue = item[column].toString();
                        searchStr += sValue.toLowerCase();
                    }
                }
                return searchStr.indexOf(this.filter.toLowerCase()) != -1;
            });
            if (this.paginator != null) {
                const /** @type {?} */ startIndex = this.paginator.pageIndex * this.paginator.pageSize;
                data = data.splice(startIndex, this.paginator.pageSize);
            }
            this.renderedData = this.getSortedData(data);
            return this.renderedData;
        });
    }
    /**
     * @return {?}
     */
    disconnect() { }
    /**
     * @param {?} data
     * @return {?}
     */
    getSortedData(data) {
        if (!this.sort.active || this.sort.direction == '') {
            return data;
        }
        return data.sort((a, b) => {
            let /** @type {?} */ propertyA = '';
            let /** @type {?} */ propertyB = '';
            [propertyA, propertyB] = [a[this.sort.active], b[this.sort.active]];
            let /** @type {?} */ valueA = isNaN(+propertyA) ? propertyA : +propertyA;
            let /** @type {?} */ valueB = isNaN(+propertyB) ? propertyB : +propertyB;
            return (valueA < valueB ? -1 : 1) * (this.sort.direction == 'asc' ? 1 : -1);
        });
    }
}

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class Sortable {
}
class EasyTableComponent {
    /**
     * @param {?} iterableDiffers
     */
    constructor(iterableDiffers) {
        this.iterableDiffers = iterableDiffers;
        this.rows = [];
        this.actions = [];
        this.showFilter = false;
        this.showPaginator = false;
        this.pageIndex = 0;
        this.pageSize = 25;
        this.totalItems = 0;
        this.displayColumns = [];
        this.colCounts = 0;
        this.fieldValueChange = new EventEmitter();
        this.pageChange = new EventEmitter();
        this.iterableDiffer = this.iterableDiffers.find([]).create(null);
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.displayColumns.length = 0;
        this.totalItems = 0;
        this.pageIndex = 0;
        this.pageSize = 25;
        for (let /** @type {?} */ column of this.columns.where(x => !x.hide && x.type != "hidden"))
            this.displayColumns.push(column.key);
        if (this.actions.length > 0 && !this.columns.any(x => x.key == "Actions")) {
            for (let /** @type {?} */ item of this.rows)
                item["Actions"] = "Placeholder";
            this.displayColumns.push("Actions");
            this.columns.push(new EasyButtonField({ type: ColumnTypes.column_type_actions, key: "Actions", label: "Actions" }));
        }
        this.database = new TableDatabase(this.rows);
        if (this.totalItems === 0) {
            this.totalItems = this.database.data.length;
        }
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        if (this.dataSource == null) {
            if (this.showFilter && this.showPaginator && this.filter != null && this.paginator != null) {
                this.dataSource = new TableDataSource(this.database, this.sort, this.displayColumns, this.paginator);
                this.initializeFilter();
            }
            else if (this.showFilter && this.filter != null) {
                this.dataSource = new TableDataSource(this.database, this.sort, this.displayColumns, this.paginator);
                this.initializeFilter();
            }
            else if (this.showPaginator && this.paginator != null) {
                this.dataSource = new TableDataSource(this.database, this.sort, this.displayColumns, this.paginator);
            }
            else if (!this.showFilter && !this.showPaginator) {
                this.dataSource = new TableDataSource(this.database, this.sort, this.displayColumns, this.paginator);
            }
            if (this.totalItems === 0) {
                this.totalItems = this.database.data.length;
            }
        }
        let /** @type {?} */ changes = this.iterableDiffer.diff(this.rows);
        if (changes) {
            this.database.dataChange.next(this.rows);
        }
    }
    /**
     * @return {?}
     */
    initializeFilter() {
        if (this.filter != null)
            Observable.fromEvent(this.filter.nativeElement, 'keyup')
                .debounceTime(150)
                .distinctUntilChanged()
                .subscribe(() => {
                if (!this.dataSource) {
                    return;
                }
                this.dataSource.filter = this.filter.nativeElement.value;
            });
    }
    /**
     * @param {?} sort
     * @return {?}
     */
    sortData(sort) {
        this.sort.direction = sort.direction;
        this.sort.active = sort.active;
        let /** @type {?} */ sortable = new Sortable();
        sortable.id = sort.active;
        sortable.start = sort.direction == 'asc' ? 'asc' : 'desc';
        this.sort.sort(sortable);
    }
    /**
     * @param {?} column
     * @param {?} row
     * @return {?}
     */
    getField(column, row) {
        let /** @type {?} */ field = new EasyField(column.options);
        let /** @type {?} */ value = Object.keys(row).single(x => x == column.key);
        field.value = row[value];
        field.label = "";
        field.marginLeft = column.marginLeft;
        field.marginTop = column.marginTop;
        field.marginRight = column.marginRight;
        field.marginBottom = column.marginBottom;
        field.onChange.subscribe(field => {
            let /** @type {?} */ rowKey = Object.keys(row).single(x => x == field.key.split('|')[0]);
            row[rowKey] = field.value;
            this.fieldValueChange.emit(new FieldChangeDto("", this.rows, true));
        });
        if (field.type === 'control') {
            field.key = field.key + '|' + this.colCounts.toString();
            this.colCounts++;
        }
        return field;
    }
    /**
     * @return {?}
     */
    clearFilter() {
        this.filter.nativeElement.value = "";
        if (!this.dataSource) {
            return;
        }
        this.dataSource.filter = this.filter.nativeElement.value;
    }
    /**
     * @param {?} action
     * @param {?} row
     * @return {?}
     */
    click(action, row) {
        var /** @type {?} */ rowIndex = this.rows.indexOf(row);
        row.rowIndex = rowIndex;
        action(row);
    }
    /**
     * @param {?} row
     * @return {?}
     */
    rowClicked(row) {
        var /** @type {?} */ rowIndex = this.rows.indexOf(row);
        row.rowIndex = rowIndex;
        if (this.actions.length > 0) {
            this.actions[0].action(row);
        }
    }
    /**
     * @param {?} column
     * @param {?} row
     * @return {?}
     */
    getValue(column, row) {
        let /** @type {?} */ name = column.key.split(' ').join('');
        return row[name];
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onPageChange(event) {
        this.pageChange.emit(event);
    }
}
EasyTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-table',
                template: `
    <div class="table-container mat-elevation-z8">
      <div style="overflow-x: auto">
        <div class="table-header" *ngIf="rows.length > 0 && showFilter">
          <mat-form-field floatPlaceholder="never">
            <input matInput #filter placeholder="Filter">
            <easy-button matSuffix color="" type="mat-icon-button" displayValue="" icon="clear" (onClicked)="clearFilter();"></easy-button>
          </mat-form-field>
        </div>

        <mat-table #table [dataSource]="dataSource" matSort>
      
          <div *ngFor="let column of columns">      
            <ng-container [cdkColumnDef]="column.key" >
              <mat-header-cell [style.min-width]="column.minWidth" [style.max-width]="column.maxWidth" [style.width]="column.width" [style.text-align]="column.textAlign" [style.margin-left]="column.marginLeft" [style.margin-right]="column.marginRight" *cdkHeaderCellDef mat-sort-header>{{column.label == 'Actions' ? '' : column.label }}</mat-header-cell>
              <mat-cell [style.min-width]="column.minWidth" [style.max-width]="column.maxWidth" [style.width]="column.width" [style.text-align]="column.textAlign" [style.margin-left]="column.marginLeft" [style.margin-right]="column.marginRight" *cdkCellDef="let row">
                <div [ngSwitch]="column.type">
                  <span *ngSwitchCase="'actions'" class="button-row">
                    <div *ngFor="let action of actions; let indexAction = index"> 
                      <easy-button [key]="action.key + indexRow + indexAction" [icon]="action.icon" [color]="action.color" [displayValue]="action.label" [type]="action.type" (onClicked)="click(action.action,row)"></easy-button>
                    </div>
                  </span>
                  <span *ngSwitchCase="'date'">
                    {{row[column.key] | date:column.format}}
                  </span>
                  <easy-form-field *ngSwitchCase="'control'" fxFlex="auto" [field]="getField(column,row)" (fieldValueChange)="valueChanged($event)"></easy-form-field>
                  <span *ngSwitchDefault>
                    {{row[column.key]}}
                  </span>
                </div>                 
              </mat-cell>
            </ng-container>
          </div>
      
          <mat-header-row *cdkHeaderRowDef="displayColumns"></mat-header-row>
          <mat-row *cdkRowDef="let row; columns: displayColumns;" (click)="rowClicked(row)"></mat-row>
      
        </mat-table>
    
        <div class="no-results" [style.display]="dataSource == null || dataSource.renderedData.length == 0 ? '' : 'none'">
          No data to display
        </div>
      </div>
      <mat-paginator *ngIf="rows.length > 0 && showPaginator" #paginator [length]="totalItems" [pageIndex]="pageIndex" [pageSize]="pageSize"
        [pageSizeOptions]="[5, 10, 25, 100]" [style.visibility]="rows.length > 0" (page)="onPageChange($event)">
      </mat-paginator>
  </div>`,
                styles: [`
  .table-container {
    display: flex;
    flex-direction: column;
    min-width: 300px;
    margin-bottom: 30px;
  }
  
  .table-header {
    min-height: 56px;
    max-height: 56px;
    display: flex;
    align-items: center;
    padding: 8px 24px 0;
    font-size: 20px;
    justify-content: space-between;
    border-bottom: 1px solid transparent;
  }
  
  mat-header-cell {
    margin-right: 10px;
  }
  
  mat-cell {
    margin-right: 10px;
  }
  
  mat-form-field {
    font-size: 14px;
    flex-grow: 1;
    margin-left: 32px;
    margin-top: 8px;
  }
  
  .no-results {
    display: flex;
    justify-content: center;
    padding: 24px;
    font-size: 12px;
    font-style: italic;
  }
  
  mat-table {
    overflow: auto;
    max-height: 500px;
  }
  
  mat-row {
    cursor: pointer;
  }
  
  mat-row:hover {
    background: lightgray;
  }
  
  .button-row {
    display: flex;
    align-items: right;
    justify-content: flex-end;
  }
`]
            },] },
];
/** @nocollapse */
EasyTableComponent.ctorParameters = () => [
    { type: IterableDiffers, },
];
EasyTableComponent.propDecorators = {
    "columns": [{ type: Input },],
    "rows": [{ type: Input },],
    "actions": [{ type: Input },],
    "showFilter": [{ type: Input },],
    "showPaginator": [{ type: Input },],
    "pageIndex": [{ type: Input },],
    "pageSize": [{ type: Input },],
    "totalItems": [{ type: Input },],
    "sort": [{ type: ViewChild, args: [MatSort,] },],
    "filter": [{ type: ViewChild, args: ['filter',] },],
    "paginator": [{ type: ViewChild, args: [MatPaginator,] },],
    "fieldValueChange": [{ type: Output },],
    "pageChange": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyAutocompleteComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     */
    constructor(validatorService) {
        super(validatorService);
        this.placeholder = '';
        this.key = '';
        this.fieldValueChange = new EventEmitter();
        this.filteredItems = this.formControl.valueChanges.startWith(null)
            .map(x => x ? this.filter(x) : this.items.slice());
    }
    /**
     * @param {?} item
     * @return {?}
     */
    onChange(item) {
        this.selectedValue = item;
        this.formControl.setValue(item);
        this.formControl.updateValueAndValidity();
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.selectedValue, this.formControl.valid));
    }
    /**
     * @param {?} name
     * @return {?}
     */
    filter(name) {
        return this.items.filter(x => x.toLowerCase().indexOf(name.toLowerCase()) === 0);
    }
}
EasyAutocompleteComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-autocomplete',
                template: `<mat-form-field class='easy-autocomplete'>
                    <input matInput [placeholder]="placeholder" [matAutocomplete]="auto" [(ngModel)]="selectedValue" [formControl]="formControl">
                    <mat-error *ngIf="formControl.hasError('required')">{{this.getError('required')}}</mat-error>
                    <mat-autocomplete #auto="matAutocomplete">
                        <mat-option *ngFor="let item of filteredItems | async" [value]="item" (onSelectionChange)="onChange(item)">
                            {{ item }}
                        </mat-option>
                    </mat-autocomplete>
                </mat-form-field>`,
                styles: [`.easy-autocomplete {
                  margin-top: 20px;
                  width: 100%;
                }`]
            },] },
];
/** @nocollapse */
EasyAutocompleteComponent.ctorParameters = () => [
    { type: ValidatorService, },
];
EasyAutocompleteComponent.propDecorators = {
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "key": [{ type: Input, args: ['key',] },],
    "selectedValue": [{ type: Input, args: ['selectedValue',] },],
    "items": [{ type: Input, args: ['items',] },],
    "fieldValueChange": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyAutocompleteKeyValueComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     * @param {?} iterableDiffers
     */
    constructor(validatorService, iterableDiffers) {
        super(validatorService);
        this.iterableDiffers = iterableDiffers;
        this.key = '';
        this.fieldValueChange = new EventEmitter();
        this.filteredItems = this.formControl.valueChanges.startWith(null)
            .map(x => x && typeof x === 'object' ? x.value : x)
            .map(x => x ? this.filter(x) : this.items.slice());
        this.iterableDiffer = this.iterableDiffers.find([]).create(null);
    }
    /**
     * @param {?} item
     * @return {?}
     */
    displayFn(item) {
        if (item == null)
            return "";
        return item.value;
    }
    /**
     * @return {?}
     */
    ngDoCheck() {
        let /** @type {?} */ changes = this.iterableDiffer.diff(this.items);
        if (changes) {
            var /** @type {?} */ item = this.items.singleOrDefault(x => x.key == this.selectedValue);
            if (item == null)
                return;
            this.selectedValue = item.key;
            if (this.selectedValue != null && this.selectedValue != "")
                this.onChange(item);
        }
    }
    /**
     * @param {?} item
     * @return {?}
     */
    onChange(item) {
        this.selectedValue = item.key;
        this.formControl.setValue(item.value);
        this.formControl.updateValueAndValidity();
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.selectedValue, this.formControl.valid));
    }
    /**
     * @param {?} name
     * @return {?}
     */
    filter(name) {
        return this.items.filter(x => x.value.toLowerCase().indexOf(name.toLowerCase()) === 0);
    }
}
EasyAutocompleteKeyValueComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-autocomplete-key-value',
                template: `<mat-form-field class='easy-autocomplete'>
                    <input matInput [placeholder]="placeholder" [matAutocomplete]="auto" [formControl]="formControl">
                    <mat-error *ngIf="formControl.hasError('required')">{{this.getError('required')}}</mat-error>

                    <mat-autocomplete #auto="matAutocomplete">
                        <mat-option *ngFor="let item of filteredItems | async" [value]="item" (onSelectionChange)="onChange(item)">
                            {{ item.value }}
                        </mat-option>
                    </mat-autocomplete>
                </mat-form-field>`,
                styles: [`
      .easy-autocomplete {
        margin-top: 20px;
        width: 100%;
      }`]
            },] },
];
/** @nocollapse */
EasyAutocompleteKeyValueComponent.ctorParameters = () => [
    { type: ValidatorService, },
    { type: IterableDiffers, },
];
EasyAutocompleteKeyValueComponent.propDecorators = {
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "items": [{ type: Input, args: ['items',] },],
    "selectedValue": [{ type: Input, args: ['selectedValue',] },],
    "key": [{ type: Input, args: ['key',] },],
    "fieldValueChange": [{ type: Output },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class SpinnerComponent {
    constructor() {
        this.size = 25;
        this.thickness = 2;
        this.color = '#4f6aa7';
        this.opacity = '.1';
        this.secondColor = '';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        const /** @type {?} */ c = this.hexToRgb(this.color);
        this.secondColor = 'rgba(' + c.r + ',' + c.g + ',' + c.b + ', ' + this.opacity + ')';
    }
    /**
     * @param {?} hex
     * @return {?}
     */
    hexToRgb(hex) {
        let /** @type {?} */ result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
        return result ? {
            r: parseInt(result[1], 16),
            g: parseInt(result[2], 16),
            b: parseInt(result[3], 16)
        } : null;
    }
}
SpinnerComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-spinner',
                template: '',
                styles: [`
    @keyframes spin {
      from {transform: rotate(0deg);}
      to {transform: rotate(360deg);}
    }

    :host {
      position:relative;
      box-sizing: border-box;
      display:inline-block;
      padding:0px;
      border-radius:100%;
      border-style:solid;
      animation: spin 0.8s linear infinite;
    }

    :host .margins {
        margin: 0px 10px;
    }
  `]
            },] },
];
/** @nocollapse */
SpinnerComponent.propDecorators = {
    "size": [{ type: Input }, { type: HostBinding, args: ['style.width.px',] }, { type: HostBinding, args: ['style.height.px',] },],
    "thickness": [{ type: Input }, { type: HostBinding, args: ['style.borderWidth.px',] },],
    "color": [{ type: Input }, { type: HostBinding, args: ['style.borderTopColor',] },],
    "opacity": [{ type: Input },],
    "secondColor": [{ type: HostBinding, args: ['style.borderBottomColor',] }, { type: HostBinding, args: ['style.borderLeftColor',] }, { type: HostBinding, args: ['style.borderRightColor',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyDatePickerComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     * @param {?} dateAdapter
     */
    constructor(validatorService, dateAdapter) {
        super(validatorService);
        this.dateAdapter = dateAdapter;
        this.fieldValueChange = new EventEmitter();
        this.value = null;
        this.key = '';
        this.hint = '';
        this.dateAdapter.setLocale('en-ZA');
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.readonly)
            this.formControl.disable();
        let /** @type {?} */ date2 = this.dateAdapter.parse(this.value, "dd/MM/yyyy");
        if (this.value == null || this.value == '' || this.value == "Invalid Date")
            this.formControl.setValue(null);
        else
            this.formControl.setValue(date2);
        super.ngOnInit();
    }
    /**
     * @return {?}
     */
    onChange() {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, this.formControl.valid));
    }
    /**
     * @param {?} date
     * @return {?}
     */
    onselectedChanged(date) {
        let /** @type {?} */ parsedDate = this.dateAdapter.parse(date, "dd/MM/yyyy");
        this.value = date;
        this.formControl.setValue(parsedDate);
        this.formControl.updateValueAndValidity();
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, this.formControl.valid));
    }
}
EasyDatePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-date-picker',
                template: `<mat-form-field class="easy-date-picker">
                <input matInput [matDatepicker]="myDatepicker" [placeholder]='placeholder' (change)="onChange()" [formControl]="formControl"/>
                    <mat-datepicker-toggle matSuffix [for]="myDatepicker"></mat-datepicker-toggle>                    
                    <mat-hint>{{hint}}</mat-hint>
                    <mat-datepicker #myDatepicker (selectedChanged)="onselectedChanged($event)"></mat-datepicker>
                    <mat-error *ngIf="formControl.hasError('required')">{{this.getError('required')}}</mat-error>
                    <mat-error *ngIf="formControl.hasError('maxlength')">{{this.getError('maxlength')}}</mat-error>
                    <mat-error *ngIf="formControl.hasError('minlength')">{{this.getError('minlength')}}</mat-error>
                    <mat-error *ngIf="formControl.hasError('pattern')">{{this.getError('pattern')}}</mat-error>
                </mat-form-field>`,
                styles: [`
                  .easy-date-picker {
                    margin-top: 20px;
                    width: 100%;
                  }`]
            },] },
];
/** @nocollapse */
EasyDatePickerComponent.ctorParameters = () => [
    { type: ValidatorService, },
    { type: DateAdapter, },
];
EasyDatePickerComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "value": [{ type: Input, args: ['value',] },],
    "key": [{ type: Input, args: ['key',] },],
    "readonly": [{ type: Input, args: ['readonly',] },],
    "hint": [{ type: Input, args: ['hint',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyFormComponent$1 {
    /**
     * @param {?} easyFabService
     */
    constructor(easyFabService) {
        this.easyFabService = easyFabService;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.easyFabService.initialize(this.form.actions);
    }
    /**
     * @return {?}
     */
    ngOnDestroy() {
        this.easyFabService.uninitialize();
    }
}
EasyFormComponent$1.decorators = [
    { type: Component, args: [{
                selector: 'easy-form',
                template: `<div *ngFor="let toolbarContainer of form.toolbarContainers">
                          <mat-toolbar color="primary">
                            <div *ngFor="let toolbar of toolbarContainer.toolbars" class="toolbar-row">

                            <button mat-icon-button [matMenuTriggerFor]="toolbarMenu" *ngFor="let menu of toolbar.menus">
                              <mat-icon>more_vert</mat-icon>
                              <mat-menu #toolbarMenu="matMenu">
                                <button *ngFor="let field of menu" mat-menu-item [disabled]="field.show" (click)="field.action()">
                                  <span *ngIf="!field.show">{{field.label}}</span>
                                </button>
                              </mat-menu>                     
                            </button>

                            <div *ngFor="let field of toolbar.fields">
                              <div [ngSwitch]="field.controlType">
                                <easy-form-field *ngSwitchCase="'button'" [field]="field"></easy-form-field>
                                <span *ngSwitchCase="'toolbar-text'">
                                  {{field.label}}
                                </span>                            
                              </div>            
                            </div>
                            </div>
                          </mat-toolbar>
                        </div>
            
            <div fxLayout="row" style="padding-top:10px;padding-bottom:10px;" fxLayoutAlign="center">                                      
                      
              <div [fxFlex.xl]="form.xlSize" [fxFlex.lg]="form.lgSize" [fxFlex.md]="form.mdSize" [fxFlex.sm]="form.smSize" [fxFlex.xs]="form.xsSize">
                <easy-container [layout]='form.layout' [containers]='form.getContainers()'></easy-container>
              </div>
            </div>`,
                styles: [`.checkbox-group-container {
              display: flex;
              flex-direction: column;
              margin-top: 20px;
            }

            .toolbar-row {
              display: flex;
              flex-direction: row;
            }
            
            .checkbox-group {
              display: flex;
              flex-direction: column;
              padding-left: 20px;
            }
            
            .easy-checkbox {
              margin-top: 100px;
            }
            
            .button-row {
              display: flex;
              align-items: right;
              justify-content: flex-end;
            }
            
            .easy-date-picker {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-select {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-input {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-autocomplete {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-button {
              margin: 8px;
              text-transform: uppercase;
            }
            
            .input-icon {
              font-size: 24px;
              height: 24px;
              width: 24px;
            }
            
            .full-width {
              width: 100vw;
            }`],
                providers: [EasyFormService]
            },] },
];
/** @nocollapse */
EasyFormComponent$1.ctorParameters = () => [
    { type: EasyFabService, },
];
EasyFormComponent$1.propDecorators = {
    "form": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class RequiredDirective {
    /**
     * @param {?} el
     */
    constructor(el) {
        this.el = el;
        this.validators = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.validators == null || this.validators.length)
            return;
        let /** @type {?} */ requiredValidators = this.validators.filter(x => x.validatorType == ValidatorType.required);
        if (requiredValidators.length > 0)
            this.el.nativeElement.required = true;
    }
}
RequiredDirective.decorators = [
    { type: Directive, args: [{ selector: '[easy-required]' },] },
];
/** @nocollapse */
RequiredDirective.ctorParameters = () => [
    { type: ElementRef, },
];
RequiredDirective.propDecorators = {
    "validators": [{ type: Input, args: ['validators',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class MaxLengthDirective {
    /**
     * @param {?} el
     */
    constructor(el) {
        this.el = el;
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.easyMaxLength == 0 || this.easyMaxLength == null)
            return;
        this.el.nativeElement.maxLength = this.easyMaxLength;
    }
}
MaxLengthDirective.decorators = [
    { type: Directive, args: [{ selector: '[easy-max-length]' },] },
];
/** @nocollapse */
MaxLengthDirective.ctorParameters = () => [
    { type: ElementRef, },
];
MaxLengthDirective.propDecorators = {
    "easyMaxLength": [{ type: Input, args: ['easy-max-length',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyFormFieldComponent {
    /**
     * @param {?} event
     * @return {?}
     */
    valueChanged(event) {
        this.field.valueChanged(event);
    }
    /**
     * @param {?} action
     * @return {?}
     */
    executeAction(action) {
        action(this.field);
    }
    /**
     * @param {?} event
     * @return {?}
     */
    tablePageChanged(event) {
        let /** @type {?} */ tableField = /** @type {?} */ (this.field);
        tableField.pageChanged(event);
    }
}
EasyFormFieldComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-form-field',
                template: `<div [ngSwitch]="field.controlType">
  
    <easy-input [key]="field.key"  *ngSwitchCase="'textbox'" [readonly]="containerReadonly || field.readonly" [validators]="field.validators" [maxLength]="field.maxLength" [placeholder]="field.label" [value]="field.value" (fieldValueChange)="valueChanged($event)" [type]="field.type" [options]="field.pristine" [hint]="field.hint" [onEnter]="field.onEnter"></easy-input>
    
    <easy-text-area [key]="field.key" [height]="field.height" [minHeight]="field.minHeight" [maxHeight]="field.maxHeight" *ngSwitchCase="'textArea'" [readonly]="containerReadonly || field.readonly" [validators]="field.validators" [maxLength]="field.maxLength" [placeholder]="field.label" [value]="field.value" (fieldValueChange)="valueChanged($event)" [options]="field.pristine"></easy-text-area>
  
    <easy-select [key]="field.key" [easy-required]="field.validators" [readonly]="containerReadonly || field.readonly" *ngSwitchCase="'select'" [validators]="field.validators" [placeholder]="field.label" [selectedValue]="field.value" [items]="field.items" (fieldValueChange)="valueChanged($event)" [options]="field.pristine"></easy-select>
  
    <easy-select-key-value [key]="field.key" [easy-required]="field.validators" [readonly]="containerReadonly || field.readonly" [validators]="field.validators" *ngSwitchCase="'select-key-value'" [placeholder]="field.label" [selectedValue]="field.value" [items]="field.items" (fieldValueChange)="valueChanged($event)" [options]="field.pristine"></easy-select-key-value>
  
    <easy-radio-button [key]="field.key" [easy-required]="field.validators" [readonly]="containerReadonly || field.readonly" [validators]="field.validators" *ngSwitchCase="'radio-button'" [placeholder]="field.label" [selectedValue]="field.value" [items]="field.items" (fieldValueChange)="valueChanged($event)" [options]="field.pristine"></easy-radio-button>
  
    <easy-checkbox [key]="field.key" *ngSwitchCase="'checkbox'" [readonly]="containerReadonly || field.readonly" [placeholder]="field.label" [(value)]="field.value" (fieldValueChange)="valueChanged($event)" [marginLeft]="field.marginLeft" [marginTop]="field.marginTop" [marginRight]="field.marginRight" [marginBottom]="field.marginBottom"></easy-checkbox>
  
    <easy-checkbox-group [key]="field.key" *ngSwitchCase="'checkbox-group'" [readonly]="containerReadonly || field.readonly" [placeholder]="field.label" [(value)]="field.value" [items]="field.items" (fieldValueChange)="valueChanged($event)"></easy-checkbox-group>
  
    <easy-autocomplete [key]="field.key" *ngSwitchCase="'autocomplete'" [readonly]="containerReadonly || field.readonly" [validators]="field.validators" [placeholder]="field.label" [items]="field.items" [selectedValue]="field.value" (fieldValueChange)="valueChanged($event)" [options]="field.pristine"></easy-autocomplete>
  
    <easy-autocomplete-key-value [key]="field.key" *ngSwitchCase="'autocomplete-key-value'" [readonly]="containerReadonly || field.readonly" [validators]="field.validators" [placeholder]="field.label" [items]="field.items" [selectedValue]="field.value" (fieldValueChange)="valueChanged($event)" [options]="field.pristine"></easy-autocomplete-key-value>
  
    <easy-button [key]="field.key" class="right" *ngSwitchCase="'button'" [color]="field.color" [icon]="field.icon" [type]="field.type" [displayValue]="field.label" [showLoader]="field.showLoader" (onClicked)="executeAction(field.action)"></easy-button>
  
    <easy-table *ngSwitchCase="'table'" [rows]="field.rows" [columns]="field.columns" [actions]="field.actions" [showFilter]="field.showFilter" [showPaginator]="field.showPaginator" [pageIndex]="field.pageIndex" [pageSize]="field.pageSize" [totalItems]="field.totalItems" (fieldValueChange)="valueChanged($event)" (pageChange)="tablePageChanged($event)"></easy-table>
    
    <easy-date-picker [key]="field.key" *ngSwitchCase="'date-picker'" [readonly]="containerReadonly || field.readonly" [placeholder]="field.label" [hint]="field.hint" [value]="field.value" [validators]="field.validators" (fieldValueChange)="valueChanged($event)" [options]="field.pristine"></easy-date-picker>

    <easy-date-time-picker [key]="field.key" *ngSwitchCase="'date-time-picker'" [readonly]="containerReadonly || field.readonly" [placeholder]="field.label" [hint]="field.hint" [value]="field.value" [validators]="field.validators" (fieldValueChange)="valueChanged($event)" [options]="field.pristine"></easy-date-time-picker>    
      
    <easy-fileupload [key]="field.key" *ngSwitchCase="'fileupload'" [readonly]="containerReadonly || field.readonly" [icon]="field.icon" [color]="field.color" [hint]="field.hint" [placeholder]="field.label" (fieldValueChange)="valueChanged($event)" [type]="field.type" [allowedExtensions]="field.allowedExtensions"></easy-fileupload>  
  
    <easy-record *ngSwitchCase="'record'" [source]="field.url" [authorizationHeader]="field.authorizationHeader"></easy-record>  
  
    <easy-form-content-actions *ngSwitchCase="'actions'" [actions]="field.actions"></easy-form-content-actions>    

    <easy-divider *ngSwitchCase="'divider'"></easy-divider>  
  
  </div>`,
                styles: [`.checkbox-group-container {
    display: flex;
    flex-direction: column;
    margin-top: 20px;
  }
  
  .checkbox-group {
    display: flex;
    flex-direction: column;
    padding-left: 20px;
  }
  
  .easy-checkbox {
    margin-top: 100px;
  }
  
  .button-row {
    display: flex;
    align-items: right;
    justify-content: flex-end;
  }
  
  .easy-date-picker {
    margin-top: 20px;
    width: 100%;
  }
  
  .easy-select {
    margin-top: 20px;
    width: 100%;
  }
  
  .easy-input {
    margin-top: 20px;
    width: 100%;
  }
  
  .easy-autocomplete {
    margin-top: 20px;
    width: 100%;
  }
  
  .easy-button {
    margin: 8px;
    text-transform: uppercase;
  }
  
  .input-icon {
    font-size: 24px;
    height: 24px;
    width: 24px;
  }
  
  .full-width {
    width: 100vw;
  }`]
            },] },
];
/** @nocollapse */
EasyFormFieldComponent.propDecorators = {
    "field": [{ type: Input },],
    "containerReadonly": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyFormContentComponent {
}
EasyFormContentComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-form-content',
                template: `<div fxLayout="row wrap" style="overflow-y:hidden">
              <div *ngFor="let field of container.fields" [fxFlex.xl]="container.getXlColumnSize(field)" [fxFlex.lg]="container.getLgColumnSize(field)"
                  [fxFlex.md]="container.getMdColumnSize(field)" [fxFlex.sm]="container.getSmColumnSize(field)" [fxFlex.xs]="container.getXsColumnSize(field)"
                  fxLayoutAlign="start">
                  <easy-form-field fxFlex="auto" *ngIf="!field.hide" style="margin-left:10px" [field]="field" [containerReadonly]="container.readonly"></easy-form-field>
              </div>
            </div>`,
                styles: [`.checkbox-group-container {
              display: flex;
              flex-direction: column;
              margin-top: 20px;
            }
            
            .checkbox-group {
              display: flex;
              flex-direction: column;
              padding-left: 20px;
            }
            
            .easy-checkbox {
              margin-top: 100px;
            }
            
            .button-row {
              display: flex;
              align-items: right;
              justify-content: flex-end;
            }
            
            .easy-date-picker {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-select {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-input {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-autocomplete {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-button {
              margin: 8px;
              text-transform: uppercase;
            }
            
            .input-icon {
              font-size: 24px;
              height: 24px;
              width: 24px;
            }
            
            .full-width {
              width: 100vw;
            }`]
            },] },
];
/** @nocollapse */
EasyFormContentComponent.propDecorators = {
    "container": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyFormContentActionsComponent {
    /**
     * @param {?} action
     * @return {?}
     */
    click(action) {
        action();
    }
}
EasyFormContentActionsComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-form-content-actions',
                template: `<div fxLayout="row wrap" fxLayoutAlign="end">
              <div *ngFor="let action of actions">
                  <easy-button [key]="action.key" *ngIf="!action.hide" [icon]="action.icon" [color]="action.color" [displayValue]="action.label" [type]='action.type'
                    [showLoader]="action.showLoader" (onClicked)="click(action.action)"></easy-button>
              </div>
            </div>`,
                styles: [`.checkbox-group-container {
              display: flex;
              flex-direction: column;
              margin-top: 20px;
            }
            
            .checkbox-group {
              display: flex;
              flex-direction: column;
              padding-left: 20px;
            }
            
            .easy-checkbox {
              margin-top: 100px;
            }
            
            .button-row {
              display: flex;
              align-items: right;
              justify-content: flex-end;
            }
            
            .easy-date-picker {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-select {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-input {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-autocomplete {
              margin-top: 20px;
              width: 100%;
            }
            
            .easy-button {
              margin: 8px;
              text-transform: uppercase;
            }
            
            .input-icon {
              font-size: 24px;
              height: 24px;
              width: 24px;
            }
            
            .full-width {
              width: 100vw;
            }`]
            },] },
];
/** @nocollapse */
EasyFormContentActionsComponent.propDecorators = {
    "actions": [{ type: Input },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyDateTimePickerComponent extends EasyFormComponent {
    /**
     * @param {?} validatorService
     */
    constructor(validatorService) {
        super(validatorService);
        this.fieldValueChange = new EventEmitter();
        this.hourValue = 0;
        this.minuteValue = 0;
        this.amPmValue = 'AM';
        this.hint = '';
        this.value = null;
        this.minuteValid = false;
        this.hourValid = false;
        this.dateValid = false;
        this.timeOfDayItems = ['AM', 'PM'];
        this.hourValidators = [];
        this.minuteValidators = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.hourValidators.add(EasyValidator.Pattern("^([1-9]|1[012])$", "Hour not valid"));
        this.minuteValidators.add(EasyValidator.Pattern("^([0-5]?[0-9]|60)$", "Minute not valid"));
        if (this.validators.any(x => x.validatorType == ValidatorType.required)) {
            this.hourValidators.add(EasyValidator.Required("Hour is required"));
            this.minuteValidators.add(EasyValidator.Required("Minute is required"));
        }
        let /** @type {?} */ date = new Date(this.value);
        let /** @type {?} */ hours = date.getHours();
        this.minuteValue = date.getMinutes();
        if (hours > 12 || hours == 0) {
            this.amPmValue = "PM";
            if (hours == 0)
                this.hourValue = 12;
            else
                this.hourValue = hours - 12;
        }
        else
            this.hourValue = hours;
        super.ngOnInit();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    amPmValueChanged(event) {
        this.amPmValue = event.value;
        this.onChange();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    hourValueChanged(event) {
        this.hourValue = event.value;
        this.hourValid = event.valid;
        this.onChange();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    minuteValueChanged(event) {
        this.minuteValue = event.value;
        this.minuteValid = event.valid;
        this.onChange();
    }
    /**
     * @param {?} event
     * @return {?}
     */
    dateValueChanged(event) {
        this.value = event.value;
        this.dateValid = event.valid;
        this.onChange();
    }
    /**
     * @return {?}
     */
    onChange() {
        if (!this.hourValue || this.hourValue == null)
            this.hourValue = 0;
        if (!this.minuteValue || this.minuteValue == null)
            this.minuteValue = 0;
        let /** @type {?} */ date = new Date(this.value);
        date.setMinutes(this.minuteValue);
        if (this.amPmValue == 'PM')
            if (this.hourValue == 12)
                date.setHours(0);
            else
                date.setHours(this.hourValue + 12);
        else
            date.setHours(this.hourValue);
        let /** @type {?} */ valid = this.dateValid && this.minuteValid && this.hourValid;
        this.fieldValueChange.emit(new FieldChangeDto(this.key, date, valid));
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.dateKey = this.dateKey + "1";
        super.ngOnChanges(changes);
    }
}
EasyDateTimePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-date-time-picker',
                template: `<div fxLayout="row wrap" fxLayoutGap="10px">
            <easy-date-picker fxFlex="47%" [readonly]="readonly" [placeholder]="placeholder" [hint]="hint" [value]="value" [validators]="validators" (fieldValueChange)="dateValueChanged($event)" [options]="options"></easy-date-picker>
        <div fxLayout="row wrap" fxFlex="47%" fxLayoutGap="10px">
            <easy-input fxFlex type="number" [readonly]="readonly" placeholder="Hours" [value]="hourValue" [validators]="hourValidators" (fieldValueChange)="hourValueChanged($event)" [options]="options"></easy-input>
            <easy-input fxFlex type="number" [readonly]="readonly" placeholder="Minutes" [value]="minuteValue" [validators]="minuteValidators" (fieldValueChange)="minuteValueChanged($event)" [options]="options"></easy-input>
            <easy-select fxFlex [easy-required]="validators" [readonly]="readonly" [validators]="validators" placeholder="" [selectedValue]="amPmValue" [items]="timeOfDayItems" (fieldValueChange)="amPmValueChanged($event)" [options]="options"></easy-select>
        </div>
    </div>
    `
            },] },
];
/** @nocollapse */
EasyDateTimePickerComponent.ctorParameters = () => [
    { type: ValidatorService, },
];
EasyDateTimePickerComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "hourValue": [{ type: Input, args: ['hourValue',] },],
    "minuteValue": [{ type: Input, args: ['minuteValue',] },],
    "amPmValue": [{ type: Input, args: ['amPmValue',] },],
    "readonly": [{ type: Input, args: ['readonly',] },],
    "hint": [{ type: Input, args: ['hint',] },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "value": [{ type: Input, args: ['value',] },],
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyDividerComponent {
}
EasyDividerComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-divider',
                template: `<mat-divider></mat-divider>`
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
class EasyModule {
}
EasyModule.decorators = [
    { type: NgModule, args: [{
                entryComponents: [EasyModalDialog],
                imports: [ReactiveFormsModule, PdfViewerModule, EasyMaterialModule, CommonModule, FormsModule, FlexLayoutModule, FileUploadModule],
                declarations: [
                    EasyDatePickerComponent,
                    EasyButtonComponent,
                    EasyFabComponent,
                    EasyFabMobileComponent,
                    EasyInputComponent,
                    EasyRecordComponent,
                    EasyCheckBoxComponent,
                    EasyCheckBoxGroupComponent,
                    EasyAutocompleteComponent,
                    EasyAutocompleteKeyValueComponent,
                    EasyFormComponent$1,
                    EasyFormFieldComponent,
                    EasyTableComponent,
                    EasyModalDialog,
                    SpinnerComponent,
                    EasySelectComponent,
                    EasySelectKeyValueComponent,
                    EasyRadioButtonComponent,
                    EasyFormContentComponent,
                    EasyFormContentActionsComponent,
                    MaxLengthDirective,
                    RequiredDirective,
                    EasyTextAreaComponent,
                    EasyContainerComponent,
                    EasyFileUploadComponent,
                    EasyDateTimePickerComponent,
                    EasyDividerComponent
                ],
                providers: [EasyFormService, EasyNotification, EasyModalService, ValidatorService, FileDownloadService, FileUploadModule, FileUploadOptions],
                exports: [
                    EasyButtonComponent,
                    EasyFabComponent,
                    EasyFabMobileComponent,
                    EasyInputComponent,
                    EasyRecordComponent,
                    EasyCheckBoxComponent,
                    EasyCheckBoxGroupComponent,
                    EasyAutocompleteComponent,
                    EasyAutocompleteKeyValueComponent,
                    EasyFormComponent$1,
                    EasyFormFieldComponent,
                    EasyTableComponent,
                    EasyModalDialog,
                    EasyDatePickerComponent,
                    SpinnerComponent,
                    EasySelectKeyValueComponent,
                    EasyRadioButtonComponent,
                    EasySelectComponent,
                    EasyFormContentComponent,
                    EasyFormContentActionsComponent,
                    MaxLengthDirective,
                    RequiredDirective,
                    EasyTextAreaComponent,
                    EasyContainerComponent,
                    FileUploadModule,
                    PdfViewerModule,
                    EasyDateTimePickerComponent,
                    EasyDividerComponent
                ]
            },] },
];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes} checked by tsc
 */
/**
 * Generated bundle index. Do not edit.
 */

export { EasyDateTimePickerComponent, CheckboxListItem, EasyFabService, EasyMaterialModule, EasyStepperField, EasyValidator, FileDownloadService, EasyCardField, EasyAccordionField, EasyButtonField, EasyToolbarTextField, EasyDatePickerField, EasyExpansionPanelField, EasyFileUploadField, EasyRadioButtonField, EasySelectField, EasySelectKeyValueField, EasyTabField, EasyTableField, EasyTextAreaField, EasyDividerField, EasyField, EasyForm, ButtonTypes, Colors, ColumnTypes, DateFormats, FieldWithSameKeyAlreadyExistsException, FieldWithKeyDoesNotExistException, MultipleFieldsWithSameKeyExistException, FieldOptions, FieldChangeDto, FileUploadOptions, Icons, InputTypes, KeyValue, SelectOption, TableFieldOptions, TextAlign, EasyButtonComponent, EasyModalDialog, EasyModule, EasyNotification, EasyFormService, EasyModalService, EasyContainer, ModalContainer, EasyAutocompleteKeyValueComponent as ɵm, EasyAutocompleteComponent as ɵl, EasyCheckBoxGroupComponent as ɵa, EasyCheckBoxComponent as ɵk, EasyDatePickerComponent as ɵf, EasyDividerComponent as ɵbb, EasyFileUploadComponent as ɵba, EasyInputComponent as ɵi, EasyRadioButtonComponent as ɵt, EasyRecordComponent as ɵj, EasySelectKeyValueComponent as ɵs, EasySelectComponent as ɵr, SpinnerComponent as ɵq, EasyTableComponent as ɵp, EasyTextAreaComponent as ɵy, EasyContainerComponent as ɵz, EasyFabMobileComponent as ɵh, EasyFabComponent as ɵg, EasyFormContentActionsComponent as ɵv, EasyFormContentComponent as ɵu, EasyFormFieldComponent as ɵo, EasyFormComponent$1 as ɵn, MaxLengthDirective as ɵw, RequiredDirective as ɵx, ContainerValidation as ɵd, EasyFieldValidator as ɵe, EasyFormComponent as ɵc, ValidatorService as ɵb };
//# sourceMappingURL=easy-suite.js.map
