import { __values, __extends, __spread, __read } from 'tslib';
import { Injectable, Input, Component, Output, EventEmitter, Inject, NgModule, IterableDiffers, ViewEncapsulation, ElementRef, ViewChild, HostBinding, Directive } from '@angular/core';
import { FormControl, Validators, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { Subject } from 'rxjs/Rx';
import { LoaderService, HttpIntegrationService } from 'easy-core';
import { MatDialogRef, MAT_DIALOG_DATA, MatDialog, MatSnackBar, MatSnackBarConfig, MatAutocompleteModule, MatButtonModule, MatButtonToggleModule, MatCardModule, MatCheckboxModule, MatChipsModule, MatDatepickerModule, MatDialogModule, MatExpansionModule, MatGridListModule, MatIconModule, MatInputModule, MatListModule, MatMenuModule, MatNativeDateModule, MatPaginatorModule, MatProgressBarModule, MatProgressSpinnerModule, MatRadioModule, MatRippleModule, MatSelectModule, MatSidenavModule, MatSliderModule, MatSlideToggleModule, MatSnackBarModule, MatSortModule, MatTableModule, MatTabsModule, MatToolbarModule, MatTooltipModule, MatStepperModule, MatSort, MatPaginator, DateAdapter } from '@angular/material';
import { ObservableMedia, FlexLayoutModule } from '@angular/flex-layout';
import { CdkTableModule, DataSource } from '@angular/cdk/table';
import { Subject as Subject$1 } from 'rxjs/Subject';
import { Http, ResponseContentType } from '@angular/http';
import { saveAs } from 'file-saver';
import { Observable } from 'rxjs/Observable';
import { BehaviorSubject } from 'rxjs/BehaviorSubject';
import 'rxjs/add/operator/startWith';
import 'rxjs/add/observable/merge';
import 'rxjs/add/operator/map';
import 'rxjs/add/operator/debounceTime';
import 'rxjs/add/operator/distinctUntilChanged';
import 'rxjs/add/observable/fromEvent';
import { CommonModule } from '@angular/common';
import { FileUploadModule } from 'ng2-file-upload';
import { PdfViewerModule } from 'ng2-pdf-viewer';

var ValidatorService = /** @class */ (function () {
    function ValidatorService() {
    }
    ValidatorService.prototype.buildValidators = function (validators, formControl) {
        if (validators === void 0) { validators = []; }
        var formValidators = Array();
        try {
            for (var validators_1 = __values(validators), validators_1_1 = validators_1.next(); !validators_1_1.done; validators_1_1 = validators_1.next()) {
                var validator = validators_1_1.value;
                switch (validator.validatorType) {
                    case ValidatorType.required:
                        formValidators.push(Validators.required);
                        break;
                    case ValidatorType.maxlength:
                        formValidators.push(Validators.maxLength(validator.maxlength));
                        break;
                    case ValidatorType.minlength:
                        formValidators.push(Validators.minLength(validator.minlength));
                        break;
                    case ValidatorType.pattern:
                        formValidators.push(Validators.pattern(validator.pattern));
                        break;
                }
            }
        }
        catch (e_1_1) { e_1 = { error: e_1_1 }; }
        finally {
            try {
                if (validators_1_1 && !validators_1_1.done && (_a = validators_1.return)) _a.call(validators_1);
            }
            finally { if (e_1) throw e_1.error; }
        }
        formControl.setValidators(formValidators);
        var e_1, _a;
    };
    ValidatorService.prototype.getError = function (name, validators) {
        var matchingValidators = validators.filter(function (x) { return x.validatorType == name; });
        if (matchingValidators.length == 0)
            return "No message configured.";
        Validators.required;
        return matchingValidators[0].message;
    };
    return ValidatorService;
}());
ValidatorService.decorators = [
    { type: Injectable },
];
var EasyFormComponent = /** @class */ (function () {
    function EasyFormComponent(validatorService) {
        this.validatorService = validatorService;
        this.validators = [];
        this.formControl = new FormControl('', []);
    }
    EasyFormComponent.prototype.getError = function (name) {
        return this.validatorService.getError(name, this.validators);
    };
    EasyFormComponent.prototype.ngOnInit = function () {
        if (this.readonly)
            this.formControl.disable();
        else
            this.formControl.enable();
        this.validatorService.buildValidators(this.validators, this.formControl);
    };
    EasyFormComponent.prototype.ngOnChanges = function (changes) {
        if (changes == null || changes.options == null || changes.options.currentValue)
            return;
        this.formControl.markAsTouched();
        this.formControl.markAsDirty();
        this.formControl.updateValueAndValidity();
    };
    EasyFormComponent.prototype.ngDoCheck = function () {
        if (this.readonly)
            this.formControl.disable();
        else
            this.formControl.enable();
    };
    return EasyFormComponent;
}());
EasyFormComponent.propDecorators = {
    "validators": [{ type: Input, args: ['validators',] },],
    "options": [{ type: Input, args: ['options',] },],
    "readonly": [{ type: Input, args: ['readonly',] },],
    "key": [{ type: Input, args: ['key',] },],
};
var EasyValidator = /** @class */ (function () {
    function EasyValidator() {
    }
    EasyValidator.Required = function (message) {
        return new EasyFieldValidator().requiredValidator(message);
    };
    EasyValidator.MinLength = function (length, message) {
        return new EasyFieldValidator().minLengthValidator(length, message);
    };
    EasyValidator.MaxLength = function (length, message) {
        return new EasyFieldValidator().maxLengthValidator(length, message);
    };
    EasyValidator.Pattern = function (pattern, message) {
        return new EasyFieldValidator().patternValidator(pattern, message);
    };
    EasyValidator.Email = function (message) {
        if (message == "" || message == null)
            message = "Email is not in correct format";
        return new EasyFieldValidator().patternValidator(/^\w+([\.-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,3})+$/, message);
    };
    EasyValidator.TelephoneNumber = function (message) {
        if (message == "" || message == null)
            message = "Telephone number is not in correct format";
        return new EasyFieldValidator().patternValidator(/^[(]{0,1}[0-9]{3}[)]{0,1}[-\s\.]{0,1}[0-9]{3}[-\s\.]{0,1}[0-9]{4}$/, message);
    };
    EasyValidator.IdentityNumber = function (message) {
        if (message == "" || message == null)
            message = "Identity number is not in correct format";
        return new EasyFieldValidator().patternValidator(/^([0-9]){2}([0-1][0-9])([0-3][0-9])([0-9]){4}([0-1])([0-9]){2}?$/, message);
    };
    return EasyValidator;
}());
var ContainerValidation = /** @class */ (function () {
    function ContainerValidation() {
    }
    ContainerValidation.prototype.validateContainerFields = function (fields) {
        var _this = this;
        var invalidFields = [];
        this.validateTableFields(fields, invalidFields);
        invalidFields.addRange(fields.filter(function (x) { return !_this.validateField(x); }));
        return { valid: invalidFields.length == 0, invalidFields: invalidFields };
    };
    ContainerValidation.prototype.validateTableFields = function (fields, invalidFields) {
        var _this = this;
        var tableFields = (fields.where(function (x) { return x.controlType == "table"; }));
        tableFields.forEach(function (x) {
            x.columns.forEach(function (field) {
                var validationResult = _this.validateField(field);
                if (!validationResult)
                    invalidFields.add(field);
            });
        });
    };
    ContainerValidation.prototype.validateField = function (field) {
        var result = true;
        if (field.value == null)
            field.value = "";
        field.value = field.value.toString().trim();
        if (field.hide) {
            result = true;
        }
        else if (!field.required && field.value == "") {
            result = true;
        }
        else if (field.easyValidators != null && field.easyValidators.any()) {
            result = this.runFieldValidation(field);
        }
        if (!result && field.easyValidators.any()) {
            field.pristine = false;
        }
        return result;
    };
    ContainerValidation.prototype.runFieldValidation = function (field) {
        try {
            for (var _a = __values(field.easyValidators), _b = _a.next(); !_b.done; _b = _a.next()) {
                var validator = _b.value;
                switch (validator.validatorType) {
                    case ValidatorType.required:
                        if (field.value == null || field.value == "" || field.value == "0")
                            return false;
                        break;
                    case ValidatorType.minlength:
                        if (field.value == null || field.value.length < validator.minlength)
                            return false;
                        break;
                    case ValidatorType.maxlength:
                        if (field.value == null || field.value.length > validator.maxlength)
                            return false;
                        break;
                    case ValidatorType.pattern:
                        var pattern = new RegExp(validator.pattern);
                        var result = pattern.test(field.value);
                        if (!result)
                            return result;
                        break;
                }
            }
        }
        catch (e_2_1) { e_2 = { error: e_2_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_2) throw e_2.error; }
        }
        return true;
        var e_2, _c;
    };
    return ContainerValidation;
}());
var EasyFieldValidator = /** @class */ (function () {
    function EasyFieldValidator() {
    }
    EasyFieldValidator.prototype.requiredValidator = function (message) {
        this.validatorType = ValidatorType.required;
        this.message = message;
        return this;
    };
    EasyFieldValidator.prototype.maxLengthValidator = function (length, message) {
        this.validatorType = ValidatorType.maxlength;
        this.maxlength = length;
        this.message = message;
        return this;
    };
    EasyFieldValidator.prototype.minLengthValidator = function (length, message) {
        this.validatorType = ValidatorType.minlength;
        this.minlength = length;
        this.message = message;
        return this;
    };
    EasyFieldValidator.prototype.patternValidator = function (pattern, message) {
        this.validatorType = ValidatorType.pattern;
        this.pattern = pattern;
        this.message = message;
        return this;
    };
    return EasyFieldValidator;
}());
var ValidatorType = /** @class */ (function () {
    function ValidatorType() {
    }
    return ValidatorType;
}());
ValidatorType.required = 'required';
ValidatorType.maxlength = 'maxlength';
ValidatorType.minlength = 'minlength';
ValidatorType.pattern = 'pattern';
var EasyField = /** @class */ (function () {
    function EasyField(options) {
        if (options === void 0) { options = {}; }
        this.value = "";
        this.selectedItem = "";
        this.key = "";
        this.hide = false;
        this.columnSpan = 1;
        this.validators = [];
        this.pristine = true;
        this.items = [];
        this.showPaginator = false;
        this.showFilter = false;
        this.url = "";
        this.options = {};
        this.subject = new Subject();
        this.onChange = this.subject.asObservable();
        this.options = options;
        this.type = options.type;
        this.controlType = options.controlType;
        this.value = options.value || '';
        this.key = options.key || '';
        this.label = options.label || '';
        this.required = !!options.required;
        this.order = options.order === undefined ? 1 : options.order;
        this.columnSpan = options.columnSpan || 1;
        this.xsColumnSize = options.xsColumnSize;
        this.smColumnSize = options.smColumnSize;
        this.mdColumnSize = options.mdColumnSize;
        this.lgColumnSize = options.lgColumnSize;
        this.xlColumnSize = options.xlColumnSize;
        this.hide = options.hide;
        this.readonly = options.readonly;
        this.maxLength = options.maxLength;
        this.validators = options.validators || [];
        this.updateAction = options.updateAction;
        this.skipFormValidation = options.skipFormValidation;
        this.items = options.items;
        this.action = options.action;
        this.showLoader = options.showLoader;
        this.hint = options.hint;
        this.onEnter = options.onEnter;
        this.showFilter = options.showFilter;
        this.showPaginator = options.showPaginator;
        this.url = options.url;
        this.marginLeft = options.marginLeft;
        this.marginRight = options.marginRight;
        this.format = options.format;
        this.width = options.width;
        this.minWidth = options.minWidth;
        this.maxWidth = options.maxWidth;
        this.textAlign = options.textAlign;
        this.height = options.height;
        this.minHeight = options.minHeight;
        this.maxHeight = options.maxHeight;
        this.allowedExtensions = options.allowedExtensions;
        this.addAdditionalProprtiesFromValidators();
    }
    Object.defineProperty(EasyField.prototype, "easyValidators", {
        get: function () {
            return this.validators;
        },
        enumerable: true,
        configurable: true
    });
    EasyField.prototype.addValidator = function (validator) {
        this.validators.add(validator);
        this.addAdditionalProprtiesFromValidators();
    };
    EasyField.prototype.addAdditionalProprtiesFromValidators = function () {
        if (this.maxLength == null || this.maxLength == 0) {
            if (this.validators != null && this.validators.length > 0) {
                var maxLengthValidator = this.validators.filter(function (x) { return x.validatorType == ValidatorType.maxlength; });
                if (maxLengthValidator.length > 0)
                    this.maxLength = maxLengthValidator[0].maxlength;
            }
        }
        if (this.required) {
            var requiredValidator = this.validators.singleOrDefault(function (x) { return x.validatorType == ValidatorType.required; });
            if (requiredValidator == null)
                this.validators.add(EasyValidator.Required(this.label + " is required"));
        }
        else {
            if (this.validators.any(function (x) { return x.validatorType == ValidatorType.required; }))
                this.required = true;
        }
    };
    EasyField.prototype.valueChanged = function (event) {
        this.valid = event.valid;
        this.value = event.value;
        this.pristine = false;
        this.selectedItem = event.selectedItem;
        this.subject.next(({ value: this.value, key: this.key, valid: this.valid, selectedItem: this.selectedItem }));
    };
    EasyField.mapFields = function (dto, fields) {
        Object.keys(dto).forEach(function (key) {
            var field = fields.singleOrDefault(function (x) { return x.key == key; });
            if (field != null)
                dto[key] = field.value;
        });
    };
    return EasyField;
}());
var EasyAutocompleteField = /** @class */ (function (_super) {
    __extends(EasyAutocompleteField, _super);
    function EasyAutocompleteField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'autocomplete';
        options.controlType = _this.controlType;
        return _this;
    }
    EasyAutocompleteField.prototype.setItems = function (items) {
        this.items = items;
    };
    return EasyAutocompleteField;
}(EasyField));
var EasyAutocompleteKeyValueField = /** @class */ (function (_super) {
    __extends(EasyAutocompleteKeyValueField, _super);
    function EasyAutocompleteKeyValueField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'autocomplete-key-value';
        options.controlType = _this.controlType;
        return _this;
    }
    EasyAutocompleteKeyValueField.prototype.setItems = function (items) {
        this.items = items;
    };
    return EasyAutocompleteKeyValueField;
}(EasyField));
var EasyInputField = /** @class */ (function (_super) {
    __extends(EasyInputField, _super);
    function EasyInputField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'textbox';
        options.controlType = _this.controlType;
        _this.type = options['type'] || '';
        return _this;
    }
    return EasyInputField;
}(EasyField));
var EasyRecordField = /** @class */ (function (_super) {
    __extends(EasyRecordField, _super);
    function EasyRecordField(url, options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'record';
        options.url = url;
        _this.url = url;
        _this.authorizationHeader = options.authorizationHeader;
        return _this;
    }
    return EasyRecordField;
}(EasyField));
var EasyCheckboxField = /** @class */ (function (_super) {
    __extends(EasyCheckboxField, _super);
    function EasyCheckboxField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'checkbox';
        options.controlType = _this.controlType;
        _this.type = options['type'] || '';
        _this.marginLeft = options.marginLeft;
        _this.marginTop = options.marginTop;
        _this.marginRight = options.marginRight;
        _this.marginBottom = options.marginBottom;
        return _this;
    }
    return EasyCheckboxField;
}(EasyField));
var EasyCheckBoxGroupField = /** @class */ (function (_super) {
    __extends(EasyCheckBoxGroupField, _super);
    function EasyCheckBoxGroupField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'checkbox-group';
        _this.type = options['type'] || [];
        return _this;
    }
    return EasyCheckBoxGroupField;
}(EasyField));
var EasyDatePickerField = /** @class */ (function (_super) {
    __extends(EasyDatePickerField, _super);
    function EasyDatePickerField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'date-picker';
        options.controlType = _this.controlType;
        return _this;
    }
    return EasyDatePickerField;
}(EasyField));
var EasySelectField = /** @class */ (function (_super) {
    __extends(EasySelectField, _super);
    function EasySelectField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'select';
        options.controlType = _this.controlType;
        return _this;
    }
    EasySelectField.prototype.setItems = function (items) {
        this.items = items;
    };
    return EasySelectField;
}(EasyField));
var EasySelectKeyValueField = /** @class */ (function (_super) {
    __extends(EasySelectKeyValueField, _super);
    function EasySelectKeyValueField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'select-key-value';
        options.controlType = _this.controlType;
        return _this;
    }
    EasySelectKeyValueField.prototype.setItems = function (items) {
        this.items = items;
    };
    return EasySelectKeyValueField;
}(EasyField));
var EasyTableField = /** @class */ (function (_super) {
    __extends(EasyTableField, _super);
    function EasyTableField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'table';
        _this.columns = [];
        _this.rows = [];
        _this.actions = [];
        _this.pageChangeSubject = new Subject();
        _this.onPageChange = _this.pageChangeSubject.asObservable();
        _this.pageIndex = options.pageIndex;
        _this.pageSize = options.pageSize;
        _this.totalItems = options.totalItems;
        return _this;
    }
    EasyTableField.prototype.addButton = function (label, action, options) {
        if (options === void 0) { options = {}; }
        options.action = action;
        options.label = label;
        this.actions.push(new EasyButtonField(options));
    };
    EasyTableField.prototype.addAction = function (label, action, options) {
        if (options === void 0) { options = {}; }
        options.action = action;
        options.label = label;
        this.actions.push(new EasyButtonField(options));
    };
    EasyTableField.prototype.addColumn = function (key, label, options) {
        if (options === void 0) { options = {}; }
        options.key = key;
        options.label = label;
        this.columns.push(new EasyField(options));
    };
    EasyTableField.prototype.addInputField = function (key, label, options) {
        if (options === void 0) { options = {}; }
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        var field = new EasyInputField(options);
        this.addField(field);
        return field;
    };
    EasyTableField.prototype.addSelectField = function (key, label, items, options) {
        if (options === void 0) { options = {}; }
        options.items = items;
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        var field = new EasySelectField(options);
        this.addField(field);
        return field;
    };
    EasyTableField.prototype.addAutocompleteKeyValueField = function (key, label, items, options) {
        if (options === void 0) { options = {}; }
        options.items = items;
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        var field = new EasyAutocompleteKeyValueField(options);
        this.addField(field);
        return field;
    };
    EasyTableField.prototype.addAutocompleteField = function (key, label, items, options) {
        if (options === void 0) { options = {}; }
        options.items = items;
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        var field = new EasyAutocompleteField(options);
        this.addField(field);
        return field;
    };
    EasyTableField.prototype.addFileUploadField = function (key, label, options) {
        if (options === void 0) { options = {}; }
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        var field = new EasyFileUploadField(options);
        this.addField(field);
        return field;
    };
    EasyTableField.prototype.addCheckboxField = function (key, label, options) {
        if (options === void 0) { options = {}; }
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        var field = new EasyCheckboxField(options);
        this.addField(field);
        return field;
    };
    EasyTableField.prototype.addSelectKeyValueField = function (key, label, items, options) {
        if (options === void 0) { options = {}; }
        options.items = items;
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        var field = new EasySelectKeyValueField(options);
        this.addField(field);
        return field;
    };
    EasyTableField.prototype.addRadioButtonField = function (key, label, items, options) {
        if (options === void 0) { options = {}; }
        options.items = items;
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        var field = new EasyRadioButtonField(options);
        this.addField(field);
        return field;
    };
    EasyTableField.prototype.addDatePickerField = function (key, label, options) {
        if (options === void 0) { options = {}; }
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        var field = new EasyDatePickerField(options);
        this.addField(field);
        return field;
    };
    EasyTableField.prototype.addTextLabelField = function (key, label, options) {
        if (options === void 0) { options = {}; }
        options.key = key;
        options.label = label;
        options.type = ColumnTypes.column_type_control;
        options.readonly = true;
        var field = new EasyInputField(options);
        this.addField(field);
        return field;
    };
    EasyTableField.prototype.addField = function (field) {
        this.setDefaultKey(field);
        this.columns.push(field);
    };
    EasyTableField.prototype.setDefaultKey = function (field) {
        if (field.key == "") {
            var similarFields = this.columns.filter(function (x) { return x.controlType == field.controlType; });
            field.key = field.controlType + "_" + similarFields.length;
        }
    };
    EasyTableField.prototype.setRows = function (rows) {
        this.rows = rows;
    };
    EasyTableField.prototype.addRows = function (rows) {
        try {
            for (var rows_1 = __values(rows), rows_1_1 = rows_1.next(); !rows_1_1.done; rows_1_1 = rows_1.next()) {
                var row = rows_1_1.value;
                this.rows.push(row);
            }
        }
        catch (e_3_1) { e_3 = { error: e_3_1 }; }
        finally {
            try {
                if (rows_1_1 && !rows_1_1.done && (_a = rows_1.return)) _a.call(rows_1);
            }
            finally { if (e_3) throw e_3.error; }
        }
        var e_3, _a;
    };
    EasyTableField.prototype.pageChanged = function (event) {
        this.pageIndex = event.pageIndex;
        this.pageSize = event.pageSize;
        this.totalItems = event.length;
        this.pageChangeSubject.next(({ columns: this.columns, rows: this.rows, actions: this.actions, pageIndex: this.pageIndex, pageSize: this.pageSize, totalItems: this.totalItems }));
    };
    return EasyTableField;
}(EasyField));
var EasyButtonField = /** @class */ (function (_super) {
    __extends(EasyButtonField, _super);
    function EasyButtonField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'button';
        _this.action = options.action;
        _this.color = options.color || '';
        _this.icon = options.icon || '';
        _this.type = options.type || 'mat-button';
        return _this;
    }
    return EasyButtonField;
}(EasyField));
var EasyTextAreaField = /** @class */ (function (_super) {
    __extends(EasyTextAreaField, _super);
    function EasyTextAreaField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'textArea';
        _this.type = options['type'] || '';
        return _this;
    }
    return EasyTextAreaField;
}(EasyField));
var EasyRadioButtonField = /** @class */ (function (_super) {
    __extends(EasyRadioButtonField, _super);
    function EasyRadioButtonField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'radio-button';
        options.controlType = _this.controlType;
        return _this;
    }
    return EasyRadioButtonField;
}(EasyField));
var EasyFileUploadField = /** @class */ (function (_super) {
    __extends(EasyFileUploadField, _super);
    function EasyFileUploadField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'fileupload';
        _this.key = '';
        _this.icon = '';
        _this.color = '';
        _this.hint = '';
        _this.allowedExtensions = '';
        _this.type = options.type || ButtonTypes.button_icon;
        _this.key = options.key || '';
        _this.icon = options.icon || Icons.icon_attach_file;
        _this.color = options.color || "";
        _this.hint = options.hint || '';
        _this.allowedExtensions = options.allowedExtensions || '';
        options.controlType = _this.controlType;
        return _this;
    }
    return EasyFileUploadField;
}(EasyField));
var EasyDateTimePickerField = /** @class */ (function (_super) {
    __extends(EasyDateTimePickerField, _super);
    function EasyDateTimePickerField(options) {
        var _this = _super.call(this, options) || this;
        _this.controlType = 'date-time-picker';
        options.controlType = _this.controlType;
        return _this;
    }
    return EasyDateTimePickerField;
}(EasyField));
var EasyDividerField = /** @class */ (function (_super) {
    __extends(EasyDividerField, _super);
    function EasyDividerField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'divider';
        options.controlType = _this.controlType;
        return _this;
    }
    return EasyDividerField;
}(EasyField));
var EasyContainer = /** @class */ (function (_super) {
    __extends(EasyContainer, _super);
    function EasyContainer(header, options, form, controlType) {
        var _this = _super.call(this) || this;
        _this.header = header;
        _this.useGrid = false;
        _this.fields = [];
        _this.actions = [];
        _this.show = true;
        _this.containers = [];
        _this.xsColumnSize = "100%";
        _this.smColumnSize = "100%";
        _this.mdColumnSize = "100%";
        _this.lgColumnSize = "100%";
        _this.xlColumnSize = "100%";
        _this.xsSize = "100%";
        _this.smSize = "100%";
        _this.mdSize = "100%";
        _this.lgSize = "100%";
        _this.xlSize = "100%";
        _this.order = 0;
        _this.controlType = controlType;
        _this.useGrid = _this.fields.filter(function (x) { return x.controlType == 'table'; }).length == 0;
        _this.form = form;
        _this.order = options.order || 0;
        _this.xsColumnSize = options.xsColumnSize || "100%";
        _this.smColumnSize = options.smColumnSize || "100%";
        _this.mdColumnSize = options.mdColumnSize || "100%";
        _this.lgColumnSize = options.lgColumnSize || "100%";
        _this.xlColumnSize = options.xlColumnSize || "100%";
        _this.xsSize = options.xsSize || "100%";
        _this.smSize = options.smSize || "100%";
        _this.mdSize = options.mdSize || "100%";
        _this.lgSize = options.lgSize || "100%";
        _this.xlSize = options.xlSize || "100%";
        _this.marginRight = options.marginRight || "";
        _this.marginLeft = options.marginLeft || "";
        _this.paddingLeft = options.paddingLeft || "";
        _this.paddingRight = options.paddingRight || "";
        _this.show = !options.hide;
        return _this;
    }
    EasyContainer.prototype.validateFields = function () {
        return _super.prototype.validateContainerFields.call(this, this.fields);
    };
    EasyContainer.prototype.showContainer = function () {
        this.show = true;
    };
    EasyContainer.prototype.hideContainer = function () {
        this.show = false;
    };
    EasyContainer.prototype.addContainer = function (container) {
        this.containers.add(container);
    };
    EasyContainer.prototype.getXlColumnSize = function (field) {
        if (field.xlColumnSize == null || field.xlColumnSize == "")
            return this.xlColumnSize;
        return field.xlColumnSize;
    };
    EasyContainer.prototype.getLgColumnSize = function (field) {
        if (field.lgColumnSize == null || field.lgColumnSize == "")
            return this.lgColumnSize;
        return field.lgColumnSize;
    };
    EasyContainer.prototype.getMdColumnSize = function (field) {
        if (field.mdColumnSize == null || field.mdColumnSize == "")
            return this.mdColumnSize;
        return field.mdColumnSize;
    };
    EasyContainer.prototype.getSmColumnSize = function (field) {
        if (field.smColumnSize == null || field.smColumnSize == "")
            return this.smColumnSize;
        return field.smColumnSize;
    };
    EasyContainer.prototype.getXsColumnSize = function (field) {
        if (field.xsColumnSize == null || field.xsColumnSize == "")
            return this.xsColumnSize;
        return field.xsColumnSize;
    };
    EasyContainer.prototype.addField = function (field) {
        this.form.setDefaultKey(field);
        this.fields.push(field);
        this.form.addField(field);
    };
    EasyContainer.prototype.addActionField = function (field) {
        this.form.setDefaultKey(field);
        this.actions.push(field);
        this.form.addField(field);
    };
    EasyContainer.prototype.addAutocompleteKeyValueField = function (label, items, options) {
        if (options === void 0) { options = {}; }
        options.items = items;
        options.label = label;
        var field = new EasyAutocompleteKeyValueField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addAutocompleteField = function (label, items, options) {
        if (options === void 0) { options = {}; }
        options.items = items;
        options.label = label;
        var field = new EasyAutocompleteField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addInputField = function (label, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        var field = new EasyInputField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addFileUploadField = function (label, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        var field = new EasyFileUploadField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addRecordField = function (url, options) {
        if (options === void 0) { options = {}; }
        var field = new EasyRecordField(url, options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addTextAreaField = function (label, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        var field = new EasyTextAreaField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addTableField = function (options) {
        if (options === void 0) { options = {}; }
        var field = new EasyTableField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addCheckBoxField = function (label, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        var field = new EasyCheckboxField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addCheckBoxGroupField = function (label, items, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        options.items = items;
        var field = new EasyCheckBoxGroupField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addSelectField = function (label, items, options) {
        if (options === void 0) { options = {}; }
        options.items = items;
        options.label = label;
        var field = new EasySelectField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addSelectKeyValueField = function (label, items, options) {
        if (options === void 0) { options = {}; }
        options.items = items;
        options.label = label;
        var field = new EasySelectKeyValueField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addRadioButtonField = function (label, items, options) {
        if (options === void 0) { options = {}; }
        options.items = items;
        options.label = label;
        var field = new EasyRadioButtonField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addButtonField = function (label, action, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        options.action = action;
        var field = new EasyButtonField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addDividerField = function (options) {
        if (options === void 0) { options = {}; }
        var field = new EasyDividerField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addAction = function (label, action, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        options.action = action;
        var field = new EasyButtonField(options);
        this.addActionField(field);
        return field;
    };
    EasyContainer.prototype.addDatePickerField = function (label, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        var field = new EasyDatePickerField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addDateTimePickerField = function (label, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        var field = new EasyDateTimePickerField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addLabelField = function (label, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        options.readonly = true;
        var field = new EasyInputField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.addTextLabelField = function (label, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        options.readonly = true;
        var field = new EasyInputField(options);
        this.addField(field);
        return field;
    };
    EasyContainer.prototype.mapFields = function (dto) {
        var _this = this;
        Object.keys(dto).forEach(function (key) {
            var field = _this.fetchField(key);
            if (field != null)
                dto[key] = field.value;
        });
    };
    EasyContainer.prototype.mapFieldsFromDto = function (dto) {
        var _this = this;
        Object.keys(dto).forEach(function (key) {
            var field = _this.fetchField(key);
            if (field != null)
                field.value = dto[key];
        });
    };
    EasyContainer.prototype.fetchField = function (key) {
        var field = this.fields.singleOrDefault(function (x) { return x.key == key; });
        return field;
    };
    return EasyContainer;
}(ContainerValidation));
var ModalContainer = /** @class */ (function (_super) {
    __extends(ModalContainer, _super);
    function ModalContainer() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ModalContainer.prototype.addField = function (field) {
        this.form.setDefaultKey(field);
        this.fields.push(field);
    };
    return ModalContainer;
}(EasyContainer));
var EasyCardField = /** @class */ (function (_super) {
    __extends(EasyCardField, _super);
    function EasyCardField(header, options, form) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, header, options, form, 'card') || this;
        _this.controlType = 'card';
        return _this;
    }
    EasyCardField.prototype.addCardContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyCardField(header, options, this.form);
        this.addContainer(container);
        return container;
    };
    EasyCardField.prototype.addTabContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var tabs = new EasyTabField(this.form, options);
        this.addContainer(tabs);
        return tabs;
    };
    EasyCardField.prototype.addAccordionContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var accordion = new EasyAccordionField(this.form, options);
        this.addContainer(accordion);
        return accordion;
    };
    EasyCardField.prototype.addExpansionPanelContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyExpansionPanelField(header, options, this.form);
        this.addContainer(container);
        return container;
    };
    return EasyCardField;
}(EasyContainer));
var EasyAccordionField = /** @class */ (function (_super) {
    __extends(EasyAccordionField, _super);
    function EasyAccordionField(form, options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, "", options, form, 'accordion') || this;
        _this.controlType = 'accordion';
        _this.form = form;
        return _this;
    }
    EasyAccordionField.prototype.addExpansionPanel = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyExpansionPanelField(header, options, this.form);
        this.containers.add(container);
        return container;
    };
    return EasyAccordionField;
}(EasyContainer));
var EasyToolbarTextField = /** @class */ (function (_super) {
    __extends(EasyToolbarTextField, _super);
    function EasyToolbarTextField(options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, options) || this;
        _this.controlType = 'toolbar-text';
        _this.color = options.color || '';
        _this.icon = options.icon || '';
        return _this;
    }
    return EasyToolbarTextField;
}(EasyField));
var EasyExpansionPanelField = /** @class */ (function (_super) {
    __extends(EasyExpansionPanelField, _super);
    function EasyExpansionPanelField(header, options, form) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, header, options, form, 'expansion-panel') || this;
        _this.controlType = 'expansion-panel';
        return _this;
    }
    EasyExpansionPanelField.prototype.addCardContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyCardField(header, options, this.form);
        this.addContainer(container);
        return container;
    };
    EasyExpansionPanelField.prototype.addTabContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var tabs = new EasyTabField(this.form, options);
        this.addContainer(tabs);
        return tabs;
    };
    EasyExpansionPanelField.prototype.addAccordionContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var accordion = new EasyAccordionField(this.form, options);
        this.addContainer(accordion);
        return accordion;
    };
    EasyExpansionPanelField.prototype.addExpansionPanelContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyExpansionPanelField(header, options, this.form);
        this.addContainer(container);
        return container;
    };
    return EasyExpansionPanelField;
}(EasyContainer));
var EasyTabField = /** @class */ (function (_super) {
    __extends(EasyTabField, _super);
    function EasyTabField(form, options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, "", options, form, 'tabs') || this;
        _this.controlType = 'tabs';
        _this.form = form;
        return _this;
    }
    EasyTabField.prototype.addTabToTabContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyCardField(header, options, this.form);
        this.addContainer(container);
        return container;
    };
    return EasyTabField;
}(EasyContainer));
var EasyToolbar = /** @class */ (function () {
    function EasyToolbar(form) {
        this.form = form;
        this.fields = [];
        this.menus = [];
    }
    EasyToolbar.prototype.addButtonField = function (label, action, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        options.action = action;
        var field = new EasyButtonField(options);
        this.addField(field);
        return field;
    };
    EasyToolbar.prototype.addTextField = function (label, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        var field = new EasyToolbarTextField(options);
        this.addField(field);
        return field;
    };
    EasyToolbar.prototype.addField = function (field) {
        this.form.setDefaultKey(field);
        this.fields.push(field);
        this.form.addField(field);
    };
    EasyToolbar.prototype.addMenu = function (fields) {
        this.menus.add(fields);
    };
    return EasyToolbar;
}());
var EasyToolbarContainer = /** @class */ (function () {
    function EasyToolbarContainer() {
        this.toolbars = [];
    }
    EasyToolbarContainer.prototype.addToolBar = function (form) {
        var toolbar = new EasyToolbar(form);
        this.toolbars.push(toolbar);
        return toolbar;
    };
    return EasyToolbarContainer;
}());
var EasyCardField$1 = /** @class */ (function (_super) {
    __extends(EasyCardField$1, _super);
    function EasyCardField$1(header, options, form) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, header, options, form, 'card') || this;
        _this.controlType = 'card';
        return _this;
    }
    EasyCardField$1.prototype.addCardContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyCardField$1(header, options, this.form);
        this.addContainer(container);
        return container;
    };
    EasyCardField$1.prototype.addTabContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var tabs = new EasyTabField(this.form, options);
        this.addContainer(tabs);
        return tabs;
    };
    EasyCardField$1.prototype.addAccordionContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var accordion = new EasyAccordionField(this.form, options);
        this.addContainer(accordion);
        return accordion;
    };
    EasyCardField$1.prototype.addExpansionPanelContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyExpansionPanelField(header, options, this.form);
        this.addContainer(container);
        return container;
    };
    return EasyCardField$1;
}(EasyContainer));
var EasyExpansionPanelField$1 = /** @class */ (function (_super) {
    __extends(EasyExpansionPanelField$1, _super);
    function EasyExpansionPanelField$1(header, options, form) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, header, options, form, 'expansion-panel') || this;
        _this.controlType = 'expansion-panel';
        return _this;
    }
    EasyExpansionPanelField$1.prototype.addCardContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyCardField(header, options, this.form);
        this.addContainer(container);
        return container;
    };
    EasyExpansionPanelField$1.prototype.addTabContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var tabs = new EasyTabField(this.form, options);
        this.addContainer(tabs);
        return tabs;
    };
    EasyExpansionPanelField$1.prototype.addAccordionContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var accordion = new EasyAccordionField(this.form, options);
        this.addContainer(accordion);
        return accordion;
    };
    EasyExpansionPanelField$1.prototype.addExpansionPanelContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyExpansionPanelField$1(header, options, this.form);
        this.addContainer(container);
        return container;
    };
    return EasyExpansionPanelField$1;
}(EasyContainer));
var EasyStepperField = /** @class */ (function (_super) {
    __extends(EasyStepperField, _super);
    function EasyStepperField(form, options) {
        if (options === void 0) { options = {}; }
        var _this = _super.call(this, "", options, form, 'stepper') || this;
        _this.controlType = 'stepper';
        _this.form = form;
        return _this;
    }
    EasyStepperField.prototype.addStepToStepperContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyCardField(header, options, this.form);
        this.addContainer(container);
        return container;
    };
    return EasyStepperField;
}(EasyContainer));
var FieldWithSameKeyAlreadyExistsException = /** @class */ (function () {
    function FieldWithSameKeyAlreadyExistsException(message) {
        this.message = message;
    }
    FieldWithSameKeyAlreadyExistsException.prototype.toString = function () {
        return "FieldWithSameKeyAlreadyExistsException " + this.message;
    };
    return FieldWithSameKeyAlreadyExistsException;
}());
var FieldWithKeyDoesNotExistException = /** @class */ (function () {
    function FieldWithKeyDoesNotExistException(message) {
        this.message = message;
    }
    FieldWithKeyDoesNotExistException.prototype.toString = function () {
        return "FieldWithKeyDoesNotExistException " + this.message;
    };
    return FieldWithKeyDoesNotExistException;
}());
var MultipleFieldsWithSameKeyExistException = /** @class */ (function () {
    function MultipleFieldsWithSameKeyExistException(message) {
        this.message = message;
    }
    MultipleFieldsWithSameKeyExistException.prototype.toString = function () {
        return "MultipleFieldsWithSameKeyExistException " + this.message;
    };
    return MultipleFieldsWithSameKeyExistException;
}());
var EasyForm = /** @class */ (function () {
    function EasyForm() {
        this.toolbarContainers = [];
        this.containers = [];
        this.subscriptions = [];
        this.fields = [];
        this.data = {};
        this.xsSize = "100%";
        this.smSize = "100%";
        this.mdSize = "80%";
        this.lgSize = "60%";
        this.xlSize = "60%";
        this.actions = [];
        this.layout = "space-between center";
    }
    EasyForm.prototype.getContainers = function () {
        return this.containers.orderBy(function (x) { return x.order; });
    };
    EasyForm.prototype.setSize = function (size) {
        this.mdSize = size;
        this.lgSize = size;
        this.xlSize = size;
    };
    EasyForm.prototype.setLayout = function (layout) {
        this.layout = layout;
    };
    EasyForm.prototype.addAction = function (label, action, options) {
        if (options === void 0) { options = {}; }
        options.label = label;
        options.action = action;
        var field = new EasyButtonField(options);
        this.actions.push(field);
        return field;
    };
    EasyForm.prototype.addCardContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var container = new EasyCardField$1(header, options, this);
        this.addContainer(container);
        return container;
    };
    EasyForm.prototype.addTabContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var tabs = new EasyTabField(this, options);
        this.addContainer(tabs);
        return tabs;
    };
    EasyForm.prototype.addStepperContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var tabs = new EasyStepperField(this, options);
        this.addContainer(tabs);
        return tabs;
    };
    EasyForm.prototype.addAccordionContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var accordion = new EasyAccordionField(this, options);
        this.addContainer(accordion);
        return accordion;
    };
    EasyForm.prototype.addExpansionPanelContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var tabs = new EasyExpansionPanelField$1(header, options, this);
        this.addContainer(tabs);
        return tabs;
    };
    EasyForm.prototype.addModalContainer = function (header, options) {
        if (options === void 0) { options = {}; }
        var subContainer = new ModalContainer(header, options, this, "modal");
        return subContainer;
    };
    EasyForm.prototype.addToolBarContainer = function () {
        var easyToolbarContainer = new EasyToolbarContainer();
        this.toolbarContainers.push(easyToolbarContainer);
        var toolbar = easyToolbarContainer.addToolBar(this);
        return toolbar;
    };
    EasyForm.prototype.validateForm = function () {
        var invalidFields = this.validateContainers(this.containers);
        return { valid: invalidFields.length == 0, invalidFields: invalidFields };
    };
    EasyForm.prototype.validateContainers = function (containers) {
        var invalidFields = [];
        try {
            for (var containers_1 = __values(containers), containers_1_1 = containers_1.next(); !containers_1_1.done; containers_1_1 = containers_1.next()) {
                var container = containers_1_1.value;
                var validationResult = container.validateFields();
                invalidFields.addRange(validationResult.invalidFields);
                invalidFields.addRange(this.validateContainers(container.containers));
            }
        }
        catch (e_4_1) { e_4 = { error: e_4_1 }; }
        finally {
            try {
                if (containers_1_1 && !containers_1_1.done && (_a = containers_1.return)) _a.call(containers_1);
            }
            finally { if (e_4) throw e_4.error; }
        }
        return invalidFields;
        var e_4, _a;
    };
    EasyForm.prototype.addContainer = function (container) {
        var _this = this;
        this.containers.push(container);
        this.addSubscriptions(container.fields);
        this.addFields(container.fields);
        if (container.containers != null && container.containers.any()) {
            container.containers.forEach(function (x) { return _this.addContainer(x); });
        }
    };
    EasyForm.prototype.addSubscriptions = function (fields) {
        var _this = this;
        try {
            for (var fields_1 = __values(fields), fields_1_1 = fields_1.next(); !fields_1_1.done; fields_1_1 = fields_1.next()) {
                var field = fields_1_1.value;
                var subscription = field.onChange.subscribe(function (x) {
                    _this.updateField(x);
                    if (_this.data != null) {
                        Object.keys(_this.data).forEach(function (key) {
                            var field = _this.fields.singleOrDefault(function (x) { return x.key == key; });
                            if (field != null)
                                _this.data[key] = field.value;
                        });
                    }
                });
                this.subscriptions.push(subscription);
            }
        }
        catch (e_5_1) { e_5 = { error: e_5_1 }; }
        finally {
            try {
                if (fields_1_1 && !fields_1_1.done && (_a = fields_1.return)) _a.call(fields_1);
            }
            finally { if (e_5) throw e_5.error; }
        }
        var e_5, _a;
    };
    EasyForm.prototype.addFields = function (fields) {
        var _this = this;
        fields.forEach(function (x) { return _this.addField(x); });
    };
    EasyForm.prototype.mapFields = function (dto) {
        var _this = this;
        Object.keys(dto).forEach(function (key) {
            var field = _this.fetchField(key);
            if (field != null)
                dto[key] = field.value;
        });
    };
    EasyForm.prototype.fetchField = function (key) {
        var fields = this.fields.filter(function (x) { return x.key == key; });
        if (fields.length > 1)
            throw new MultipleFieldsWithSameKeyExistException(key);
        if (fields.length == 0)
            return null;
        return fields[0];
    };
    EasyForm.prototype.fetchFieldValue = function (key) {
        var fields = this.fields.filter(function (x) { return x.key == key; });
        if (fields.length > 1)
            throw new MultipleFieldsWithSameKeyExistException(key);
        if (fields.length == 0)
            return null;
        return fields[0].value;
    };
    EasyForm.prototype.addField = function (field) {
        if (field.controlType == "button")
            return;
        this.checkFieldAlreadyExists(field.key);
        this.fields.push(field);
        this.addSubscription(field);
    };
    EasyForm.prototype.checkFieldAlreadyExists = function (key) {
        var existingFields = this.fields.filter(function (x) { return x.key == key; });
        if (existingFields.length > 0)
            throw new FieldWithSameKeyAlreadyExistsException(key);
    };
    EasyForm.prototype.addSubscription = function (field) {
        var _this = this;
        var subscription = field.onChange.subscribe(function (x) {
            _this.updateField(x);
        });
    };
    EasyForm.prototype.updateField = function (field) {
        var fields = this.fields.filter(function (x) { return x.key == field.key; });
        if (fields.length > 1)
            throw new MultipleFieldsWithSameKeyExistException(field.key);
        if (fields.length == 0)
            throw new FieldWithKeyDoesNotExistException(field.key);
        fields[0].value = field.value;
        if (fields[0].updateAction != null)
            fields[0].updateAction(field);
    };
    EasyForm.prototype.setDefaultKey = function (field) {
        if (field.key == "") {
            var similarFields = this.fields.filter(function (x) { return x.controlType == field.controlType; });
            field.key = field.controlType + "_" + similarFields.length;
        }
    };
    EasyForm.prototype.setData = function (data) {
        var _this = this;
        if (data != null) {
            this.data = data;
            Object.keys(this.data).forEach(function (key) {
                var field = _this.fetchField(key);
                if (field != null)
                    field.value = _this.data[key];
            });
        }
    };
    EasyForm.prototype.enableReadonlyMode = function () {
        this.containers.forEach(function (x) {
            x.readonly = true;
        });
    };
    EasyForm.prototype.disableReadonlyMode = function () {
        this.containers.forEach(function (x) {
            x.readonly = false;
        });
    };
    EasyForm.prototype.ngOnDestroy = function () {
        try {
            for (var _a = __values(this.subscriptions), _b = _a.next(); !_b.done; _b = _a.next()) {
                var subscription = _b.value;
                subscription.unsubscribe();
            }
        }
        catch (e_6_1) { e_6 = { error: e_6_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_6) throw e_6.error; }
        }
        var e_6, _c;
    };
    return EasyForm;
}());
var ButtonTypes = /** @class */ (function () {
    function ButtonTypes() {
    }
    return ButtonTypes;
}());
ButtonTypes.button_mini_fab = 'mat-mini-fab';
ButtonTypes.button_fab = 'mat-fab';
ButtonTypes.button_raised = 'mat-raised-button';
ButtonTypes.button_flat = 'mat-button';
ButtonTypes.button_toolbar = 'mat-button-toolbar';
ButtonTypes.button_icon = 'mat-icon-button';
ButtonTypes.button_menu_item = 'mat-menu-item';
var Colors = /** @class */ (function () {
    function Colors() {
    }
    return Colors;
}());
Colors.color_primary = 'primary';
Colors.color_accent = 'accent';
Colors.color_warn = 'warn';
var ColumnTypes = /** @class */ (function () {
    function ColumnTypes() {
    }
    return ColumnTypes;
}());
ColumnTypes.column_type_hidden = 'hidden';
ColumnTypes.column_type_date = 'date';
ColumnTypes.column_type_actions = 'actions';
ColumnTypes.column_type_control = 'control';
ColumnTypes.column_type_checkbox = 'checkbox';
var DateFormats = /** @class */ (function () {
    function DateFormats() {
    }
    return DateFormats;
}());
DateFormats.date_format_medium = 'medium';
DateFormats.date_format_short = 'short';
DateFormats.date_format_fullDate = 'fullDate';
DateFormats.date_format_longDate = 'longDate';
DateFormats.date_format_mediumDate = 'mediumDate';
DateFormats.date_format_shortDate = 'shortDate';
DateFormats.date_format_mediumTime = 'mediumTime';
DateFormats.date_format_shortTime = 'shortTime';
DateFormats.date_format_ddMMyyyy = 'dd/MM/yyyy';
DateFormats.date_format_yyyyMMdd = 'yyyy/MM/dd';
var FieldOptions = /** @class */ (function () {
    function FieldOptions() {
        this.order = 0;
        this.items = [];
    }
    return FieldOptions;
}());
var FieldChangeDto = /** @class */ (function () {
    function FieldChangeDto(key, value, valid, selectedItem) {
        if (value === void 0) { value = ""; }
        if (selectedItem === void 0) { selectedItem = ""; }
        this.key = key;
        this.value = value;
        this.valid = valid;
        this.selectedItem = selectedItem;
    }
    return FieldChangeDto;
}());
var FileUploadOptions = /** @class */ (function () {
    function FileUploadOptions() {
        this.hasBaseDropZoneOver = false;
        this.hasAnotherDropZoneOver = false;
        this.url = "";
        this.authToken = "";
        this.itemAlias = "";
    }
    return FileUploadOptions;
}());
var Icons = /** @class */ (function () {
    function Icons() {
    }
    return Icons;
}());
Icons.icon_3d_rotation = '3d_rotation';
Icons.icon_ac_unit = 'ac_unit';
Icons.icon_access_alarm = 'access_alarm';
Icons.icon_access_alarms = 'access_alarms';
Icons.icon_access_time = 'access_time';
Icons.icon_accessibility = 'accessibility';
Icons.icon_accessible = 'accessible';
Icons.icon_account_balance = 'account_balance';
Icons.icon_account_balance_wallet = 'account_balance_wallet';
Icons.icon_account_box = 'account_box';
Icons.icon_account_circle = 'account_circle';
Icons.icon_adb = 'adb';
Icons.icon_add = 'add';
Icons.icon_add_a_photo = 'add_a_photo';
Icons.icon_add_alarm = 'add_alarm';
Icons.icon_add_alert = 'add_alert';
Icons.icon_add_box = 'add_box';
Icons.icon_add_circle = 'add_circle';
Icons.icon_add_circle_outline = 'add_circle_outline';
Icons.icon_add_location = 'add_location';
Icons.icon_add_shopping_cart = 'add_shopping_cart';
Icons.icon_add_to_photos = 'add_to_photos';
Icons.icon_add_to_queue = 'add_to_queue';
Icons.icon_adjust = 'adjust';
Icons.icon_airline_seat_flat = 'airline_seat_flat';
Icons.icon_airline_seat_flat_angled = 'airline_seat_flat_angled';
Icons.icon_airline_seat_individual_suite = 'airline_seat_individual_suite';
Icons.icon_airline_seat_legroom_extra = 'airline_seat_legroom_extra';
Icons.icon_airline_seat_legroom_normal = 'airline_seat_legroom_normal';
Icons.icon_airline_seat_legroom_reduced = 'airline_seat_legroom_reduced';
Icons.icon_airline_seat_recline_extra = 'airline_seat_recline_extra';
Icons.icon_airline_seat_recline_normal = 'airline_seat_recline_normal';
Icons.icon_airplanemode_active = 'airplanemode_active';
Icons.icon_airplanemode_inactive = 'airplanemode_inactive';
Icons.icon_airplay = 'airplay';
Icons.icon_airport_shuttle = 'airport_shuttle';
Icons.icon_alarm = 'alarm';
Icons.icon_alarm_add = 'alarm_add';
Icons.icon_alarm_off = 'alarm_off';
Icons.icon_alarm_on = 'alarm_on';
Icons.icon_album = 'album';
Icons.icon_all_inclusive = 'all_inclusive';
Icons.icon_all_out = 'all_out';
Icons.icon_android = 'android';
Icons.icon_announcement = 'announcement';
Icons.icon_apps = 'apps';
Icons.icon_archive = 'archive';
Icons.icon_arrow_back = 'arrow_back';
Icons.icon_arrow_downward = 'arrow_downward';
Icons.icon_arrow_drop_down = 'arrow_drop_down';
Icons.icon_arrow_drop_down_circle = 'arrow_drop_down_circle';
Icons.icon_arrow_drop_up = 'arrow_drop_up';
Icons.icon_arrow_forward = 'arrow_forward';
Icons.icon_arrow_upward = 'arrow_upward';
Icons.icon_art_track = 'art_track';
Icons.icon_aspect_ratio = 'aspect_ratio';
Icons.icon_assessment = 'assessment';
Icons.icon_assignment = 'assignment';
Icons.icon_assignment_ind = 'assignment_ind';
Icons.icon_assignment_late = 'assignment_late';
Icons.icon_assignment_return = 'assignment_return';
Icons.icon_assignment_returned = 'assignment_returned';
Icons.icon_assignment_turned_in = 'assignment_turned_in';
Icons.icon_assistant = 'assistant';
Icons.icon_assistant_photo = 'assistant_photo';
Icons.icon_attach_file = 'attach_file';
Icons.icon_attach_money = 'attach_money';
Icons.icon_attachment = 'attachment';
Icons.icon_audiotrack = 'audiotrack';
Icons.icon_autorenew = 'autorenew';
Icons.icon_av_timer = 'av_timer';
Icons.icon_backspace = 'backspace';
Icons.icon_backup = 'backup';
Icons.icon_battery_alert = 'battery_alert';
Icons.icon_battery_charging_full = 'battery_charging_full';
Icons.icon_battery_full = 'battery_full';
Icons.icon_battery_std = 'battery_std';
Icons.icon_battery_unknown = 'battery_unknown';
Icons.icon_beach_access = 'beach_access';
Icons.icon_beenhere = 'beenhere';
Icons.icon_block = 'block';
Icons.icon_bluetooth = 'bluetooth';
Icons.icon_bluetooth_audio = 'bluetooth_audio';
Icons.icon_bluetooth_connected = 'bluetooth_connected';
Icons.icon_bluetooth_disabled = 'bluetooth_disabled';
Icons.icon_bluetooth_searching = 'bluetooth_searching';
Icons.icon_blur_circular = 'blur_circular';
Icons.icon_blur_linear = 'blur_linear';
Icons.icon_blur_off = 'blur_off';
Icons.icon_blur_on = 'blur_on';
Icons.icon_book = 'book';
Icons.icon_bookmark = 'bookmark';
Icons.icon_bookmark_border = 'bookmark_border';
Icons.icon_border_all = 'border_all';
Icons.icon_border_bottom = 'border_bottom';
Icons.icon_border_clear = 'border_clear';
Icons.icon_border_color = 'border_color';
Icons.icon_border_horizontal = 'border_horizontal';
Icons.icon_border_inner = 'border_inner';
Icons.icon_border_left = 'border_left';
Icons.icon_border_outer = 'border_outer';
Icons.icon_border_right = 'border_right';
Icons.icon_border_style = 'border_style';
Icons.icon_border_top = 'border_top';
Icons.icon_border_vertical = 'border_vertical';
Icons.icon_branding_watermark = 'branding_watermark';
Icons.icon_brightness_1 = 'brightness_1';
Icons.icon_brightness_2 = 'brightness_2';
Icons.icon_brightness_3 = 'brightness_3';
Icons.icon_brightness_4 = 'brightness_4';
Icons.icon_brightness_5 = 'brightness_5';
Icons.icon_brightness_6 = 'brightness_6';
Icons.icon_brightness_7 = 'brightness_7';
Icons.icon_brightness_auto = 'brightness_auto';
Icons.icon_brightness_high = 'brightness_high';
Icons.icon_brightness_low = 'brightness_low';
Icons.icon_brightness_medium = 'brightness_medium';
Icons.icon_broken_image = 'broken_image';
Icons.icon_brush = 'brush';
Icons.icon_bubble_chart = 'bubble_chart';
Icons.icon_bug_report = 'bug_report';
Icons.icon_build = 'build';
Icons.icon_burst_mode = 'burst_mode';
Icons.icon_business = 'business';
Icons.icon_business_center = 'business_center';
Icons.icon_cached = 'cached';
Icons.icon_cake = 'cake';
Icons.icon_call = 'call';
Icons.icon_call_end = 'call_end';
Icons.icon_call_made = 'call_made';
Icons.icon_call_merge = 'call_merge';
Icons.icon_call_missed = 'call_missed';
Icons.icon_call_missed_outgoing = 'call_missed_outgoing';
Icons.icon_call_received = 'call_received';
Icons.icon_call_split = 'call_split';
Icons.icon_call_to_action = 'call_to_action';
Icons.icon_camera = 'camera';
Icons.icon_camera_alt = 'camera_alt';
Icons.icon_camera_enhance = 'camera_enhance';
Icons.icon_camera_front = 'camera_front';
Icons.icon_camera_rear = 'camera_rear';
Icons.icon_camera_roll = 'camera_roll';
Icons.icon_cancel = 'cancel';
Icons.icon_card_giftcard = 'card_giftcard';
Icons.icon_card_membership = 'card_membership';
Icons.icon_card_travel = 'card_travel';
Icons.icon_casino = 'casino';
Icons.icon_cast = 'cast';
Icons.icon_cast_connected = 'cast_connected';
Icons.icon_center_focus_strong = 'center_focus_strong';
Icons.icon_center_focus_weak = 'center_focus_weak';
Icons.icon_change_history = 'change_history';
Icons.icon_chat = 'chat';
Icons.icon_chat_bubble = 'chat_bubble';
Icons.icon_chat_bubble_outline = 'chat_bubble_outline';
Icons.icon_check = 'check';
Icons.icon_check_box = 'check_box';
Icons.icon_check_box_outline_blank = 'check_box_outline_blank';
Icons.icon_check_circle = 'check_circle';
Icons.icon_chevron_left = 'chevron_left';
Icons.icon_chevron_right = 'chevron_right';
Icons.icon_child_care = 'child_care';
Icons.icon_child_friendly = 'child_friendly';
Icons.icon_chrome_reader_mode = 'chrome_reader_mode';
Icons.icon_class = 'class';
Icons.icon_clear = 'clear';
Icons.icon_clear_all = 'clear_all';
Icons.icon_close = 'close';
Icons.icon_closed_caption = 'closed_caption';
Icons.icon_cloud = 'cloud';
Icons.icon_cloud_circle = 'cloud_circle';
Icons.icon_cloud_done = 'cloud_done';
Icons.icon_cloud_download = 'cloud_download';
Icons.icon_cloud_off = 'cloud_off';
Icons.icon_cloud_queue = 'cloud_queue';
Icons.icon_cloud_upload = 'cloud_upload';
Icons.icon_code = 'code';
Icons.icon_collections = 'collections';
Icons.icon_collections_bookmark = 'collections_bookmark';
Icons.icon_color_lens = 'color_lens';
Icons.icon_colorize = 'colorize';
Icons.icon_comment = 'comment';
Icons.icon_compare = 'compare';
Icons.icon_compare_arrows = 'compare_arrows';
Icons.icon_computer = 'computer';
Icons.icon_confirmation_number = 'confirmation_number';
Icons.icon_contact_mail = 'contact_mail';
Icons.icon_contact_phone = 'contact_phone';
Icons.icon_contacts = 'contacts';
Icons.icon_content_copy = 'content_copy';
Icons.icon_content_cut = 'content_cut';
Icons.icon_content_paste = 'content_paste';
Icons.icon_control_point = 'control_point';
Icons.icon_control_point_duplicate = 'control_point_duplicate';
Icons.icon_copyright = 'copyright';
Icons.icon_create = 'create';
Icons.icon_create_new_folder = 'create_new_folder';
Icons.icon_credit_card = 'credit_card';
Icons.icon_crop = 'crop';
Icons.icon_crop_16_9 = 'crop_16_9';
Icons.icon_crop_3_2 = 'crop_3_2';
Icons.icon_crop_5_4 = 'crop_5_4';
Icons.icon_crop_7_5 = 'crop_7_5';
Icons.icon_crop_din = 'crop_din';
Icons.icon_crop_free = 'crop_free';
Icons.icon_crop_landscape = 'crop_landscape';
Icons.icon_crop_original = 'crop_original';
Icons.icon_crop_portrait = 'crop_portrait';
Icons.icon_crop_rotate = 'crop_rotate';
Icons.icon_crop_square = 'crop_square';
Icons.icon_dashboard = 'dashboard';
Icons.icon_data_usage = 'data_usage';
Icons.icon_date_range = 'date_range';
Icons.icon_dehaze = 'dehaze';
Icons.icon_delete = 'delete';
Icons.icon_delete_forever = 'delete_forever';
Icons.icon_delete_sweep = 'delete_sweep';
Icons.icon_description = 'description';
Icons.icon_desktop_mac = 'desktop_mac';
Icons.icon_desktop_windows = 'desktop_windows';
Icons.icon_details = 'details';
Icons.icon_developer_board = 'developer_board';
Icons.icon_developer_mode = 'developer_mode';
Icons.icon_device_hub = 'device_hub';
Icons.icon_devices = 'devices';
Icons.icon_devices_other = 'devices_other';
Icons.icon_dialer_sip = 'dialer_sip';
Icons.icon_dialpad = 'dialpad';
Icons.icon_directions = 'directions';
Icons.icon_directions_bike = 'directions_bike';
Icons.icon_directions_boat = 'directions_boat';
Icons.icon_directions_bus = 'directions_bus';
Icons.icon_directions_car = 'directions_car';
Icons.icon_directions_railway = 'directions_railway';
Icons.icon_directions_run = 'directions_run';
Icons.icon_directions_subway = 'directions_subway';
Icons.icon_directions_transit = 'directions_transit';
Icons.icon_directions_walk = 'directions_walk';
Icons.icon_disc_full = 'disc_full';
Icons.icon_dns = 'dns';
Icons.icon_do_not_disturb = 'do_not_disturb';
Icons.icon_do_not_disturb_alt = 'do_not_disturb_alt';
Icons.icon_do_not_disturb_off = 'do_not_disturb_off';
Icons.icon_do_not_disturb_on = 'do_not_disturb_on';
Icons.icon_dock = 'dock';
Icons.icon_domain = 'domain';
Icons.icon_done = 'done';
Icons.icon_done_all = 'done_all';
Icons.icon_donut_large = 'donut_large';
Icons.icon_donut_small = 'donut_small';
Icons.icon_drafts = 'drafts';
Icons.icon_drag_handle = 'drag_handle';
Icons.icon_drive_eta = 'drive_eta';
Icons.icon_dvr = 'dvr';
Icons.icon_edit = 'edit';
Icons.icon_edit_location = 'edit_location';
Icons.icon_eject = 'eject';
Icons.icon_email = 'email';
Icons.icon_enhanced_encryption = 'enhanced_encryption';
Icons.icon_equalizer = 'equalizer';
Icons.icon_error = 'error';
Icons.icon_error_outline = 'error_outline';
Icons.icon_euro_symbol = 'euro_symbol';
Icons.icon_ev_station = 'ev_station';
Icons.icon_event = 'event';
Icons.icon_event_available = 'event_available';
Icons.icon_event_busy = 'event_busy';
Icons.icon_event_note = 'event_note';
Icons.icon_event_seat = 'event_seat';
Icons.icon_exit_to_app = 'exit_to_app';
Icons.icon_expand_less = 'expand_less';
Icons.icon_expand_more = 'expand_more';
Icons.icon_explicit = 'explicit';
Icons.icon_explore = 'explore';
Icons.icon_exposure = 'exposure';
Icons.icon_exposure_neg_1 = 'exposure_neg_1';
Icons.icon_exposure_neg_2 = 'exposure_neg_2';
Icons.icon_exposure_plus_1 = 'exposure_plus_1';
Icons.icon_exposure_plus_2 = 'exposure_plus_2';
Icons.icon_exposure_zero = 'exposure_zero';
Icons.icon_extension = 'extension';
Icons.icon_face = 'face';
Icons.icon_fast_forward = 'fast_forward';
Icons.icon_fast_rewind = 'fast_rewind';
Icons.icon_favorite = 'favorite';
Icons.icon_favorite_border = 'favorite_border';
Icons.icon_featured_play_list = 'featured_play_list';
Icons.icon_featured_video = 'featured_video';
Icons.icon_feedback = 'feedback';
Icons.icon_fiber_dvr = 'fiber_dvr';
Icons.icon_fiber_manual_record = 'fiber_manual_record';
Icons.icon_fiber_new = 'fiber_new';
Icons.icon_fiber_pin = 'fiber_pin';
Icons.icon_fiber_smart_record = 'fiber_smart_record';
Icons.icon_file_download = 'file_download';
Icons.icon_file_upload = 'file_upload';
Icons.icon_filter = 'filter';
Icons.icon_filter_1 = 'filter_1';
Icons.icon_filter_2 = 'filter_2';
Icons.icon_filter_3 = 'filter_3';
Icons.icon_filter_4 = 'filter_4';
Icons.icon_filter_5 = 'filter_5';
Icons.icon_filter_6 = 'filter_6';
Icons.icon_filter_7 = 'filter_7';
Icons.icon_filter_8 = 'filter_8';
Icons.icon_filter_9 = 'filter_9';
Icons.icon_filter_9_plus = 'filter_9_plus';
Icons.icon_filter_b_and_w = 'filter_b_and_w';
Icons.icon_filter_center_focus = 'filter_center_focus';
Icons.icon_filter_drama = 'filter_drama';
Icons.icon_filter_frames = 'filter_frames';
Icons.icon_filter_hdr = 'filter_hdr';
Icons.icon_filter_list = 'filter_list';
Icons.icon_filter_none = 'filter_none';
Icons.icon_filter_tilt_shift = 'filter_tilt_shift';
Icons.icon_filter_vintage = 'filter_vintage';
Icons.icon_find_in_page = 'find_in_page';
Icons.icon_find_replace = 'find_replace';
Icons.icon_fingerprint = 'fingerprint';
Icons.icon_first_page = 'first_page';
Icons.icon_fitness_center = 'fitness_center';
Icons.icon_flag = 'flag';
Icons.icon_flare = 'flare';
Icons.icon_flash_auto = 'flash_auto';
Icons.icon_flash_off = 'flash_off';
Icons.icon_flash_on = 'flash_on';
Icons.icon_flight = 'flight';
Icons.icon_flight_land = 'flight_land';
Icons.icon_flight_takeoff = 'flight_takeoff';
Icons.icon_flip = 'flip';
Icons.icon_flip_to_back = 'flip_to_back';
Icons.icon_flip_to_front = 'flip_to_front';
Icons.icon_folder = 'folder';
Icons.icon_folder_open = 'folder_open';
Icons.icon_folder_shared = 'folder_shared';
Icons.icon_folder_special = 'folder_special';
Icons.icon_font_download = 'font_download';
Icons.icon_format_align_center = 'format_align_center';
Icons.icon_format_align_justify = 'format_align_justify';
Icons.icon_format_align_left = 'format_align_left';
Icons.icon_format_align_right = 'format_align_right';
Icons.icon_format_bold = 'format_bold';
Icons.icon_format_clear = 'format_clear';
Icons.icon_format_color_fill = 'format_color_fill';
Icons.icon_format_color_reset = 'format_color_reset';
Icons.icon_format_color_text = 'format_color_text';
Icons.icon_format_indent_decrease = 'format_indent_decrease';
Icons.icon_format_indent_increase = 'format_indent_increase';
Icons.icon_format_italic = 'format_italic';
Icons.icon_format_line_spacing = 'format_line_spacing';
Icons.icon_format_list_bulleted = 'format_list_bulleted';
Icons.icon_format_list_numbered = 'format_list_numbered';
Icons.icon_format_paint = 'format_paint';
Icons.icon_format_quote = 'format_quote';
Icons.icon_format_shapes = 'format_shapes';
Icons.icon_format_size = 'format_size';
Icons.icon_format_strikethrough = 'format_strikethrough';
Icons.icon_format_textdirection_l_to_r = 'format_textdirection_l_to_r';
Icons.icon_format_textdirection_r_to_l = 'format_textdirection_r_to_l';
Icons.icon_format_underlined = 'format_underlined';
Icons.icon_forum = 'forum';
Icons.icon_forward = 'forward';
Icons.icon_forward_10 = 'forward_10';
Icons.icon_forward_30 = 'forward_30';
Icons.icon_forward_5 = 'forward_5';
Icons.icon_free_breakfast = 'free_breakfast';
Icons.icon_fullscreen = 'fullscreen';
Icons.icon_fullscreen_exit = 'fullscreen_exit';
Icons.icon_functions = 'functions';
Icons.icon_g_translate = 'g_translate';
Icons.icon_gamepad = 'gamepad';
Icons.icon_games = 'games';
Icons.icon_gavel = 'gavel';
Icons.icon_gesture = 'gesture';
Icons.icon_get_app = 'get_app';
Icons.icon_gif = 'gif';
Icons.icon_golf_course = 'golf_course';
Icons.icon_gps_fixed = 'gps_fixed';
Icons.icon_gps_not_fixed = 'gps_not_fixed';
Icons.icon_gps_off = 'gps_off';
Icons.icon_grade = 'grade';
Icons.icon_gradient = 'gradient';
Icons.icon_grain = 'grain';
Icons.icon_graphic_eq = 'graphic_eq';
Icons.icon_grid_off = 'grid_off';
Icons.icon_grid_on = 'grid_on';
Icons.icon_group = 'group';
Icons.icon_group_add = 'group_add';
Icons.icon_group_work = 'group_work';
Icons.icon_hd = 'hd';
Icons.icon_hdr_off = 'hdr_off';
Icons.icon_hdr_on = 'hdr_on';
Icons.icon_hdr_strong = 'hdr_strong';
Icons.icon_hdr_weak = 'hdr_weak';
Icons.icon_headset = 'headset';
Icons.icon_headset_mic = 'headset_mic';
Icons.icon_healing = 'healing';
Icons.icon_hearing = 'hearing';
Icons.icon_help = 'help';
Icons.icon_help_outline = 'help_outline';
Icons.icon_high_quality = 'high_quality';
Icons.icon_highlight = 'highlight';
Icons.icon_highlight_off = 'highlight_off';
Icons.icon_history = 'history';
Icons.icon_home = 'home';
Icons.icon_hot_tub = 'hot_tub';
Icons.icon_hotel = 'hotel';
Icons.icon_hourglass_empty = 'hourglass_empty';
Icons.icon_hourglass_full = 'hourglass_full';
Icons.icon_http = 'http';
Icons.icon_https = 'https';
Icons.icon_image = 'image';
Icons.icon_image_aspect_ratio = 'image_aspect_ratio';
Icons.icon_import_contacts = 'import_contacts';
Icons.icon_import_export = 'import_export';
Icons.icon_important_devices = 'important_devices';
Icons.icon_inbox = 'inbox';
Icons.icon_indeterminate_check_box = 'indeterminate_check_box';
Icons.icon_info = 'info';
Icons.icon_info_outline = 'info_outline';
Icons.icon_input = 'input';
Icons.icon_insert_chart = 'insert_chart';
Icons.icon_insert_comment = 'insert_comment';
Icons.icon_insert_drive_file = 'insert_drive_file';
Icons.icon_insert_emoticon = 'insert_emoticon';
Icons.icon_insert_invitation = 'insert_invitation';
Icons.icon_insert_link = 'insert_link';
Icons.icon_insert_photo = 'insert_photo';
Icons.icon_invert_colors = 'invert_colors';
Icons.icon_invert_colors_off = 'invert_colors_off';
Icons.icon_iso = 'iso';
Icons.icon_keyboard = 'keyboard';
Icons.icon_keyboard_arrow_down = 'keyboard_arrow_down';
Icons.icon_keyboard_arrow_left = 'keyboard_arrow_left';
Icons.icon_keyboard_arrow_right = 'keyboard_arrow_right';
Icons.icon_keyboard_arrow_up = 'keyboard_arrow_up';
Icons.icon_keyboard_backspace = 'keyboard_backspace';
Icons.icon_keyboard_capslock = 'keyboard_capslock';
Icons.icon_keyboard_hide = 'keyboard_hide';
Icons.icon_keyboard_return = 'keyboard_return';
Icons.icon_keyboard_tab = 'keyboard_tab';
Icons.icon_keyboard_voice = 'keyboard_voice';
Icons.icon_kitchen = 'kitchen';
Icons.icon_label = 'label';
Icons.icon_label_outline = 'label_outline';
Icons.icon_landscape = 'landscape';
Icons.icon_language = 'language';
Icons.icon_laptop = 'laptop';
Icons.icon_laptop_chromebook = 'laptop_chromebook';
Icons.icon_laptop_mac = 'laptop_mac';
Icons.icon_laptop_windows = 'laptop_windows';
Icons.icon_last_page = 'last_page';
Icons.icon_launch = 'launch';
Icons.icon_layers = 'layers';
Icons.icon_layers_clear = 'layers_clear';
Icons.icon_leak_add = 'leak_add';
Icons.icon_leak_remove = 'leak_remove';
Icons.icon_lens = 'lens';
Icons.icon_library_add = 'library_add';
Icons.icon_library_books = 'library_books';
Icons.icon_library_music = 'library_music';
Icons.icon_lightbulb_outline = 'lightbulb_outline';
Icons.icon_line_style = 'line_style';
Icons.icon_line_weight = 'line_weight';
Icons.icon_linear_scale = 'linear_scale';
Icons.icon_link = 'link';
Icons.icon_linked_camera = 'linked_camera';
Icons.icon_list = 'list';
Icons.icon_live_help = 'live_help';
Icons.icon_live_tv = 'live_tv';
Icons.icon_local_activity = 'local_activity';
Icons.icon_local_airport = 'local_airport';
Icons.icon_local_atm = 'local_atm';
Icons.icon_local_bar = 'local_bar';
Icons.icon_local_cafe = 'local_cafe';
Icons.icon_local_car_wash = 'local_car_wash';
Icons.icon_local_convenience_store = 'local_convenience_store';
Icons.icon_local_dining = 'local_dining';
Icons.icon_local_drink = 'local_drink';
Icons.icon_local_florist = 'local_florist';
Icons.icon_local_gas_station = 'local_gas_station';
Icons.icon_local_grocery_store = 'local_grocery_store';
Icons.icon_local_hospital = 'local_hospital';
Icons.icon_local_hotel = 'local_hotel';
Icons.icon_local_laundry_service = 'local_laundry_service';
Icons.icon_local_library = 'local_library';
Icons.icon_local_mall = 'local_mall';
Icons.icon_local_movies = 'local_movies';
Icons.icon_local_offer = 'local_offer';
Icons.icon_local_parking = 'local_parking';
Icons.icon_local_pharmacy = 'local_pharmacy';
Icons.icon_local_phone = 'local_phone';
Icons.icon_local_pizza = 'local_pizza';
Icons.icon_local_play = 'local_play';
Icons.icon_local_post_office = 'local_post_office';
Icons.icon_local_printshop = 'local_printshop';
Icons.icon_local_see = 'local_see';
Icons.icon_local_shipping = 'local_shipping';
Icons.icon_local_taxi = 'local_taxi';
Icons.icon_location_city = 'location_city';
Icons.icon_location_disabled = 'location_disabled';
Icons.icon_location_off = 'location_off';
Icons.icon_location_on = 'location_on';
Icons.icon_location_searching = 'location_searching';
Icons.icon_lock = 'lock';
Icons.icon_lock_open = 'lock_open';
Icons.icon_lock_outline = 'lock_outline';
Icons.icon_looks = 'looks';
Icons.icon_looks_3 = 'looks_3';
Icons.icon_looks_4 = 'looks_4';
Icons.icon_looks_5 = 'looks_5';
Icons.icon_looks_6 = 'looks_6';
Icons.icon_looks_one = 'looks_one';
Icons.icon_looks_two = 'looks_two';
Icons.icon_loop = 'loop';
Icons.icon_loupe = 'loupe';
Icons.icon_low_priority = 'low_priority';
Icons.icon_loyalty = 'loyalty';
Icons.icon_mail = 'mail';
Icons.icon_mail_outline = 'mail_outline';
Icons.icon_map = 'map';
Icons.icon_markunread = 'markunread';
Icons.icon_markunread_mailbox = 'markunread_mailbox';
Icons.icon_memory = 'memory';
Icons.icon_menu = 'menu';
Icons.icon_merge_type = 'merge_type';
Icons.icon_message = 'message';
Icons.icon_mic = 'mic';
Icons.icon_mic_none = 'mic_none';
Icons.icon_mic_off = 'mic_off';
Icons.icon_mms = 'mms';
Icons.icon_mode_comment = 'mode_comment';
Icons.icon_mode_edit = 'mode_edit';
Icons.icon_monetization_on = 'monetization_on';
Icons.icon_money_off = 'money_off';
Icons.icon_monochrome_photos = 'monochrome_photos';
Icons.icon_mood = 'mood';
Icons.icon_mood_bad = 'mood_bad';
Icons.icon_more = 'more';
Icons.icon_more_horiz = 'more_horiz';
Icons.icon_more_vert = 'more_vert';
Icons.icon_motorcycle = 'motorcycle';
Icons.icon_mouse = 'mouse';
Icons.icon_move_to_inbox = 'move_to_inbox';
Icons.icon_movie = 'movie';
Icons.icon_movie_creation = 'movie_creation';
Icons.icon_movie_filter = 'movie_filter';
Icons.icon_multiline_chart = 'multiline_chart';
Icons.icon_music_note = 'music_note';
Icons.icon_music_video = 'music_video';
Icons.icon_my_location = 'my_location';
Icons.icon_nature = 'nature';
Icons.icon_nature_people = 'nature_people';
Icons.icon_navigate_before = 'navigate_before';
Icons.icon_navigate_next = 'navigate_next';
Icons.icon_navigation = 'navigation';
Icons.icon_near_me = 'near_me';
Icons.icon_network_cell = 'network_cell';
Icons.icon_network_check = 'network_check';
Icons.icon_network_locked = 'network_locked';
Icons.icon_network_wifi = 'network_wifi';
Icons.icon_new_releases = 'new_releases';
Icons.icon_next_week = 'next_week';
Icons.icon_nfc = 'nfc';
Icons.icon_no_encryption = 'no_encryption';
Icons.icon_no_sim = 'no_sim';
Icons.icon_not_interested = 'not_interested';
Icons.icon_note = 'note';
Icons.icon_note_add = 'note_add';
Icons.icon_notifications = 'notifications';
Icons.icon_notifications_active = 'notifications_active';
Icons.icon_notifications_none = 'notifications_none';
Icons.icon_notifications_off = 'notifications_off';
Icons.icon_notifications_paused = 'notifications_paused';
Icons.icon_offline_pin = 'offline_pin';
Icons.icon_ondemand_video = 'ondemand_video';
Icons.icon_opacity = 'opacity';
Icons.icon_open_in_browser = 'open_in_browser';
Icons.icon_open_in_new = 'open_in_new';
Icons.icon_open_with = 'open_with';
Icons.icon_pages = 'pages';
Icons.icon_pageview = 'pageview';
Icons.icon_palette = 'palette';
Icons.icon_pan_tool = 'pan_tool';
Icons.icon_panorama = 'panorama';
Icons.icon_panorama_fish_eye = 'panorama_fish_eye';
Icons.icon_panorama_horizontal = 'panorama_horizontal';
Icons.icon_panorama_vertical = 'panorama_vertical';
Icons.icon_panorama_wide_angle = 'panorama_wide_angle';
Icons.icon_party_mode = 'party_mode';
Icons.icon_pause = 'pause';
Icons.icon_pause_circle_filled = 'pause_circle_filled';
Icons.icon_pause_circle_outline = 'pause_circle_outline';
Icons.icon_payment = 'payment';
Icons.icon_people = 'people';
Icons.icon_people_outline = 'people_outline';
Icons.icon_perm_camera_mic = 'perm_camera_mic';
Icons.icon_perm_contact_calendar = 'perm_contact_calendar';
Icons.icon_perm_data_setting = 'perm_data_setting';
Icons.icon_perm_device_information = 'perm_device_information';
Icons.icon_perm_identity = 'perm_identity';
Icons.icon_perm_media = 'perm_media';
Icons.icon_perm_phone_msg = 'perm_phone_msg';
Icons.icon_perm_scan_wifi = 'perm_scan_wifi';
Icons.icon_person = 'person';
Icons.icon_person_add = 'person_add';
Icons.icon_person_outline = 'person_outline';
Icons.icon_person_pin = 'person_pin';
Icons.icon_person_pin_circle = 'person_pin_circle';
Icons.icon_personal_video = 'personal_video';
Icons.icon_pets = 'pets';
Icons.icon_phone = 'phone';
Icons.icon_phone_android = 'phone_android';
Icons.icon_phone_bluetooth_speaker = 'phone_bluetooth_speaker';
Icons.icon_phone_forwarded = 'phone_forwarded';
Icons.icon_phone_in_talk = 'phone_in_talk';
Icons.icon_phone_iphone = 'phone_iphone';
Icons.icon_phone_locked = 'phone_locked';
Icons.icon_phone_missed = 'phone_missed';
Icons.icon_phone_paused = 'phone_paused';
Icons.icon_phonelink = 'phonelink';
Icons.icon_phonelink_erase = 'phonelink_erase';
Icons.icon_phonelink_lock = 'phonelink_lock';
Icons.icon_phonelink_off = 'phonelink_off';
Icons.icon_phonelink_ring = 'phonelink_ring';
Icons.icon_phonelink_setup = 'phonelink_setup';
Icons.icon_photo = 'photo';
Icons.icon_photo_album = 'photo_album';
Icons.icon_photo_camera = 'photo_camera';
Icons.icon_photo_filter = 'photo_filter';
Icons.icon_photo_library = 'photo_library';
Icons.icon_photo_size_select_actual = 'photo_size_select_actual';
Icons.icon_photo_size_select_large = 'photo_size_select_large';
Icons.icon_photo_size_select_small = 'photo_size_select_small';
Icons.icon_picture_as_pdf = 'picture_as_pdf';
Icons.icon_picture_in_picture = 'picture_in_picture';
Icons.icon_picture_in_picture_alt = 'picture_in_picture_alt';
Icons.icon_pie_chart = 'pie_chart';
Icons.icon_pie_chart_outlined = 'pie_chart_outlined';
Icons.icon_pin_drop = 'pin_drop';
Icons.icon_place = 'place';
Icons.icon_play_arrow = 'play_arrow';
Icons.icon_play_circle_filled = 'play_circle_filled';
Icons.icon_play_circle_outline = 'play_circle_outline';
Icons.icon_play_for_work = 'play_for_work';
Icons.icon_playlist_add = 'playlist_add';
Icons.icon_playlist_add_check = 'playlist_add_check';
Icons.icon_playlist_play = 'playlist_play';
Icons.icon_plus_one = 'plus_one';
Icons.icon_poll = 'poll';
Icons.icon_polymer = 'polymer';
Icons.icon_pool = 'pool';
Icons.icon_portable_wifi_off = 'portable_wifi_off';
Icons.icon_portrait = 'portrait';
Icons.icon_power = 'power';
Icons.icon_power_input = 'power_input';
Icons.icon_power_settings_new = 'power_settings_new';
Icons.icon_pregnant_woman = 'pregnant_woman';
Icons.icon_present_to_all = 'present_to_all';
Icons.icon_print = 'print';
Icons.icon_priority_high = 'priority_high';
Icons.icon_public = 'public';
Icons.icon_publish = 'publish';
Icons.icon_query_builder = 'query_builder';
Icons.icon_question_answer = 'question_answer';
Icons.icon_queue = 'queue';
Icons.icon_queue_music = 'queue_music';
Icons.icon_queue_play_next = 'queue_play_next';
Icons.icon_radio = 'radio';
Icons.icon_radio_button_checked = 'radio_button_checked';
Icons.icon_radio_button_unchecked = 'radio_button_unchecked';
Icons.icon_rate_review = 'rate_review';
Icons.icon_receipt = 'receipt';
Icons.icon_recent_actors = 'recent_actors';
Icons.icon_record_voice_over = 'record_voice_over';
Icons.icon_redeem = 'redeem';
Icons.icon_redo = 'redo';
Icons.icon_refresh = 'refresh';
Icons.icon_remove = 'remove';
Icons.icon_remove_circle = 'remove_circle';
Icons.icon_remove_circle_outline = 'remove_circle_outline';
Icons.icon_remove_from_queue = 'remove_from_queue';
Icons.icon_remove_red_eye = 'remove_red_eye';
Icons.icon_remove_shopping_cart = 'remove_shopping_cart';
Icons.icon_reorder = 'reorder';
Icons.icon_repeat = 'repeat';
Icons.icon_repeat_one = 'repeat_one';
Icons.icon_replay = 'replay';
Icons.icon_replay_10 = 'replay_10';
Icons.icon_replay_30 = 'replay_30';
Icons.icon_replay_5 = 'replay_5';
Icons.icon_reply = 'reply';
Icons.icon_reply_all = 'reply_all';
Icons.icon_report = 'report';
Icons.icon_report_problem = 'report_problem';
Icons.icon_restaurant = 'restaurant';
Icons.icon_restaurant_menu = 'restaurant_menu';
Icons.icon_restore = 'restore';
Icons.icon_restore_page = 'restore_page';
Icons.icon_ring_volume = 'ring_volume';
Icons.icon_room = 'room';
Icons.icon_room_service = 'room_service';
Icons.icon_rotate_90_degrees_ccw = 'rotate_90_degrees_ccw';
Icons.icon_rotate_left = 'rotate_left';
Icons.icon_rotate_right = 'rotate_right';
Icons.icon_rounded_corner = 'rounded_corner';
Icons.icon_router = 'router';
Icons.icon_rowing = 'rowing';
Icons.icon_rss_feed = 'rss_feed';
Icons.icon_rv_hookup = 'rv_hookup';
Icons.icon_satellite = 'satellite';
Icons.icon_save = 'save';
Icons.icon_scanner = 'scanner';
Icons.icon_schedule = 'schedule';
Icons.icon_school = 'school';
Icons.icon_screen_lock_landscape = 'screen_lock_landscape';
Icons.icon_screen_lock_portrait = 'screen_lock_portrait';
Icons.icon_screen_lock_rotation = 'screen_lock_rotation';
Icons.icon_screen_rotation = 'screen_rotation';
Icons.icon_screen_share = 'screen_share';
Icons.icon_sd_card = 'sd_card';
Icons.icon_sd_storage = 'sd_storage';
Icons.icon_search = 'search';
Icons.icon_security = 'security';
Icons.icon_select_all = 'select_all';
Icons.icon_send = 'send';
Icons.icon_sentiment_dissatisfied = 'sentiment_dissatisfied';
Icons.icon_sentiment_neutral = 'sentiment_neutral';
Icons.icon_sentiment_satisfied = 'sentiment_satisfied';
Icons.icon_sentiment_very_dissatisfied = 'sentiment_very_dissatisfied';
Icons.icon_sentiment_very_satisfied = 'sentiment_very_satisfied';
Icons.icon_settings = 'settings';
Icons.icon_settings_applications = 'settings_applications';
Icons.icon_settings_backup_restore = 'settings_backup_restore';
Icons.icon_settings_bluetooth = 'settings_bluetooth';
Icons.icon_settings_brightness = 'settings_brightness';
Icons.icon_settings_cell = 'settings_cell';
Icons.icon_settings_ethernet = 'settings_ethernet';
Icons.icon_settings_input_antenna = 'settings_input_antenna';
Icons.icon_settings_input_component = 'settings_input_component';
Icons.icon_settings_input_composite = 'settings_input_composite';
Icons.icon_settings_input_hdmi = 'settings_input_hdmi';
Icons.icon_settings_input_svideo = 'settings_input_svideo';
Icons.icon_settings_overscan = 'settings_overscan';
Icons.icon_settings_phone = 'settings_phone';
Icons.icon_settings_power = 'settings_power';
Icons.icon_settings_remote = 'settings_remote';
Icons.icon_settings_system_daydream = 'settings_system_daydream';
Icons.icon_settings_voice = 'settings_voice';
Icons.icon_share = 'share';
Icons.icon_shop = 'shop';
Icons.icon_shop_two = 'shop_two';
Icons.icon_shopping_basket = 'shopping_basket';
Icons.icon_shopping_cart = 'shopping_cart';
Icons.icon_short_text = 'short_text';
Icons.icon_show_chart = 'show_chart';
Icons.icon_shuffle = 'shuffle';
Icons.icon_signal_cellular_4_bar = 'signal_cellular_4_bar';
Icons.icon_signal_cellular_connected_no_internet_4_bar = 'signal_cellular_connected_no_internet_4_bar';
Icons.icon_signal_cellular_no_sim = 'signal_cellular_no_sim';
Icons.icon_signal_cellular_null = 'signal_cellular_null';
Icons.icon_signal_cellular_off = 'signal_cellular_off';
Icons.icon_signal_wifi_4_bar = 'signal_wifi_4_bar';
Icons.icon_signal_wifi_4_bar_lock = 'signal_wifi_4_bar_lock';
Icons.icon_signal_wifi_off = 'signal_wifi_off';
Icons.icon_sim_card = 'sim_card';
Icons.icon_sim_card_alert = 'sim_card_alert';
Icons.icon_skip_next = 'skip_next';
Icons.icon_skip_previous = 'skip_previous';
Icons.icon_slideshow = 'slideshow';
Icons.icon_slow_motion_video = 'slow_motion_video';
Icons.icon_smartphone = 'smartphone';
Icons.icon_smoke_free = 'smoke_free';
Icons.icon_smoking_rooms = 'smoking_rooms';
Icons.icon_sms = 'sms';
Icons.icon_sms_failed = 'sms_failed';
Icons.icon_snooze = 'snooze';
Icons.icon_sort = 'sort';
Icons.icon_sort_by_alpha = 'sort_by_alpha';
Icons.icon_spa = 'spa';
Icons.icon_space_bar = 'space_bar';
Icons.icon_speaker = 'speaker';
Icons.icon_speaker_group = 'speaker_group';
Icons.icon_speaker_notes = 'speaker_notes';
Icons.icon_speaker_notes_off = 'speaker_notes_off';
Icons.icon_speaker_phone = 'speaker_phone';
Icons.icon_spellcheck = 'spellcheck';
Icons.icon_star = 'star';
Icons.icon_star_border = 'star_border';
Icons.icon_star_half = 'star_half';
Icons.icon_stars = 'stars';
Icons.icon_stay_current_landscape = 'stay_current_landscape';
Icons.icon_stay_current_portrait = 'stay_current_portrait';
Icons.icon_stay_primary_landscape = 'stay_primary_landscape';
Icons.icon_stay_primary_portrait = 'stay_primary_portrait';
Icons.icon_stop = 'stop';
Icons.icon_stop_screen_share = 'stop_screen_share';
Icons.icon_storage = 'storage';
Icons.icon_store = 'store';
Icons.icon_store_mall_directory = 'store_mall_directory';
Icons.icon_straighten = 'straighten';
Icons.icon_streetview = 'streetview';
Icons.icon_strikethrough_s = 'strikethrough_s';
Icons.icon_style = 'style';
Icons.icon_subdirectory_arrow_left = 'subdirectory_arrow_left';
Icons.icon_subdirectory_arrow_right = 'subdirectory_arrow_right';
Icons.icon_subject = 'subject';
Icons.icon_subscriptions = 'subscriptions';
Icons.icon_subtitles = 'subtitles';
Icons.icon_subway = 'subway';
Icons.icon_supervisor_account = 'supervisor_account';
Icons.icon_surround_sound = 'surround_sound';
Icons.icon_swap_calls = 'swap_calls';
Icons.icon_swap_horiz = 'swap_horiz';
Icons.icon_swap_vert = 'swap_vert';
Icons.icon_swap_vertical_circle = 'swap_vertical_circle';
Icons.icon_switch_camera = 'switch_camera';
Icons.icon_switch_video = 'switch_video';
Icons.icon_sync = 'sync';
Icons.icon_sync_disabled = 'sync_disabled';
Icons.icon_sync_problem = 'sync_problem';
Icons.icon_system_update = 'system_update';
Icons.icon_system_update_alt = 'system_update_alt';
Icons.icon_tab = 'tab';
Icons.icon_tab_unselected = 'tab_unselected';
Icons.icon_tablet = 'tablet';
Icons.icon_tablet_android = 'tablet_android';
Icons.icon_tablet_mac = 'tablet_mac';
Icons.icon_tag_faces = 'tag_faces';
Icons.icon_tap_and_play = 'tap_and_play';
Icons.icon_terrain = 'terrain';
Icons.icon_text_fields = 'text_fields';
Icons.icon_text_format = 'text_format';
Icons.icon_textsms = 'textsms';
Icons.icon_texture = 'texture';
Icons.icon_theaters = 'theaters';
Icons.icon_thumb_down = 'thumb_down';
Icons.icon_thumb_up = 'thumb_up';
Icons.icon_thumbs_up_down = 'thumbs_up_down';
Icons.icon_time_to_leave = 'time_to_leave';
Icons.icon_timelapse = 'timelapse';
Icons.icon_timeline = 'timeline';
Icons.icon_timer = 'timer';
Icons.icon_timer_10 = 'timer_10';
Icons.icon_timer_3 = 'timer_3';
Icons.icon_timer_off = 'timer_off';
Icons.icon_title = 'title';
Icons.icon_toc = 'toc';
Icons.icon_today = 'today';
Icons.icon_toll = 'toll';
Icons.icon_tonality = 'tonality';
Icons.icon_touch_app = 'touch_app';
Icons.icon_toys = 'toys';
Icons.icon_track_changes = 'track_changes';
Icons.icon_traffic = 'traffic';
Icons.icon_train = 'train';
Icons.icon_tram = 'tram';
Icons.icon_transfer_within_a_station = 'transfer_within_a_station';
Icons.icon_transform = 'transform';
Icons.icon_translate = 'translate';
Icons.icon_trending_down = 'trending_down';
Icons.icon_trending_flat = 'trending_flat';
Icons.icon_trending_up = 'trending_up';
Icons.icon_tune = 'tune';
Icons.icon_turned_in = 'turned_in';
Icons.icon_turned_in_not = 'turned_in_not';
Icons.icon_tv = 'tv';
Icons.icon_unarchive = 'unarchive';
Icons.icon_undo = 'undo';
Icons.icon_unfold_less = 'unfold_less';
Icons.icon_unfold_more = 'unfold_more';
Icons.icon_update = 'update';
Icons.icon_usb = 'usb';
Icons.icon_verified_user = 'verified_user';
Icons.icon_vertical_align_bottom = 'vertical_align_bottom';
Icons.icon_vertical_align_center = 'vertical_align_center';
Icons.icon_vertical_align_top = 'vertical_align_top';
Icons.icon_vibration = 'vibration';
Icons.icon_video_call = 'video_call';
Icons.icon_video_label = 'video_label';
Icons.icon_video_library = 'video_library';
Icons.icon_videocam = 'videocam';
Icons.icon_videocam_off = 'videocam_off';
Icons.icon_videogame_asset = 'videogame_asset';
Icons.icon_view_agenda = 'view_agenda';
Icons.icon_view_array = 'view_array';
Icons.icon_view_carousel = 'view_carousel';
Icons.icon_view_column = 'view_column';
Icons.icon_view_comfy = 'view_comfy';
Icons.icon_view_compact = 'view_compact';
Icons.icon_view_day = 'view_day';
Icons.icon_view_headline = 'view_headline';
Icons.icon_view_list = 'view_list';
Icons.icon_view_module = 'view_module';
Icons.icon_view_quilt = 'view_quilt';
Icons.icon_view_stream = 'view_stream';
Icons.icon_view_week = 'view_week';
Icons.icon_vignette = 'vignette';
Icons.icon_visibility = 'visibility';
Icons.icon_visibility_off = 'visibility_off';
Icons.icon_voice_chat = 'voice_chat';
Icons.icon_voicemail = 'voicemail';
Icons.icon_volume_down = 'volume_down';
Icons.icon_volume_mute = 'volume_mute';
Icons.icon_volume_off = 'volume_off';
Icons.icon_volume_up = 'volume_up';
Icons.icon_vpn_key = 'vpn_key';
Icons.icon_vpn_lock = 'vpn_lock';
Icons.icon_wallpaper = 'wallpaper';
Icons.icon_warning = 'warning';
Icons.icon_watch = 'watch';
Icons.icon_watch_later = 'watch_later';
Icons.icon_wb_auto = 'wb_auto';
Icons.icon_wb_cloudy = 'wb_cloudy';
Icons.icon_wb_incandescent = 'wb_incandescent';
Icons.icon_wb_iridescent = 'wb_iridescent';
Icons.icon_wb_sunny = 'wb_sunny';
Icons.icon_wc = 'wc';
Icons.icon_web = 'web';
Icons.icon_web_asset = 'web_asset';
Icons.icon_weekend = 'weekend';
Icons.icon_whatshot = 'whatshot';
Icons.icon_widgets = 'widgets';
Icons.icon_wifi = 'wifi';
Icons.icon_wifi_lock = 'wifi_lock';
Icons.icon_wifi_tethering = 'wifi_tethering';
Icons.icon_work = 'work';
Icons.icon_wrap_text = 'wrap_text';
Icons.icon_youtube_searched_for = 'youtube_searched_for';
Icons.icon_zoom_in = 'zoom_in';
Icons.icon_zoom_out = 'zoom_out';
Icons.icon_zoom_out_map = 'zoom_out_map';
var InputTypes = /** @class */ (function () {
    function InputTypes() {
    }
    return InputTypes;
}());
InputTypes.input_type_date = 'date';
InputTypes.input_type_datetime_local = 'datetime-local';
InputTypes.input_type_email = 'email';
InputTypes.input_type_month = 'month';
InputTypes.input_type_number = 'number';
InputTypes.input_type_password = 'password';
InputTypes.input_type_search = 'search';
InputTypes.input_type_tel = 'tel';
InputTypes.input_type_text = 'text';
InputTypes.input_type_time = 'time';
InputTypes.input_type_url = 'url';
InputTypes.input_type_week = 'week';
var KeyValue = /** @class */ (function () {
    function KeyValue(key, value) {
        this.key = key;
        this.value = value;
    }
    return KeyValue;
}());
var SelectOption = /** @class */ (function () {
    function SelectOption(key, value) {
        this.key = key;
        this.value = value;
    }
    return SelectOption;
}());
var TableFieldOptions = /** @class */ (function () {
    function TableFieldOptions() {
    }
    return TableFieldOptions;
}());
var TextAlign = /** @class */ (function () {
    function TextAlign() {
    }
    return TextAlign;
}());
TextAlign.text_align_right = 'right';
TextAlign.text_align_left = 'left';
TextAlign.text_align_center = 'center';
var EasyButtonComponent = /** @class */ (function () {
    function EasyButtonComponent(loaderService) {
        this.loaderService = loaderService;
        this.color = '';
        this.icon = '';
        this.key = '';
        this.type = 'mat-button';
        this.showLoader = false;
        this.onClicked = new EventEmitter();
        this.show = false;
    }
    EasyButtonComponent.prototype.ngOnInit = function () {
        var _this = this;
        if (this.showLoader) {
            this.subscription = this.loaderService.loaderState
                .subscribe(function (state) {
                _this.show = state.show;
            });
        }
    };
    EasyButtonComponent.prototype.ngOnDestroy = function () {
        if (this.showLoader) {
            this.subscription.unsubscribe();
        }
    };
    EasyButtonComponent.prototype.click = function () {
        this.onClicked.emit(true);
    };
    return EasyButtonComponent;
}());
EasyButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-button',
                template: "<div [ngSwitch]=\"type\">\n    \n        <button [id]=\"key\" *ngSwitchCase=\"'mat-button-toolbar'\" [disabled]=\"show\" mat-button class='easy-button' (click)=\"click(); $event.stopPropagation();\">\n            <mat-icon *ngIf=\"icon !='' && icon != null && !show\">{{icon}}</mat-icon>\n            <easy-spinner *ngIf=\"show\" [thickness]=\"4\" [size]=\"30\" style=\"vertical-align: middle\"></easy-spinner>\n            <span *ngIf=\"!show\">{{displayValue}}</span>\n        </button>\n    \n        <button [id]=\"key\" *ngSwitchCase=\"'mat-button'\" [disabled]=\"show\" mat-button [color]=\"color\" class='easy-button' (click)=\"click(); $event.stopPropagation();\">\n            <mat-icon *ngIf=\"icon !='' && icon != null && !show\">{{icon}}</mat-icon>\n            <easy-spinner *ngIf=\"show\" [thickness]=\"4\" [size]=\"30\" style=\"vertical-align: middle\"></easy-spinner>\n            <span *ngIf=\"!show\">{{displayValue}}</span>\n        </button>\n    \n        <button [id]=\"key\" *ngSwitchCase=\"'mat-raised-button'\" [disabled]=\"show\" mat-raised-button [color]=\"color\" class='easy-button'\n            (click)=\"click(); $event.stopPropagation();\">\n            <mat-icon *ngIf=\"icon !='' && icon != null && !show\">{{icon}}</mat-icon>\n            <easy-spinner *ngIf=\"show\" [thickness]=\"4\" [size]=\"30\" style=\"vertical-align: middle\"></easy-spinner>\n            <span *ngIf=\"!show\">{{displayValue}}</span>\n        </button>\n    \n        <button [id]=\"key\" *ngSwitchCase=\"'mat-fab'\" mat-fab [disabled]=\"show\" [color]=\"color\" class='easy-button' (click)=\"click(); $event.stopPropagation();\">\n            <mat-icon *ngIf=\"icon !='' && icon != null && !show\">{{icon}}</mat-icon>\n            <easy-spinner *ngIf=\"show\" [thickness]=\"4\" [size]=\"56\" style=\"vertical-align: middle\"></easy-spinner>\n        </button>\n    \n        <button [id]=\"key\" *ngSwitchCase=\"'mat-mini-fab'\" mat-mini-fab [disabled]=\"show\" [color]=\"color\" class='easy-button' (click)=\"click(); $event.stopPropagation();\">\n            <mat-icon *ngIf=\"icon !='' && icon != null && !show\">{{icon}}</mat-icon>\n            <easy-spinner *ngIf=\"show\" [thickness]=\"4\" [size]=\"40\" style=\"vertical-align: middle\"></easy-spinner>\n        </button>\n    \n        <button [id]=\"key\" *ngSwitchCase=\"'mat-menu-item'\" mat-menu-item [disabled]=\"show\" (click)=\"click();\">\n            <span *ngIf=\"!show\">{{displayValue}}</span>\n        </button>\n    \n        <button [id]=\"key\" *ngSwitchCase=\"'mat-icon-button'\" mat-icon-button [disabled]=\"show\" [color]=\"color\" class='easy-button'\n            (click)=\"click(); $event.stopPropagation();\">\n            <mat-icon *ngIf=\"icon !='' && icon != null && !show\">{{icon}}</mat-icon>\n        </button>",
                styles: [".easy-button {\n        margin: 8px;\n        text-transform: uppercase;\n      }"]
            },] },
];
EasyButtonComponent.ctorParameters = function () { return [
    { type: LoaderService, },
]; };
EasyButtonComponent.propDecorators = {
    "displayValue": [{ type: Input },],
    "color": [{ type: Input },],
    "icon": [{ type: Input },],
    "key": [{ type: Input, args: ['key',] },],
    "type": [{ type: Input },],
    "showLoader": [{ type: Input },],
    "onClicked": [{ type: Output },],
};
var EasyModalDialog = /** @class */ (function () {
    function EasyModalDialog(dialogRef, media, data) {
        this.dialogRef = dialogRef;
        this.media = media;
        this.data = data;
    }
    EasyModalDialog.prototype.ngOnInit = function () {
        var _this = this;
        this.setResponsiveStyles();
        this.media.subscribe(function (x) {
            _this.setResponsiveStyles();
        });
        this.setFieldValuesFromData();
    };
    EasyModalDialog.prototype.setResponsiveStyles = function () {
        if (this.dialogRef == null || this.dialogRef.componentInstance == null)
            return;
        if (this.media != null && this.media.isActive('xs')) {
            this.dialogRef.updateSize('100vw');
        }
        else
            this.dialogRef.updateSize('60vw');
    };
    EasyModalDialog.prototype.setFieldValuesFromData = function () {
        var _this = this;
        if (this.data != null && this.fields != null) {
            Object.keys(this.data).forEach(function (key) {
                var field = _this.fields.singleOrDefault(function (x) { return x.key == key; });
                if (field != null)
                    field.value = _this.data[key];
            });
        }
    };
    EasyModalDialog.prototype.setForm = function (container) {
        this.header = container.header;
        this.fields = container.fields;
        this.actions = container.actions;
        this.container = container;
    };
    EasyModalDialog.prototype.click = function (action, field) {
        var _this = this;
        if (this.data != null) {
            Object.keys(this.data).forEach(function (key) {
                var field = _this.fields.singleOrDefault(function (x) { return x.key == key; });
                if (field != null)
                    _this.data[key] = field.value;
            });
        }
        if (field.skipFormValidation) {
            this.dialogRef.close(this.fields);
            if (action != null)
                action(this.fields, this.data);
        }
        else {
            var validationResult = this.container.validateFields();
            if (validationResult.valid) {
                this.dialogRef.close(this.fields);
                if (action != null)
                    action(this.fields, this.data);
            }
        }
    };
    return EasyModalDialog;
}());
EasyModalDialog.decorators = [
    { type: Component, args: [{
                template: "<h1 mat-dialog-title>{{header}}</h1>\n                <div mat-dialog-content flex style=\"overflow-y: auto;\">\n                    <div *ngFor=\"let field of fields\" class=\"form-row\">\n                        <easy-form-field *ngIf=\"!field.hide\" [field]=\"field\"></easy-form-field>\n                    </div>\n                </div>\n                <div mat-dialog-actions fxLayout=\"row wrap\" fxLayoutAlign=\"end\">\n                    <div *ngFor=\"let action of actions\">\n                        <easy-button [key]=\"action.key\" *ngIf=\"!action.hide\" [icon]=\"action.icon\" [color]=\"action.color\" [displayValue]=\"action.label\" [type]='action.type' (onClicked)=\"click(action.action,action)\"></easy-button>\n                    </div>\n               </div>",
                styles: ["\n               .form-row {\n                margin-left: 15px;\n              }"]
            },] },
];
EasyModalDialog.ctorParameters = function () { return [
    { type: MatDialogRef, },
    { type: ObservableMedia, },
    { type: undefined, decorators: [{ type: Inject, args: [MAT_DIALOG_DATA,] },] },
]; };
var EasyModalService = /** @class */ (function () {
    function EasyModalService(modal) {
        this.modal = modal;
    }
    EasyModalService.prototype.showModal = function (container, data, disableClose) {
        if (data === void 0) { data = {}; }
        if (disableClose === void 0) { disableClose = true; }
        if (container == null)
            return;
        var width = "60vw";
        var dialogRef = this.modal.open(EasyModalDialog, { width: width, disableClose: disableClose, data: data, panelClass: 'full-width-dialog' });
        dialogRef.componentInstance.setForm(container);
        return dialogRef;
    };
    return EasyModalService;
}());
EasyModalService.decorators = [
    { type: Injectable },
];
EasyModalService.ctorParameters = function () { return [
    { type: MatDialog, },
]; };
var EasyNotification = /** @class */ (function () {
    function EasyNotification(snackBar) {
        this.snackBar = snackBar;
    }
    EasyNotification.prototype.showMessage = function (title, body) {
        this.snackBar.open(title, body, { duration: 3000 });
    };
    EasyNotification.prototype.showError = function (title, body, action) {
        if (action === void 0) { action = null; }
        var config = new MatSnackBarConfig();
        config.duration = 6000;
        this.snackBar.open(title, body, config);
        var ref = this.snackBar.open(title, body, config);
        if (action != null)
            ref.onAction().subscribe(function (x) { action(); });
    };
    return EasyNotification;
}());
EasyNotification.decorators = [
    { type: Injectable },
];
EasyNotification.ctorParameters = function () { return [
    { type: MatSnackBar, },
]; };
var EasyFormService = /** @class */ (function () {
    function EasyFormService(easyNotification, httpIntegrationService, matDialog) {
        var _this = this;
        this.easyNotification = easyNotification;
        this.httpIntegrationService = httpIntegrationService;
        this.easyModal = new EasyModalService(matDialog);
        this.errorSubscription = httpIntegrationService.OnError.subscribe(function (x) {
            if (x.status == 0) {
                _this.easyNotification.showError("Error", "No response from server.", function () { return _this.showErrorModal(x.json().Message); });
            }
            else if (x.status == 500) {
                _this.easyNotification.showError("Error", x.status + " : " + x.statusText, function () { return _this.showErrorModal(x.json().Message); });
            }
        });
    }
    EasyFormService.prototype.buildModal = function () {
        this.modal = this.form.addModalContainer("Error");
        this.stackTraceField = this.modal.addTextAreaField("Stack Trace", { readonly: true });
        this.modal.addAction('Back', function () { }, { key: 'Back', color: Colors.color_warn, icon: Icons.icon_arrow_back, showLoader: true, type: ButtonTypes.button_raised, columnSpan: 2 });
    };
    EasyFormService.prototype.showErrorModal = function (message) {
        this.stackTraceField.value = message;
        this.easyModal.showModal(this.modal);
    };
    EasyFormService.prototype.createForm = function () {
        this.form = new EasyForm();
        this.buildModal();
        return this.form;
    };
    EasyFormService.prototype.ngOnDestroy = function () {
        this.errorSubscription.unsubscribe();
    };
    return EasyFormService;
}());
EasyFormService.decorators = [
    { type: Injectable },
];
EasyFormService.ctorParameters = function () { return [
    { type: EasyNotification, },
    { type: HttpIntegrationService, },
    { type: MatDialog, },
]; };
var EasyFileUploadComponent = /** @class */ (function (_super) {
    __extends(EasyFileUploadComponent, _super);
    function EasyFileUploadComponent(validatorService) {
        var _this = _super.call(this, validatorService) || this;
        _this.color = '';
        _this.icon = '';
        _this.type = '';
        _this.placeholder = '';
        _this.key = '';
        _this.hint = '';
        _this.allowedExtensions = '';
        _this.onClicked = new EventEmitter();
        _this.fieldValueChange = new EventEmitter();
        return _this;
    }
    EasyFileUploadComponent.prototype.ngOnInit = function () {
    };
    EasyFileUploadComponent.prototype.uploadClick = function () {
    };
    EasyFileUploadComponent.prototype.click = function () {
    };
    EasyFileUploadComponent.prototype.fileChanged = function ($event) {
        var files = $event.target.files;
        if (files[0]) {
            this.hint = files[0].name;
            this.fieldValueChange.emit(new FieldChangeDto(this.key, files[0], true));
        }
        else
            this.hint = null;
    };
    return EasyFileUploadComponent;
}(EasyFormComponent));
EasyFileUploadComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-fileupload',
                template: "<div>\n                <input id={{key}} type='file' #fileUploader style='visibility:hidden' (change)=fileChanged($event) [accept]=\"allowedExtensions\">\n                <mat-form-field class='easy-input'>\n                    <input id='fileDsplayLabel' type='text' [placeholder]=\"placeholder\" matInput disabled>\n                    <mat-hint>{{hint}}</mat-hint>\n                    <easy-button matSuffix [color]=\"color\" [icon]=\"icon\" [type]=\"type\" [displayValue]=\"''\" (onClicked)=\"fileUploader.click();\"></easy-button>\n                </mat-form-field>\n              </div>",
                styles: [".easy-input {\n                margin-top: 20px;\n                width: 100%;\n              }"]
            },] },
];
EasyFileUploadComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
]; };
EasyFileUploadComponent.propDecorators = {
    "color": [{ type: Input },],
    "icon": [{ type: Input },],
    "type": [{ type: Input },],
    "placeholder": [{ type: Input },],
    "key": [{ type: Input, args: ['key',] },],
    "hint": [{ type: Input, args: ['hint',] },],
    "allowedExtensions": [{ type: Input },],
    "onClicked": [{ type: Output },],
    "fieldValueChange": [{ type: Output },],
};
var EasyMaterialModule = /** @class */ (function () {
    function EasyMaterialModule() {
    }
    return EasyMaterialModule;
}());
EasyMaterialModule.decorators = [
    { type: NgModule, args: [{
                exports: [
                    CdkTableModule,
                    MatAutocompleteModule,
                    MatButtonModule,
                    MatButtonToggleModule,
                    MatCardModule,
                    MatCheckboxModule,
                    MatChipsModule,
                    MatStepperModule,
                    MatDatepickerModule,
                    MatDialogModule,
                    MatExpansionModule,
                    MatGridListModule,
                    MatIconModule,
                    MatInputModule,
                    MatListModule,
                    MatMenuModule,
                    MatNativeDateModule,
                    MatPaginatorModule,
                    MatProgressBarModule,
                    MatProgressSpinnerModule,
                    MatRadioModule,
                    MatRippleModule,
                    MatSelectModule,
                    MatSidenavModule,
                    MatSliderModule,
                    MatSlideToggleModule,
                    MatSnackBarModule,
                    MatSortModule,
                    MatTableModule,
                    MatTabsModule,
                    MatToolbarModule,
                    MatTooltipModule
                ],
            },] },
];
var EasyRadioButtonComponent = /** @class */ (function (_super) {
    __extends(EasyRadioButtonComponent, _super);
    function EasyRadioButtonComponent(validatorService) {
        var _this = _super.call(this, validatorService) || this;
        _this.fieldValueChange = new EventEmitter();
        _this.key = '';
        _this.formControl = new FormControl('', []);
        return _this;
    }
    EasyRadioButtonComponent.prototype.onChange = function () {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.selectedValue, this.formControl.valid));
    };
    return EasyRadioButtonComponent;
}(EasyFormComponent));
EasyRadioButtonComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-radio-button',
                template: "<mat-radio-group [(ngModel)]=\"selectedValue\" (change)=\"onChange()\" [formControl]=\"formControl\">\n                <mat-radio-button *ngFor=\"let item of items\" [value]=\"item.key\">\n                   {{item.value}}\n                 </mat-radio-button>\n               </mat-radio-group>",
                styles: [""],
                inputs: ['easy-required']
            },] },
];
EasyRadioButtonComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
]; };
EasyRadioButtonComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "selectedValue": [{ type: Input, args: ['selectedValue',] },],
    "key": [{ type: Input, args: ['key',] },],
    "items": [{ type: Input, args: ['items',] },],
};
var EasySelectKeyValueComponent = /** @class */ (function (_super) {
    __extends(EasySelectKeyValueComponent, _super);
    function EasySelectKeyValueComponent(validatorService, iterableDiffers) {
        var _this = _super.call(this, validatorService) || this;
        _this.iterableDiffers = iterableDiffers;
        _this.fieldValueChange = new EventEmitter();
        _this.key = '';
        _this.iterableDiffer = _this.iterableDiffers.find([]).create(null);
        return _this;
    }
    EasySelectKeyValueComponent.prototype.ngDoCheck = function () {
        var _this = this;
        var changes = this.iterableDiffer.diff(this.items);
        if (changes) {
            var item = this.items.singleOrDefault(function (x) { return x.key == _this.selectedValue; });
            if (item == null)
                return;
            this.selectedValue = item.key;
            if (this.selectedValue != null && this.selectedValue != "")
                this.onChange();
        }
        _super.prototype.ngDoCheck.call(this);
    };
    EasySelectKeyValueComponent.prototype.ngOnInit = function () {
        _super.prototype.ngOnInit.call(this);
        if (this.selectedValue != null && this.selectedValue != "")
            this.onChange();
    };
    EasySelectKeyValueComponent.prototype.onChange = function () {
        var _this = this;
        if (this.items == null || !this.items.any())
            return;
        var selectedItem = this.items.single(function (x) { return x.key == _this.selectedValue; });
        if (selectedItem == null) {
            return;
        }
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.selectedValue, this.formControl.valid, selectedItem));
    };
    return EasySelectKeyValueComponent;
}(EasyFormComponent));
EasySelectKeyValueComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-select-key-value',
                template: "<mat-form-field class=\"easy-select\">\n                <mat-select id=\"{{key}}\" [placeholder]=\"placeholder\"  [(ngModel)]=\"selectedValue\" (change)=\"onChange()\" [formControl]=\"formControl\">\n                    <mat-option *ngFor=\"let item of items\" [value]=\"item.key\" id=\"{{item.key}}\">\n                    {{item.value}}\n                    </mat-option>\n                </mat-select>\n               </mat-form-field>",
                styles: [".easy-select {\n                margin-top: 20px;\n                width: 100%;\n              }"],
                inputs: ['easy-required']
            },] },
];
EasySelectKeyValueComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
    { type: IterableDiffers, },
]; };
EasySelectKeyValueComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "items": [{ type: Input, args: ['items',] },],
    "selectedValue": [{ type: Input, args: ['selectedValue',] },],
    "key": [{ type: Input, args: ['key',] },],
};
var EasySelectComponent = /** @class */ (function (_super) {
    __extends(EasySelectComponent, _super);
    function EasySelectComponent(validatorService) {
        var _this = _super.call(this, validatorService) || this;
        _this.fieldValueChange = new EventEmitter();
        _this.key = '';
        return _this;
    }
    EasySelectComponent.prototype.onChange = function () {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.selectedValue, this.formControl.valid));
    };
    return EasySelectComponent;
}(EasyFormComponent));
EasySelectComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-select',
                template: "<mat-form-field class=\"easy-select\">\n                <mat-select [placeholder]=\"placeholder\"  [id]=\"key\" [(ngModel)]=\"selectedValue\" (change)=\"onChange()\" [formControl]=\"formControl\">\n                    <mat-option *ngFor=\"let item of items\" [value]=\"item\">\n                        {{item}}\n                    </mat-option>\n                </mat-select>\n               </mat-form-field>",
                styles: [".easy-select {\n                margin-top: 20px;\n                width: 100%;\n              }"],
                inputs: ['easy-required']
            },] },
];
EasySelectComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
]; };
EasySelectComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "items": [{ type: Input, args: ['items',] },],
    "selectedValue": [{ type: Input, args: ['selectedValue',] },],
    "key": [{ type: Input, args: ['key',] },],
};
var EasyFabService = /** @class */ (function () {
    function EasyFabService() {
        this.subject = new Subject$1();
        this.actions = [];
        this.initialized = this.subject.asObservable();
    }
    EasyFabService.prototype.initialize = function (actions) {
        if (actions === void 0) { actions = []; }
        this.actions = actions;
        this.subject.next(true);
    };
    EasyFabService.prototype.uninitialize = function () {
        this.actions = [];
        this.subject.next(true);
    };
    return EasyFabService;
}());
EasyFabService.decorators = [
    { type: Injectable },
];
EasyFabService.ctorParameters = function () { return []; };
var EasyFabComponent = /** @class */ (function () {
    function EasyFabComponent(loaderService, easyFabService) {
        var _this = this;
        this.loaderService = loaderService;
        this.easyFabService = easyFabService;
        this.actions = [];
        this.easyFabSubscription = easyFabService.initialized.subscribe(function (x) {
            _this.actions = easyFabService.actions;
        });
    }
    EasyFabComponent.prototype.click = function (field) {
        field.action();
    };
    EasyFabComponent.prototype.ngOnDestroy = function () {
        this.easyFabSubscription.unsubscribe();
    };
    return EasyFabComponent;
}());
EasyFabComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-fab',
                template: "<div class='full-container'>\n               <button [id]=\"action.key\" *ngFor=\"let action of actions\" mat-fab class='sticky-fab easy-button' [color]=\"action.color\" (click)=\"click(action)\" [matTooltip]=\"action.label\" matTooltipPosition=\"left\">\n                <mat-icon *ngIf=\"action.icon !='' && action.icon != null\">{{action.icon}}</mat-icon>\n               </button>\n               </div>",
                styles: ["\n               \n               .form-row {\n                margin-left: 15px;\n              }\n              \n              .demo-card-container {\n                display: flex;\n                flex-flow: column nowrap;\n              }\n              \n              .demo-card-container .mat-card {\n                margin: 0 16px 16px 0;\n                width: 350px;\n              }\n              \n              .demo-card-container img {\n                background-color: gray;\n              }\n              \n              .demo-card-blue {\n                background-color: #b0becc;\n              }\n              \n              .demo-card-blue .mat-card-actions {\n                display: flex;\n                flex-direction: column;\n              }\n              \n              .container {\n                width: 100%;\n                margin-bottom: 15px;\n              }\n              \n              .full-container {\n                position: fixed;\n                height: 100vh;\n                width: 56px;\n                right: 30px;\n                bottom: 30px;\n                z-index: 9999;\n                pointer-events: none;\n                display: flex;\n                flex-direction: column-reverse;\n              }\n              \n              .sticky-fab {\n                margin-top: 10px;\n                margin-right: 30px;\n                margin-left: auto;\n                pointer-events: all;\n              }\n               \n               .checkbox-group-container {\n                display: flex;\n                flex-direction: column;\n                margin-top: 20px;\n              }\n              \n              .checkbox-group {\n                display: flex;\n                flex-direction: column;\n                padding-left: 20px;\n              }\n              \n              .easy-checkbox {\n                margin-top: 100px;\n              }\n              \n              .button-row {\n                display: flex;\n                align-items: right;\n                justify-content: flex-end;\n              }\n              \n              .easy-date-picker {\n                margin-top: 20px;\n                width: 100%;\n              }\n              \n              .easy-select {\n                margin-top: 20px;\n                width: 100%;\n              }\n              \n              .easy-input {\n                margin-top: 20px;\n                width: 100%;\n              }\n              \n              .easy-autocomplete {\n                margin-top: 20px;\n                width: 100%;\n              }\n              \n              .easy-button {\n                margin: 8px;\n                text-transform: uppercase;\n              }\n              \n              .input-icon {\n                font-size: 24px;\n                height: 24px;\n                width: 24px;\n              }\n              \n              .full-width {\n                width: 100vw;\n              }"]
            },] },
];
EasyFabComponent.ctorParameters = function () { return [
    { type: LoaderService, },
    { type: EasyFabService, },
]; };
var EasyFabMobileComponent = /** @class */ (function () {
    function EasyFabMobileComponent(loaderService, easyFabService) {
        var _this = this;
        this.loaderService = loaderService;
        this.easyFabService = easyFabService;
        this.actions = [];
        this.easyFabSubscription = easyFabService.initialized.subscribe(function (x) {
            _this.actions = easyFabService.actions;
        });
    }
    EasyFabMobileComponent.prototype.click = function (field) {
        field.action();
    };
    EasyFabMobileComponent.prototype.ngOnDestroy = function () {
        this.easyFabSubscription.unsubscribe();
    };
    return EasyFabMobileComponent;
}());
EasyFabMobileComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-fab-mobile',
                template: "<button *ngIf=\"actions != null && actions.length > 0\" mat-icon-button [matMenuTriggerFor]=\"easyFabMobileMenu\">\n                <mat-menu #easyFabMobileMenu=\"matMenu\">\n                    <easy-button type=\"mat-menu-item\" [displayValue]=\"action.label\" (onClicked)=\"click(action)\" *ngFor=\"let action of actions\"></easy-button>\n                </mat-menu>\n                <mat-icon>more_vert</mat-icon>\n            </button>",
                styles: [".checkbox-group-container {\n                display: flex;\n                flex-direction: column;\n                margin-top: 20px;\n              }\n              \n              .checkbox-group {\n                display: flex;\n                flex-direction: column;\n                padding-left: 20px;\n              }\n              \n              .easy-checkbox {\n                margin-top: 100px;\n              }\n              \n              .button-row {\n                display: flex;\n                align-items: right;\n                justify-content: flex-end;\n              }\n              \n              .easy-date-picker {\n                margin-top: 20px;\n                width: 100%;\n              }\n              \n              .easy-select {\n                margin-top: 20px;\n                width: 100%;\n              }\n              \n              .easy-input {\n                margin-top: 20px;\n                width: 100%;\n              }\n              \n              .easy-autocomplete {\n                margin-top: 20px;\n                width: 100%;\n              }\n              \n              .easy-button {\n                margin: 8px;\n                text-transform: uppercase;\n              }\n              \n              .input-icon {\n                font-size: 24px;\n                height: 24px;\n                width: 24px;\n              }\n              \n              .full-width {\n                width: 100vw;\n              }"]
            },] },
];
EasyFabMobileComponent.ctorParameters = function () { return [
    { type: LoaderService, },
    { type: EasyFabService, },
]; };
var EasyContainerComponent = /** @class */ (function () {
    function EasyContainerComponent() {
        this.selectedTabIndex = 0;
    }
    return EasyContainerComponent;
}());
EasyContainerComponent.decorators = [
    { type: Component, args: [{
                encapsulation: ViewEncapsulation.None,
                selector: 'easy-container',
                template: "<div fxLayout=\"row wrap\" fxLayoutAlign=\"space-around\">\n    <div *ngFor=\"let container of containers\" [fxFlex.xl]=\"container.xlSize\" [fxFlex.lg]=\"container.lgSize\" [fxFlex.md]=\"container.mdSize\" [fxFlex.sm]=\"container.smSize\" [fxFlex.xs]=\"container.xsSize\" \n    [style.margin-right]=\"container.marginRight\" [style.margin-left]=\"container.marginLeft\" [style.padding-left]=\"container.paddingLeft\" [style.padding-left]=\"container.paddingLeft\">\n      <div *ngIf=\"container.show\" [ngSwitch]=\"container.controlType\" class=\"container\">\n          <mat-card *ngSwitchCase=\"'card'\">\n              <mat-card-header *ngIf=\"container.header != null && container.header != ''\">\n                  <mat-card-title class=\"mat-card-title\" style=\"text-transform:uppercase;\">\n                      {{container.header}}\n                  </mat-card-title>\n              </mat-card-header>\n              <mat-card-content>\n                  <easy-form-content [container]=\"container\"></easy-form-content>\n                  <easy-container [containers]='container.containers'></easy-container>\n              </mat-card-content>\n              <mat-card-actions>\n                  <easy-form-content-actions [actions]=\"container.actions\"></easy-form-content-actions>\n              </mat-card-actions>\n          </mat-card>\n          <mat-expansion-panel [id]=\"container.header\" *ngSwitchCase=\"'expansion-panel'\">\n              <mat-expansion-panel-header>\n                  <mat-panel-title>\n                      {{container.header}}\n                  </mat-panel-title>\n              </mat-expansion-panel-header>\n              <easy-form-content [container]=\"container\"></easy-form-content>\n              <easy-container [containers]='container.containers'></easy-container>\n              <easy-form-content-actions [actions]=\"container.actions\"></easy-form-content-actions>\n          </mat-expansion-panel>\n          <mat-card *ngSwitchCase=\"'tabs'\">\n              <mat-tab-group [(selectedIndex)]=\"selectedTabIndex\">\n                  <mat-tab label=\"{{tab.header}}\" *ngFor=\"let tab of container.containers;let i = index\">\n                  <div *ngIf=\"selectedTabIndex == i\">\n                      <easy-form-content [container]=\"tab\"></easy-form-content>\n                      <easy-container [containers]='tab.containers'></easy-container>\n                      <easy-form-content-actions [actions]=\"tab.actions\"></easy-form-content-actions>\n                  </div>\n                  </mat-tab>\n              </mat-tab-group>\n          </mat-card>\n          <mat-horizontal-stepper *ngSwitchCase=\"'stepper'\">\n              <mat-step *ngFor=\"let step of container.containers\">\n                  <easy-form-content [container]=\"step\"></easy-form-content>\n                  <easy-container [containers]='step.containers'></easy-container>\n              </mat-step>\n          </mat-horizontal-stepper>\n          <mat-accordion *ngSwitchCase=\"'accordion'\">\n              <mat-expansion-panel [id]=\"expansionPanel.header\" *ngFor=\"let expansionPanel of container.containers\">\n                  <mat-expansion-panel-header>\n                      <mat-panel-title>\n                          {{expansionPanel.header}}\n                      </mat-panel-title>\n                  </mat-expansion-panel-header>\n                  <easy-form-content [container]=\"expansionPanel\"></easy-form-content>\n                  <easy-container [containers]='expansionPanel.containers'></easy-container>\n                  <easy-form-content-actions [actions]=\"expansionPanel.actions\"></easy-form-content-actions>\n              </mat-expansion-panel>\n          </mat-accordion>\n      </div>\n  </div>\n</div>",
                styles: ["\n    div.mat-expansion-panel-content:not(.mat-expanded) {\n        height: 0px;\n        visibility: hidden;\n    }\n    \n    .mat-expansion-panel-header:not(.mat-expanded)  {\n        height: 48px;\n    }\n    \n    .mat-expansion-panel-header  {\n        height: 64px;\n        .mat-content {\n            font-weight: 100;\n            font-size: 18px;\n        }\n        &.mat-expanded {        \n            .mat-expansion-indicator {\n                transform: rotate(180deg);\n            }\n        }\n    }\n    \n    .checkbox-group-container {\n    display: flex;\n    flex-direction: column;\n    margin-top: 20px;\n  }\n  \n  .checkbox-group {\n    display: flex;\n    flex-direction: column;\n    padding-left: 20px;\n  }\n  \n  .button-row {\n    display: flex;\n    align-items: right;\n    justify-content: flex-end;\n  }\n  \n  .easy-date-picker {\n    margin-top: 20px;\n    width: 100%;\n  }\n  \n  .easy-select {\n    margin-top: 20px;\n    width: 100%;\n  }\n  \n  .easy-input {\n    margin-top: 20px;\n    width: 100%;\n  }\n  \n  .easy-autocomplete {\n    margin-top: 20px;\n    width: 100%;\n  }\n  \n  .easy-button {\n    margin: 8px;\n    text-transform: uppercase;\n  }\n  \n  .input-icon {\n    font-size: 24px;\n    height: 24px;\n    width: 24px;\n  }\n  \n  .full-width {\n    width: 100vw;\n  }"]
            },] },
];
EasyContainerComponent.propDecorators = {
    "containers": [{ type: Input },],
    "layout": [{ type: Input },],
};
var EasyInputComponent = /** @class */ (function (_super) {
    __extends(EasyInputComponent, _super);
    function EasyInputComponent(validatorService) {
        var _this = _super.call(this, validatorService) || this;
        _this.fieldValueChange = new EventEmitter();
        _this.key = '';
        _this.hint = '';
        _this.type = 'text';
        _this.maxLength = null;
        _this.placeholder = '';
        return _this;
    }
    EasyInputComponent.prototype.onChange = function () {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, this.formControl.valid));
    };
    EasyInputComponent.prototype.enterKeyPressed = function () {
        if (!this.onEnter)
            return;
        this.onEnter();
    };
    return EasyInputComponent;
}(EasyFormComponent));
EasyInputComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-input',
                template: "<mat-form-field class='easy-input'>\n                        <input matInput [id]=\"key\" [easy-max-length]=\"maxLength\" [type]=\"type\" [placeholder]=\"placeholder\"  [(ngModel)]=\"value\" (change)=\"onChange()\" (keyup.enter)=\"enterKeyPressed()\" [formControl]=\"formControl\">\n                        <mat-hint *ngIf=\"maxLength != null && maxLength > 0\" align=\"end\">{{value.length}} / {{maxLength}}</mat-hint>\n                        <mat-hint *ngIf=\"hint != null && hint.length > 0\" align=\"start\">{{hint}}</mat-hint>\n                        <mat-error *ngIf=\"formControl.hasError('required')\">{{this.getError('required')}}</mat-error>\n                        <mat-error *ngIf=\"formControl.hasError('maxlength')\">{{this.getError('maxlength')}}</mat-error>\n                        <mat-error *ngIf=\"formControl.hasError('minlength')\">{{this.getError('minlength')}}</mat-error>\n                        <mat-error *ngIf=\"formControl.hasError('pattern')\">{{this.getError('pattern')}}</mat-error>\n               </mat-form-field>",
                styles: [".easy-input {\n                margin-top: 20px;\n                width: 100%;\n              }"]
            },] },
];
EasyInputComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
]; };
EasyInputComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "value": [{ type: Input, args: ['value',] },],
    "key": [{ type: Input, args: ['key',] },],
    "hint": [{ type: Input, args: ['hint',] },],
    "type": [{ type: Input, args: ['type',] },],
    "onEnter": [{ type: Input, args: ['onEnter',] },],
    "maxLength": [{ type: Input, args: ['maxLength',] },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
};
var FileDownloadService = /** @class */ (function () {
    function FileDownloadService(http, easyNotification) {
        this.http = http;
        this.easyNotification = easyNotification;
    }
    FileDownloadService.prototype.downloadFile = function (url, overriddenFilename) {
        var _this = this;
        this.http.get(url, { responseType: ResponseContentType.Blob }).subscribe(function (x) {
            _this.saveToFileSystem(x, overriddenFilename);
        });
    };
    FileDownloadService.prototype.downloadFileFromBytes = function (bytes, filename) {
        saveAs(new Blob([new Uint8Array(bytes)]), filename);
    };
    FileDownloadService.prototype.saveToFileSystem = function (response, overriddenFilename) {
        var contentDispositionHeader = response.headers.get('Content-Disposition');
        var contentType = response.headers.get('Content-Type');
        if (contentDispositionHeader == null || contentDispositionHeader == "" || contentType == null || contentType == "") {
            this.buildError();
            return;
        }
        var parts = contentDispositionHeader.split(';');
        var filename = parts[1].split('=')[1];
        var blob = new Blob([response._body], { type: contentType });
        saveAs(blob, overriddenFilename != null && overriddenFilename != "" ? overriddenFilename : filename);
    };
    FileDownloadService.prototype.buildError = function () {
        var error = "There seems to be a problem with the server configuration. Please see example below:\n\n        If downloading from record store change url to RecordDownload.\n                \n        var result = new HttpResponseMessage(HttpStatusCode.OK);\n        result.Content = new ByteArrayContent(record.FileData);\n\n        result.Content.Headers.ContentType = new MediaTypeHeaderValue(\"application/pdf\");\n        result.Content.Headers.ContentDisposition = new ContentDispositionHeaderValue(\"attachment\");\n        result.Content.Headers.ContentDisposition.FileName = record.FileName;\n\n        result.Content.Headers.Add(\"Access-Control-Expose-Headers\", \"Content-Disposition\");\n        result.Content.Headers.Add(\"Access-Control-Expose-Headers\", \"Filename\");\n        result.Content.Headers.Add(\"Filename\", record.FileName);";
        this.easyNotification.showError("Download failed", "Could not download file. Check console for errors.");
        console.error(error);
    };
    return FileDownloadService;
}());
FileDownloadService.decorators = [
    { type: Injectable },
];
FileDownloadService.ctorParameters = function () { return [
    { type: Http, },
    { type: EasyNotification, },
]; };
var SourceDetail = /** @class */ (function () {
    function SourceDetail(url, token) {
        this.url = url;
        this.httpHeaders = { Authorization: token };
    }
    return SourceDetail;
}());
var EasyRecordComponent = /** @class */ (function () {
    function EasyRecordComponent(easyNotification, fileDownloader, http) {
        this.easyNotification = easyNotification;
        this.fileDownloader = fileDownloader;
        this.http = http;
        this.page = 1;
        this.isLoadComplete = false;
    }
    EasyRecordComponent.prototype.ngOnInit = function () {
        this.document = new SourceDetail(this.source, this.authorizationHeader);
    };
    EasyRecordComponent.prototype.loadComplete = function (event) {
        this.isLoadComplete = true;
        this.pageCount = event.numPages;
    };
    EasyRecordComponent.prototype.onError = function (error) {
        this.easyNotification.showError("Error", "Could open load pdf");
    };
    EasyRecordComponent.prototype.nextPage = function () {
        this.page++;
    };
    EasyRecordComponent.prototype.previousPage = function () {
        if (this.page > 1)
            this.page--;
    };
    EasyRecordComponent.prototype.getFilename = function (response) {
        var contentDispositionHeader = response.headers.get('Content-Disposition');
        var contentType = response.headers.get('Content-Type');
        if (contentDispositionHeader == null || contentDispositionHeader == "") {
            if (contentType != null && contentType != "") {
                return "download" + "." + this.getFileExtension(contentType);
            }
            return "";
        }
        var parts = contentDispositionHeader.split(';');
        return parts[1].split('=')[1];
    };
    EasyRecordComponent.prototype.download = function () {
        var _this = this;
        this.http.get(this.source, { responseType: ResponseContentType.ArrayBuffer })
            .subscribe(function (file) {
            var bytes = new Uint8Array(file._body);
            _this.fileDownloader.downloadFileFromBytes(bytes, _this.getFilename(file));
        }, function (x) {
            _this.easyNotification.showError("Error", "Could open load pdf");
        });
    };
    EasyRecordComponent.prototype.getFileExtension = function (filename) {
        return filename.split('/').pop();
    };
    return EasyRecordComponent;
}());
EasyRecordComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-record',
                template: "<div>\n                <div *ngIf=\"!isLoadComplete\">\n                    <mat-progress-bar mode=\"indeterminate\">\n                    </mat-progress-bar>\n                </div>\n                <mat-toolbar>\n                    <easy-button icon=\"keyboard_arrow_left\" matTooltip=\"Previous Page\" type=\"mat-icon-button\" displayValue=\"''\" (onClicked)=\"previousPage()\"></easy-button>\n                    <easy-button icon=\"keyboard_arrow_right\" matTooltip=\"Next Page\" type=\"mat-icon-button\" displayValue=\"''\" (onClicked)=\"nextPage()\"></easy-button>\n                    <span class=\"spacer\"></span>\n                    <easy-button icon=\"file_download\" matTooltip=\"Download\" type=\"mat-icon-button\" displayValue=\"''\" (onClicked)=\"download()\"></easy-button>\n                </mat-toolbar>\n                <div [style.visible]=\"isLoadComplete\">               \n                    <pdf-viewer [src]=\"document\" [(page)]=\"page\" [show-all]=\"false\" original-size=\"false\"\n                        (after-load-complete)=\"loadComplete($event)\" (error)=\"onError($event)\"></pdf-viewer>                \n                    </div>\n                <div>",
                styles: [".spacer { flex: 1 1 auto; }\n            "]
            },] },
];
EasyRecordComponent.ctorParameters = function () { return [
    { type: EasyNotification, },
    { type: FileDownloadService, },
    { type: Http, },
]; };
EasyRecordComponent.propDecorators = {
    "source": [{ type: Input, args: ['source',] },],
    "authorizationHeader": [{ type: Input, args: ['authorizationHeader',] },],
};
var EasyTextAreaComponent = /** @class */ (function (_super) {
    __extends(EasyTextAreaComponent, _super);
    function EasyTextAreaComponent(validatorService) {
        var _this = _super.call(this, validatorService) || this;
        _this.fieldValueChange = new EventEmitter();
        _this.validators = [];
        _this.key = '';
        _this.formControl = new FormControl('', []);
        return _this;
    }
    EasyTextAreaComponent.prototype.ngOnInit = function () {
        if (this.readonly)
            this.formControl.disable();
        _super.prototype.ngOnInit.call(this);
    };
    EasyTextAreaComponent.prototype.onBlur = function () {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, this.formControl.valid));
    };
    return EasyTextAreaComponent;
}(EasyFormComponent));
EasyTextAreaComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-text-area',
                template: "<mat-form-field class='easy-input'>\n                        <textarea matInput [id]=\"key\" [style.height]=\"height\" [style.min-height]=\"minHeight\" [style.max-height]=\"maxHeight\" [easy-max-length]=\"maxLength\" [placeholder]=\"placeholder\"  [(ngModel)]=\"value\" (change)=\"onBlur()\" [formControl]=\"formControl\"></textarea>\n                        <mat-hint *ngIf=\"maxLength != null && maxLength > 0\" align=\"end\">{{value.length}} / {{maxLength}}</mat-hint>\n                        <mat-error *ngIf=\"formControl.hasError('required')\">{{this.getError('required')}}</mat-error>\n                        <mat-error *ngIf=\"formControl.hasError('maxlength')\">{{this.getError('maxlength')}}</mat-error>\n                        <mat-error *ngIf=\"formControl.hasError('minlength')\">{{this.getError('minlength')}}</mat-error>\n                        <mat-error *ngIf=\"formControl.hasError('pattern')\">{{this.getError('pattern')}}</mat-error>\n               </mat-form-field>",
                styles: [".easy-input {\n                margin-top: 20px;\n                width: 100%;\n              }"]
            },] },
];
EasyTextAreaComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
]; };
EasyTextAreaComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "value": [{ type: Input, args: ['value',] },],
    "maxLength": [{ type: Input, args: ['maxLength',] },],
    "validators": [{ type: Input, args: ['validators',] },],
    "key": [{ type: Input, args: ['key',] },],
    "readonly": [{ type: Input, args: ['readonly',] },],
    "height": [{ type: Input, args: ['height',] },],
    "minHeight": [{ type: Input, args: ['minHeight',] },],
    "maxHeight": [{ type: Input, args: ['maxHeight',] },],
};
var EasyCheckBoxComponent = /** @class */ (function (_super) {
    __extends(EasyCheckBoxComponent, _super);
    function EasyCheckBoxComponent(validatorService) {
        var _this = _super.call(this, validatorService) || this;
        _this.fieldValueChange = new EventEmitter();
        _this.key = '';
        _this.marginLeft = '';
        _this.marginTop = '';
        _this.marginRight = '';
        _this.marginBottom = '';
        return _this;
    }
    EasyCheckBoxComponent.prototype.onChange = function () {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, true));
    };
    EasyCheckBoxComponent.prototype.click = function () {
    };
    return EasyCheckBoxComponent;
}(EasyFormComponent));
EasyCheckBoxComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-checkbox',
                template: "<div class=\"easy-checkbox xxxx\"><mat-checkbox [id]=\"key\" [(ngModel)]=\"value\" (change)=\"onChange();\" (margin-left)=\"marginLeft\" (margin-top)=\"marginTop\" (margin-right)=\"marginRight\" (margin-bottom)=\"marginBottom\" (click)=\"click(); $event.stopPropagation();\">\n                {{placeholder}}\n               </mat-checkbox></div>",
                styles: []
            },] },
];
EasyCheckBoxComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
]; };
EasyCheckBoxComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "value": [{ type: Input, args: ['value',] },],
    "key": [{ type: Input, args: ['key',] },],
    "marginLeft": [{ type: Input, args: ['marginLeft',] },],
    "marginTop": [{ type: Input, args: ['marginTop',] },],
    "marginRight": [{ type: Input, args: ['marginRight',] },],
    "marginBottom": [{ type: Input, args: ['marginBottom',] },],
};
var CheckboxListItem = /** @class */ (function () {
    function CheckboxListItem(displayValue, value) {
        this.displayValue = displayValue;
        this.value = value;
    }
    return CheckboxListItem;
}());
var EasyCheckBoxGroupComponent = /** @class */ (function (_super) {
    __extends(EasyCheckBoxGroupComponent, _super);
    function EasyCheckBoxGroupComponent(validatorService) {
        var _this = _super.call(this, validatorService) || this;
        _this.fieldValueChange = new EventEmitter();
        _this.value = [];
        _this.key = '';
        _this.items = [];
        _this.checkboxListItems = [];
        return _this;
    }
    EasyCheckBoxGroupComponent.prototype.ngOnInit = function () {
        if (this.value == null)
            this.value = [];
        var _loop_1 = function (item) {
            var checked = this_1.value.any(function (x) { return x == item.value; });
            var checkboxItem = new CheckboxListItem(item.displayValue, item.value);
            checkboxItem.checked = checked;
            this_1.checkboxListItems.add(checkboxItem);
        };
        var this_1 = this;
        try {
            for (var _a = __values(this.items), _b = _a.next(); !_b.done; _b = _a.next()) {
                var item = _b.value;
                _loop_1(item);
            }
        }
        catch (e_7_1) { e_7 = { error: e_7_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_7) throw e_7.error; }
        }
        var e_7, _c;
    };
    EasyCheckBoxGroupComponent.prototype.onChange = function () {
        this.value = [];
        try {
            for (var _a = __values(this.checkboxListItems), _b = _a.next(); !_b.done; _b = _a.next()) {
                var item = _b.value;
                if (item.checked)
                    this.value.push(item.value);
            }
        }
        catch (e_8_1) { e_8 = { error: e_8_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_8) throw e_8.error; }
        }
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, true));
        var e_8, _c;
    };
    return EasyCheckBoxGroupComponent;
}(EasyFormComponent));
EasyCheckBoxGroupComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-checkbox-group',
                template: "<div class=\"checkbox-group-container\">\n                <span>{{placeholder}}</span>\n                <div *ngFor=\"let item of checkboxListItems\" class=\"checkbox-group\">\n                    <mat-checkbox [(ngModel)]=\"item.checked\" (change)=\"onChange()\">\n                        {{item.displayValue}} \n                    </mat-checkbox>\n               </div>\n              </div>",
                styles: [".checkbox-group-container {\n                display: flex;\n                flex-direction: column;\n                margin-top: 20px;\n              }\n              \n              .checkbox-group {\n                display: flex;\n                flex-direction: column;\n                padding-left: 20px;\n              }"]
            },] },
];
EasyCheckBoxGroupComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
]; };
EasyCheckBoxGroupComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "value": [{ type: Input, args: ['value',] },],
    "key": [{ type: Input, args: ['key',] },],
    "items": [{ type: Input, args: ['items',] },],
};
var TableDatabase = /** @class */ (function () {
    function TableDatabase(data) {
        this.dataChange = new BehaviorSubject([]);
        this.dataChange.next(data);
    }
    Object.defineProperty(TableDatabase.prototype, "data", {
        get: function () { return this.dataChange.value; },
        enumerable: true,
        configurable: true
    });
    return TableDatabase;
}());
var TableDataSource = /** @class */ (function (_super) {
    __extends(TableDataSource, _super);
    function TableDataSource(database, sort, columns, paginator) {
        var _this = _super.call(this) || this;
        _this.database = database;
        _this.sort = sort;
        _this.columns = columns;
        _this.paginator = paginator;
        _this.filterChange = new BehaviorSubject('');
        _this.paginatorInitialized = false;
        _this.renderedData = [];
        _this.displayDataChanges = [
            _this.database.dataChange,
            _this.sort.sortChange,
            _this.filterChange
        ];
        return _this;
    }
    Object.defineProperty(TableDataSource.prototype, "filter", {
        get: function () { return this.filterChange.value; },
        set: function (filter) { this.filterChange.next(filter); },
        enumerable: true,
        configurable: true
    });
    TableDataSource.prototype.setPaginator = function (paginator) {
        if (paginator != null && !this.paginatorInitialized) {
            this.paginator = paginator;
            this.displayDataChanges.add(this.paginator.page);
            this.paginatorInitialized = true;
            this.filterChange.next(this.filter);
        }
    };
    TableDataSource.prototype.connect = function () {
        var _this = this;
        var page = this.paginator == null ? null : this.paginator.page;
        if (this.paginator != null)
            this.setPaginator(this.paginator);
        return Observable.merge.apply(Observable, __spread(this.displayDataChanges)).map(function () {
            var data = _this.database.data;
            data = data.slice().filter(function (item) {
                var searchStr = "";
                try {
                    for (var _a = __values(_this.columns), _b = _a.next(); !_b.done; _b = _a.next()) {
                        var column = _b.value;
                        if (item[column] != undefined) {
                            var sValue = item[column].toString();
                            searchStr += sValue.toLowerCase();
                        }
                    }
                }
                catch (e_9_1) { e_9 = { error: e_9_1 }; }
                finally {
                    try {
                        if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
                    }
                    finally { if (e_9) throw e_9.error; }
                }
                return searchStr.indexOf(_this.filter.toLowerCase()) != -1;
                var e_9, _c;
            });
            if (_this.paginator != null) {
                var startIndex = _this.paginator.pageIndex * _this.paginator.pageSize;
                data = data.splice(startIndex, _this.paginator.pageSize);
            }
            _this.renderedData = _this.getSortedData(data);
            return _this.renderedData;
        });
    };
    TableDataSource.prototype.disconnect = function () { };
    TableDataSource.prototype.getSortedData = function (data) {
        var _this = this;
        if (!this.sort.active || this.sort.direction == '') {
            return data;
        }
        return data.sort(function (a, b) {
            var propertyA = '';
            var propertyB = '';
            _a = __read([a[_this.sort.active], b[_this.sort.active]], 2), propertyA = _a[0], propertyB = _a[1];
            var valueA = isNaN(+propertyA) ? propertyA : +propertyA;
            var valueB = isNaN(+propertyB) ? propertyB : +propertyB;
            return (valueA < valueB ? -1 : 1) * (_this.sort.direction == 'asc' ? 1 : -1);
            var _a;
        });
    };
    return TableDataSource;
}(DataSource));
var Sortable = /** @class */ (function () {
    function Sortable() {
    }
    return Sortable;
}());
var EasyTableComponent = /** @class */ (function () {
    function EasyTableComponent(iterableDiffers) {
        this.iterableDiffers = iterableDiffers;
        this.rows = [];
        this.actions = [];
        this.showFilter = false;
        this.showPaginator = false;
        this.pageIndex = 0;
        this.pageSize = 25;
        this.totalItems = 0;
        this.displayColumns = [];
        this.colCounts = 0;
        this.fieldValueChange = new EventEmitter();
        this.pageChange = new EventEmitter();
        this.iterableDiffer = this.iterableDiffers.find([]).create(null);
    }
    EasyTableComponent.prototype.ngOnInit = function () {
        this.displayColumns.length = 0;
        this.totalItems = 0;
        this.pageIndex = 0;
        this.pageSize = 25;
        try {
            for (var _a = __values(this.columns.where(function (x) { return !x.hide && x.type != "hidden"; })), _b = _a.next(); !_b.done; _b = _a.next()) {
                var column = _b.value;
                this.displayColumns.push(column.key);
            }
        }
        catch (e_10_1) { e_10 = { error: e_10_1 }; }
        finally {
            try {
                if (_b && !_b.done && (_c = _a.return)) _c.call(_a);
            }
            finally { if (e_10) throw e_10.error; }
        }
        if (this.actions.length > 0 && !this.columns.any(function (x) { return x.key == "Actions"; })) {
            try {
                for (var _d = __values(this.rows), _e = _d.next(); !_e.done; _e = _d.next()) {
                    var item = _e.value;
                    item["Actions"] = "Placeholder";
                }
            }
            catch (e_11_1) { e_11 = { error: e_11_1 }; }
            finally {
                try {
                    if (_e && !_e.done && (_f = _d.return)) _f.call(_d);
                }
                finally { if (e_11) throw e_11.error; }
            }
            this.displayColumns.push("Actions");
            this.columns.push(new EasyButtonField({ type: ColumnTypes.column_type_actions, key: "Actions", label: "Actions" }));
        }
        this.database = new TableDatabase(this.rows);
        if (this.totalItems === 0) {
            this.totalItems = this.database.data.length;
        }
        var e_10, _c, e_11, _f;
    };
    EasyTableComponent.prototype.ngDoCheck = function () {
        if (this.dataSource == null) {
            if (this.showFilter && this.showPaginator && this.filter != null && this.paginator != null) {
                this.dataSource = new TableDataSource(this.database, this.sort, this.displayColumns, this.paginator);
                this.initializeFilter();
            }
            else if (this.showFilter && this.filter != null) {
                this.dataSource = new TableDataSource(this.database, this.sort, this.displayColumns, this.paginator);
                this.initializeFilter();
            }
            else if (this.showPaginator && this.paginator != null) {
                this.dataSource = new TableDataSource(this.database, this.sort, this.displayColumns, this.paginator);
            }
            else if (!this.showFilter && !this.showPaginator) {
                this.dataSource = new TableDataSource(this.database, this.sort, this.displayColumns, this.paginator);
            }
            if (this.totalItems === 0) {
                this.totalItems = this.database.data.length;
            }
        }
        var changes = this.iterableDiffer.diff(this.rows);
        if (changes) {
            this.database.dataChange.next(this.rows);
        }
    };
    EasyTableComponent.prototype.initializeFilter = function () {
        var _this = this;
        if (this.filter != null)
            Observable.fromEvent(this.filter.nativeElement, 'keyup')
                .debounceTime(150)
                .distinctUntilChanged()
                .subscribe(function () {
                if (!_this.dataSource) {
                    return;
                }
                _this.dataSource.filter = _this.filter.nativeElement.value;
            });
    };
    EasyTableComponent.prototype.sortData = function (sort) {
        this.sort.direction = sort.direction;
        this.sort.active = sort.active;
        var sortable = new Sortable();
        sortable.id = sort.active;
        sortable.start = sort.direction == 'asc' ? 'asc' : 'desc';
        this.sort.sort(sortable);
    };
    EasyTableComponent.prototype.getField = function (column, row) {
        var _this = this;
        var field = new EasyField(column.options);
        var value = Object.keys(row).single(function (x) { return x == column.key; });
        field.value = row[value];
        field.label = "";
        field.marginLeft = column.marginLeft;
        field.marginTop = column.marginTop;
        field.marginRight = column.marginRight;
        field.marginBottom = column.marginBottom;
        field.onChange.subscribe(function (field) {
            var rowKey = Object.keys(row).single(function (x) { return x == field.key.split('|')[0]; });
            row[rowKey] = field.value;
            _this.fieldValueChange.emit(new FieldChangeDto("", _this.rows, true));
        });
        if (field.type === 'control') {
            field.key = field.key + '|' + this.colCounts.toString();
            this.colCounts++;
        }
        return field;
    };
    EasyTableComponent.prototype.clearFilter = function () {
        this.filter.nativeElement.value = "";
        if (!this.dataSource) {
            return;
        }
        this.dataSource.filter = this.filter.nativeElement.value;
    };
    EasyTableComponent.prototype.click = function (action, row) {
        var rowIndex = this.rows.indexOf(row);
        row.rowIndex = rowIndex;
        action(row);
    };
    EasyTableComponent.prototype.rowClicked = function (row) {
        var rowIndex = this.rows.indexOf(row);
        row.rowIndex = rowIndex;
        if (this.actions.length > 0) {
            this.actions[0].action(row);
        }
    };
    EasyTableComponent.prototype.getValue = function (column, row) {
        var name = column.key.split(' ').join('');
        return row[name];
    };
    EasyTableComponent.prototype.onPageChange = function (event) {
        this.pageChange.emit(event);
    };
    return EasyTableComponent;
}());
EasyTableComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-table',
                template: "\n    <div class=\"table-container mat-elevation-z8\">\n      <div style=\"overflow-x: auto\">\n        <div class=\"table-header\" *ngIf=\"rows.length > 0 && showFilter\">\n          <mat-form-field floatPlaceholder=\"never\">\n            <input matInput #filter placeholder=\"Filter\">\n            <easy-button matSuffix color=\"\" type=\"mat-icon-button\" displayValue=\"\" icon=\"clear\" (onClicked)=\"clearFilter();\"></easy-button>\n          </mat-form-field>\n        </div>\n\n        <mat-table #table [dataSource]=\"dataSource\" matSort>\n      \n          <div *ngFor=\"let column of columns\">      \n            <ng-container [cdkColumnDef]=\"column.key\" >\n              <mat-header-cell [style.min-width]=\"column.minWidth\" [style.max-width]=\"column.maxWidth\" [style.width]=\"column.width\" [style.text-align]=\"column.textAlign\" [style.margin-left]=\"column.marginLeft\" [style.margin-right]=\"column.marginRight\" *cdkHeaderCellDef mat-sort-header>{{column.label == 'Actions' ? '' : column.label }}</mat-header-cell>\n              <mat-cell [style.min-width]=\"column.minWidth\" [style.max-width]=\"column.maxWidth\" [style.width]=\"column.width\" [style.text-align]=\"column.textAlign\" [style.margin-left]=\"column.marginLeft\" [style.margin-right]=\"column.marginRight\" *cdkCellDef=\"let row\">\n                <div [ngSwitch]=\"column.type\">\n                  <span *ngSwitchCase=\"'actions'\" class=\"button-row\">\n                    <div *ngFor=\"let action of actions; let indexAction = index\"> \n                      <easy-button [key]=\"action.key + indexRow + indexAction\" [icon]=\"action.icon\" [color]=\"action.color\" [displayValue]=\"action.label\" [type]=\"action.type\" (onClicked)=\"click(action.action,row)\"></easy-button>\n                    </div>\n                  </span>\n                  <span *ngSwitchCase=\"'date'\">\n                    {{row[column.key] | date:column.format}}\n                  </span>\n                  <easy-form-field *ngSwitchCase=\"'control'\" fxFlex=\"auto\" [field]=\"getField(column,row)\" (fieldValueChange)=\"valueChanged($event)\"></easy-form-field>\n                  <span *ngSwitchDefault>\n                    {{row[column.key]}}\n                  </span>\n                </div>                 \n              </mat-cell>\n            </ng-container>\n          </div>\n      \n          <mat-header-row *cdkHeaderRowDef=\"displayColumns\"></mat-header-row>\n          <mat-row *cdkRowDef=\"let row; columns: displayColumns;\" (click)=\"rowClicked(row)\"></mat-row>\n      \n        </mat-table>\n    \n        <div class=\"no-results\" [style.display]=\"dataSource == null || dataSource.renderedData.length == 0 ? '' : 'none'\">\n          No data to display\n        </div>\n      </div>\n      <mat-paginator *ngIf=\"rows.length > 0 && showPaginator\" #paginator [length]=\"totalItems\" [pageIndex]=\"pageIndex\" [pageSize]=\"pageSize\"\n        [pageSizeOptions]=\"[5, 10, 25, 100]\" [style.visibility]=\"rows.length > 0\" (page)=\"onPageChange($event)\">\n      </mat-paginator>\n  </div>",
                styles: ["\n  .table-container {\n    display: flex;\n    flex-direction: column;\n    min-width: 300px;\n    margin-bottom: 30px;\n  }\n  \n  .table-header {\n    min-height: 56px;\n    max-height: 56px;\n    display: flex;\n    align-items: center;\n    padding: 8px 24px 0;\n    font-size: 20px;\n    justify-content: space-between;\n    border-bottom: 1px solid transparent;\n  }\n  \n  mat-header-cell {\n    margin-right: 10px;\n  }\n  \n  mat-cell {\n    margin-right: 10px;\n  }\n  \n  mat-form-field {\n    font-size: 14px;\n    flex-grow: 1;\n    margin-left: 32px;\n    margin-top: 8px;\n  }\n  \n  .no-results {\n    display: flex;\n    justify-content: center;\n    padding: 24px;\n    font-size: 12px;\n    font-style: italic;\n  }\n  \n  mat-table {\n    overflow: auto;\n    max-height: 500px;\n  }\n  \n  mat-row {\n    cursor: pointer;\n  }\n  \n  mat-row:hover {\n    background: lightgray;\n  }\n  \n  .button-row {\n    display: flex;\n    align-items: right;\n    justify-content: flex-end;\n  }\n"]
            },] },
];
EasyTableComponent.ctorParameters = function () { return [
    { type: IterableDiffers, },
]; };
EasyTableComponent.propDecorators = {
    "columns": [{ type: Input },],
    "rows": [{ type: Input },],
    "actions": [{ type: Input },],
    "showFilter": [{ type: Input },],
    "showPaginator": [{ type: Input },],
    "pageIndex": [{ type: Input },],
    "pageSize": [{ type: Input },],
    "totalItems": [{ type: Input },],
    "sort": [{ type: ViewChild, args: [MatSort,] },],
    "filter": [{ type: ViewChild, args: ['filter',] },],
    "paginator": [{ type: ViewChild, args: [MatPaginator,] },],
    "fieldValueChange": [{ type: Output },],
    "pageChange": [{ type: Output },],
};
var EasyAutocompleteComponent = /** @class */ (function (_super) {
    __extends(EasyAutocompleteComponent, _super);
    function EasyAutocompleteComponent(validatorService) {
        var _this = _super.call(this, validatorService) || this;
        _this.placeholder = '';
        _this.key = '';
        _this.fieldValueChange = new EventEmitter();
        _this.filteredItems = _this.formControl.valueChanges.startWith(null)
            .map(function (x) { return x ? _this.filter(x) : _this.items.slice(); });
        return _this;
    }
    EasyAutocompleteComponent.prototype.onChange = function (item) {
        this.selectedValue = item;
        this.formControl.setValue(item);
        this.formControl.updateValueAndValidity();
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.selectedValue, this.formControl.valid));
    };
    EasyAutocompleteComponent.prototype.filter = function (name) {
        return this.items.filter(function (x) { return x.toLowerCase().indexOf(name.toLowerCase()) === 0; });
    };
    return EasyAutocompleteComponent;
}(EasyFormComponent));
EasyAutocompleteComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-autocomplete',
                template: "<mat-form-field class='easy-autocomplete'>\n                    <input matInput [placeholder]=\"placeholder\" [matAutocomplete]=\"auto\" [(ngModel)]=\"selectedValue\" [formControl]=\"formControl\">\n                    <mat-error *ngIf=\"formControl.hasError('required')\">{{this.getError('required')}}</mat-error>\n                    <mat-autocomplete #auto=\"matAutocomplete\">\n                        <mat-option *ngFor=\"let item of filteredItems | async\" [value]=\"item\" (onSelectionChange)=\"onChange(item)\">\n                            {{ item }}\n                        </mat-option>\n                    </mat-autocomplete>\n                </mat-form-field>",
                styles: [".easy-autocomplete {\n                  margin-top: 20px;\n                  width: 100%;\n                }"]
            },] },
];
EasyAutocompleteComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
]; };
EasyAutocompleteComponent.propDecorators = {
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "key": [{ type: Input, args: ['key',] },],
    "selectedValue": [{ type: Input, args: ['selectedValue',] },],
    "items": [{ type: Input, args: ['items',] },],
    "fieldValueChange": [{ type: Output },],
};
var EasyAutocompleteKeyValueComponent = /** @class */ (function (_super) {
    __extends(EasyAutocompleteKeyValueComponent, _super);
    function EasyAutocompleteKeyValueComponent(validatorService, iterableDiffers) {
        var _this = _super.call(this, validatorService) || this;
        _this.iterableDiffers = iterableDiffers;
        _this.key = '';
        _this.fieldValueChange = new EventEmitter();
        _this.filteredItems = _this.formControl.valueChanges.startWith(null)
            .map(function (x) { return x && typeof x === 'object' ? x.value : x; })
            .map(function (x) { return x ? _this.filter(x) : _this.items.slice(); });
        _this.iterableDiffer = _this.iterableDiffers.find([]).create(null);
        return _this;
    }
    EasyAutocompleteKeyValueComponent.prototype.displayFn = function (item) {
        if (item == null)
            return "";
        return item.value;
    };
    EasyAutocompleteKeyValueComponent.prototype.ngDoCheck = function () {
        var _this = this;
        var changes = this.iterableDiffer.diff(this.items);
        if (changes) {
            var item = this.items.singleOrDefault(function (x) { return x.key == _this.selectedValue; });
            if (item == null)
                return;
            this.selectedValue = item.key;
            if (this.selectedValue != null && this.selectedValue != "")
                this.onChange(item);
        }
    };
    EasyAutocompleteKeyValueComponent.prototype.onChange = function (item) {
        this.selectedValue = item.key;
        this.formControl.setValue(item.value);
        this.formControl.updateValueAndValidity();
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.selectedValue, this.formControl.valid));
    };
    EasyAutocompleteKeyValueComponent.prototype.filter = function (name) {
        return this.items.filter(function (x) { return x.value.toLowerCase().indexOf(name.toLowerCase()) === 0; });
    };
    return EasyAutocompleteKeyValueComponent;
}(EasyFormComponent));
EasyAutocompleteKeyValueComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-autocomplete-key-value',
                template: "<mat-form-field class='easy-autocomplete'>\n                    <input matInput [placeholder]=\"placeholder\" [matAutocomplete]=\"auto\" [formControl]=\"formControl\">\n                    <mat-error *ngIf=\"formControl.hasError('required')\">{{this.getError('required')}}</mat-error>\n\n                    <mat-autocomplete #auto=\"matAutocomplete\">\n                        <mat-option *ngFor=\"let item of filteredItems | async\" [value]=\"item\" (onSelectionChange)=\"onChange(item)\">\n                            {{ item.value }}\n                        </mat-option>\n                    </mat-autocomplete>\n                </mat-form-field>",
                styles: ["\n      .easy-autocomplete {\n        margin-top: 20px;\n        width: 100%;\n      }"]
            },] },
];
EasyAutocompleteKeyValueComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
    { type: IterableDiffers, },
]; };
EasyAutocompleteKeyValueComponent.propDecorators = {
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "items": [{ type: Input, args: ['items',] },],
    "selectedValue": [{ type: Input, args: ['selectedValue',] },],
    "key": [{ type: Input, args: ['key',] },],
    "fieldValueChange": [{ type: Output },],
};
var SpinnerComponent = /** @class */ (function () {
    function SpinnerComponent() {
        this.size = 25;
        this.thickness = 2;
        this.color = '#4f6aa7';
        this.opacity = '.1';
        this.secondColor = '';
    }
    SpinnerComponent.prototype.ngOnInit = function () {
        var c = this.hexToRgb(this.color);
        this.secondColor = 'rgba(' + c.r + ',' + c.g + ',' + c.b + ', ' + this.opacity + ')';
    };
    SpinnerComponent.prototype.hexToRgb = function (hex) {
        var result = /^#?([a-f\d]{2})([a-f\d]{2})([a-f\d]{2})$/i.exec(hex);
        return result ? {
            r: parseInt(result[1], 16),
            g: parseInt(result[2], 16),
            b: parseInt(result[3], 16)
        } : null;
    };
    return SpinnerComponent;
}());
SpinnerComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-spinner',
                template: '',
                styles: ["\n    @keyframes spin {\n      from {transform: rotate(0deg);}\n      to {transform: rotate(360deg);}\n    }\n\n    :host {\n      position:relative;\n      box-sizing: border-box;\n      display:inline-block;\n      padding:0px;\n      border-radius:100%;\n      border-style:solid;\n      animation: spin 0.8s linear infinite;\n    }\n\n    :host .margins {\n        margin: 0px 10px;\n    }\n  "]
            },] },
];
SpinnerComponent.propDecorators = {
    "size": [{ type: Input }, { type: HostBinding, args: ['style.width.px',] }, { type: HostBinding, args: ['style.height.px',] },],
    "thickness": [{ type: Input }, { type: HostBinding, args: ['style.borderWidth.px',] },],
    "color": [{ type: Input }, { type: HostBinding, args: ['style.borderTopColor',] },],
    "opacity": [{ type: Input },],
    "secondColor": [{ type: HostBinding, args: ['style.borderBottomColor',] }, { type: HostBinding, args: ['style.borderLeftColor',] }, { type: HostBinding, args: ['style.borderRightColor',] },],
};
var EasyDatePickerComponent = /** @class */ (function (_super) {
    __extends(EasyDatePickerComponent, _super);
    function EasyDatePickerComponent(validatorService, dateAdapter) {
        var _this = _super.call(this, validatorService) || this;
        _this.dateAdapter = dateAdapter;
        _this.fieldValueChange = new EventEmitter();
        _this.value = null;
        _this.key = '';
        _this.hint = '';
        _this.dateAdapter.setLocale('en-ZA');
        return _this;
    }
    EasyDatePickerComponent.prototype.ngOnInit = function () {
        if (this.readonly)
            this.formControl.disable();
        var date2 = this.dateAdapter.parse(this.value, "dd/MM/yyyy");
        if (this.value == null || this.value == '' || this.value == "Invalid Date")
            this.formControl.setValue(null);
        else
            this.formControl.setValue(date2);
        _super.prototype.ngOnInit.call(this);
    };
    EasyDatePickerComponent.prototype.onChange = function () {
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, this.formControl.valid));
    };
    EasyDatePickerComponent.prototype.onselectedChanged = function (date) {
        var parsedDate = this.dateAdapter.parse(date, "dd/MM/yyyy");
        this.value = date;
        this.formControl.setValue(parsedDate);
        this.formControl.updateValueAndValidity();
        this.fieldValueChange.emit(new FieldChangeDto(this.key, this.value, this.formControl.valid));
    };
    return EasyDatePickerComponent;
}(EasyFormComponent));
EasyDatePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-date-picker',
                template: "<mat-form-field class=\"easy-date-picker\">\n                <input matInput [matDatepicker]=\"myDatepicker\" [placeholder]='placeholder' (change)=\"onChange()\" [formControl]=\"formControl\"/>\n                    <mat-datepicker-toggle matSuffix [for]=\"myDatepicker\"></mat-datepicker-toggle>                    \n                    <mat-hint>{{hint}}</mat-hint>\n                    <mat-datepicker #myDatepicker (selectedChanged)=\"onselectedChanged($event)\"></mat-datepicker>\n                    <mat-error *ngIf=\"formControl.hasError('required')\">{{this.getError('required')}}</mat-error>\n                    <mat-error *ngIf=\"formControl.hasError('maxlength')\">{{this.getError('maxlength')}}</mat-error>\n                    <mat-error *ngIf=\"formControl.hasError('minlength')\">{{this.getError('minlength')}}</mat-error>\n                    <mat-error *ngIf=\"formControl.hasError('pattern')\">{{this.getError('pattern')}}</mat-error>\n                </mat-form-field>",
                styles: ["\n                  .easy-date-picker {\n                    margin-top: 20px;\n                    width: 100%;\n                  }"]
            },] },
];
EasyDatePickerComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
    { type: DateAdapter, },
]; };
EasyDatePickerComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "value": [{ type: Input, args: ['value',] },],
    "key": [{ type: Input, args: ['key',] },],
    "readonly": [{ type: Input, args: ['readonly',] },],
    "hint": [{ type: Input, args: ['hint',] },],
};
var EasyFormComponent$1 = /** @class */ (function () {
    function EasyFormComponent$1(easyFabService) {
        this.easyFabService = easyFabService;
    }
    EasyFormComponent$1.prototype.ngOnInit = function () {
        this.easyFabService.initialize(this.form.actions);
    };
    EasyFormComponent$1.prototype.ngOnDestroy = function () {
        this.easyFabService.uninitialize();
    };
    return EasyFormComponent$1;
}());
EasyFormComponent$1.decorators = [
    { type: Component, args: [{
                selector: 'easy-form',
                template: "<div *ngFor=\"let toolbarContainer of form.toolbarContainers\">\n                          <mat-toolbar color=\"primary\">\n                            <div *ngFor=\"let toolbar of toolbarContainer.toolbars\" class=\"toolbar-row\">\n\n                            <button mat-icon-button [matMenuTriggerFor]=\"toolbarMenu\" *ngFor=\"let menu of toolbar.menus\">\n                              <mat-icon>more_vert</mat-icon>\n                              <mat-menu #toolbarMenu=\"matMenu\">\n                                <button *ngFor=\"let field of menu\" mat-menu-item [disabled]=\"field.show\" (click)=\"field.action()\">\n                                  <span *ngIf=\"!field.show\">{{field.label}}</span>\n                                </button>\n                              </mat-menu>                     \n                            </button>\n\n                            <div *ngFor=\"let field of toolbar.fields\">\n                              <div [ngSwitch]=\"field.controlType\">\n                                <easy-form-field *ngSwitchCase=\"'button'\" [field]=\"field\"></easy-form-field>\n                                <span *ngSwitchCase=\"'toolbar-text'\">\n                                  {{field.label}}\n                                </span>                            \n                              </div>            \n                            </div>\n                            </div>\n                          </mat-toolbar>\n                        </div>\n            \n            <div fxLayout=\"row\" style=\"padding-top:10px;padding-bottom:10px;\" fxLayoutAlign=\"center\">                                      \n                      \n              <div [fxFlex.xl]=\"form.xlSize\" [fxFlex.lg]=\"form.lgSize\" [fxFlex.md]=\"form.mdSize\" [fxFlex.sm]=\"form.smSize\" [fxFlex.xs]=\"form.xsSize\">\n                <easy-container [layout]='form.layout' [containers]='form.getContainers()'></easy-container>\n              </div>\n            </div>",
                styles: [".checkbox-group-container {\n              display: flex;\n              flex-direction: column;\n              margin-top: 20px;\n            }\n\n            .toolbar-row {\n              display: flex;\n              flex-direction: row;\n            }\n            \n            .checkbox-group {\n              display: flex;\n              flex-direction: column;\n              padding-left: 20px;\n            }\n            \n            .easy-checkbox {\n              margin-top: 100px;\n            }\n            \n            .button-row {\n              display: flex;\n              align-items: right;\n              justify-content: flex-end;\n            }\n            \n            .easy-date-picker {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-select {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-input {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-autocomplete {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-button {\n              margin: 8px;\n              text-transform: uppercase;\n            }\n            \n            .input-icon {\n              font-size: 24px;\n              height: 24px;\n              width: 24px;\n            }\n            \n            .full-width {\n              width: 100vw;\n            }"],
                providers: [EasyFormService]
            },] },
];
EasyFormComponent$1.ctorParameters = function () { return [
    { type: EasyFabService, },
]; };
EasyFormComponent$1.propDecorators = {
    "form": [{ type: Input },],
};
var RequiredDirective = /** @class */ (function () {
    function RequiredDirective(el) {
        this.el = el;
        this.validators = [];
    }
    RequiredDirective.prototype.ngOnInit = function () {
        if (this.validators == null || this.validators.length)
            return;
        var requiredValidators = this.validators.filter(function (x) { return x.validatorType == ValidatorType.required; });
        if (requiredValidators.length > 0)
            this.el.nativeElement.required = true;
    };
    return RequiredDirective;
}());
RequiredDirective.decorators = [
    { type: Directive, args: [{ selector: '[easy-required]' },] },
];
RequiredDirective.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
RequiredDirective.propDecorators = {
    "validators": [{ type: Input, args: ['validators',] },],
};
var MaxLengthDirective = /** @class */ (function () {
    function MaxLengthDirective(el) {
        this.el = el;
    }
    MaxLengthDirective.prototype.ngOnInit = function () {
        if (this.easyMaxLength == 0 || this.easyMaxLength == null)
            return;
        this.el.nativeElement.maxLength = this.easyMaxLength;
    };
    return MaxLengthDirective;
}());
MaxLengthDirective.decorators = [
    { type: Directive, args: [{ selector: '[easy-max-length]' },] },
];
MaxLengthDirective.ctorParameters = function () { return [
    { type: ElementRef, },
]; };
MaxLengthDirective.propDecorators = {
    "easyMaxLength": [{ type: Input, args: ['easy-max-length',] },],
};
var EasyFormFieldComponent = /** @class */ (function () {
    function EasyFormFieldComponent() {
    }
    EasyFormFieldComponent.prototype.valueChanged = function (event) {
        this.field.valueChanged(event);
    };
    EasyFormFieldComponent.prototype.executeAction = function (action) {
        action(this.field);
    };
    EasyFormFieldComponent.prototype.tablePageChanged = function (event) {
        var tableField = (this.field);
        tableField.pageChanged(event);
    };
    return EasyFormFieldComponent;
}());
EasyFormFieldComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-form-field',
                template: "<div [ngSwitch]=\"field.controlType\">\n  \n    <easy-input [key]=\"field.key\"  *ngSwitchCase=\"'textbox'\" [readonly]=\"containerReadonly || field.readonly\" [validators]=\"field.validators\" [maxLength]=\"field.maxLength\" [placeholder]=\"field.label\" [value]=\"field.value\" (fieldValueChange)=\"valueChanged($event)\" [type]=\"field.type\" [options]=\"field.pristine\" [hint]=\"field.hint\" [onEnter]=\"field.onEnter\"></easy-input>\n    \n    <easy-text-area [key]=\"field.key\" [height]=\"field.height\" [minHeight]=\"field.minHeight\" [maxHeight]=\"field.maxHeight\" *ngSwitchCase=\"'textArea'\" [readonly]=\"containerReadonly || field.readonly\" [validators]=\"field.validators\" [maxLength]=\"field.maxLength\" [placeholder]=\"field.label\" [value]=\"field.value\" (fieldValueChange)=\"valueChanged($event)\" [options]=\"field.pristine\"></easy-text-area>\n  \n    <easy-select [key]=\"field.key\" [easy-required]=\"field.validators\" [readonly]=\"containerReadonly || field.readonly\" *ngSwitchCase=\"'select'\" [validators]=\"field.validators\" [placeholder]=\"field.label\" [selectedValue]=\"field.value\" [items]=\"field.items\" (fieldValueChange)=\"valueChanged($event)\" [options]=\"field.pristine\"></easy-select>\n  \n    <easy-select-key-value [key]=\"field.key\" [easy-required]=\"field.validators\" [readonly]=\"containerReadonly || field.readonly\" [validators]=\"field.validators\" *ngSwitchCase=\"'select-key-value'\" [placeholder]=\"field.label\" [selectedValue]=\"field.value\" [items]=\"field.items\" (fieldValueChange)=\"valueChanged($event)\" [options]=\"field.pristine\"></easy-select-key-value>\n  \n    <easy-radio-button [key]=\"field.key\" [easy-required]=\"field.validators\" [readonly]=\"containerReadonly || field.readonly\" [validators]=\"field.validators\" *ngSwitchCase=\"'radio-button'\" [placeholder]=\"field.label\" [selectedValue]=\"field.value\" [items]=\"field.items\" (fieldValueChange)=\"valueChanged($event)\" [options]=\"field.pristine\"></easy-radio-button>\n  \n    <easy-checkbox [key]=\"field.key\" *ngSwitchCase=\"'checkbox'\" [readonly]=\"containerReadonly || field.readonly\" [placeholder]=\"field.label\" [(value)]=\"field.value\" (fieldValueChange)=\"valueChanged($event)\" [marginLeft]=\"field.marginLeft\" [marginTop]=\"field.marginTop\" [marginRight]=\"field.marginRight\" [marginBottom]=\"field.marginBottom\"></easy-checkbox>\n  \n    <easy-checkbox-group [key]=\"field.key\" *ngSwitchCase=\"'checkbox-group'\" [readonly]=\"containerReadonly || field.readonly\" [placeholder]=\"field.label\" [(value)]=\"field.value\" [items]=\"field.items\" (fieldValueChange)=\"valueChanged($event)\"></easy-checkbox-group>\n  \n    <easy-autocomplete [key]=\"field.key\" *ngSwitchCase=\"'autocomplete'\" [readonly]=\"containerReadonly || field.readonly\" [validators]=\"field.validators\" [placeholder]=\"field.label\" [items]=\"field.items\" [selectedValue]=\"field.value\" (fieldValueChange)=\"valueChanged($event)\" [options]=\"field.pristine\"></easy-autocomplete>\n  \n    <easy-autocomplete-key-value [key]=\"field.key\" *ngSwitchCase=\"'autocomplete-key-value'\" [readonly]=\"containerReadonly || field.readonly\" [validators]=\"field.validators\" [placeholder]=\"field.label\" [items]=\"field.items\" [selectedValue]=\"field.value\" (fieldValueChange)=\"valueChanged($event)\" [options]=\"field.pristine\"></easy-autocomplete-key-value>\n  \n    <easy-button [key]=\"field.key\" class=\"right\" *ngSwitchCase=\"'button'\" [color]=\"field.color\" [icon]=\"field.icon\" [type]=\"field.type\" [displayValue]=\"field.label\" [showLoader]=\"field.showLoader\" (onClicked)=\"executeAction(field.action)\"></easy-button>\n  \n    <easy-table *ngSwitchCase=\"'table'\" [rows]=\"field.rows\" [columns]=\"field.columns\" [actions]=\"field.actions\" [showFilter]=\"field.showFilter\" [showPaginator]=\"field.showPaginator\" [pageIndex]=\"field.pageIndex\" [pageSize]=\"field.pageSize\" [totalItems]=\"field.totalItems\" (fieldValueChange)=\"valueChanged($event)\" (pageChange)=\"tablePageChanged($event)\"></easy-table>\n    \n    <easy-date-picker [key]=\"field.key\" *ngSwitchCase=\"'date-picker'\" [readonly]=\"containerReadonly || field.readonly\" [placeholder]=\"field.label\" [hint]=\"field.hint\" [value]=\"field.value\" [validators]=\"field.validators\" (fieldValueChange)=\"valueChanged($event)\" [options]=\"field.pristine\"></easy-date-picker>\n\n    <easy-date-time-picker [key]=\"field.key\" *ngSwitchCase=\"'date-time-picker'\" [readonly]=\"containerReadonly || field.readonly\" [placeholder]=\"field.label\" [hint]=\"field.hint\" [value]=\"field.value\" [validators]=\"field.validators\" (fieldValueChange)=\"valueChanged($event)\" [options]=\"field.pristine\"></easy-date-time-picker>    \n      \n    <easy-fileupload [key]=\"field.key\" *ngSwitchCase=\"'fileupload'\" [readonly]=\"containerReadonly || field.readonly\" [icon]=\"field.icon\" [color]=\"field.color\" [hint]=\"field.hint\" [placeholder]=\"field.label\" (fieldValueChange)=\"valueChanged($event)\" [type]=\"field.type\" [allowedExtensions]=\"field.allowedExtensions\"></easy-fileupload>  \n  \n    <easy-record *ngSwitchCase=\"'record'\" [source]=\"field.url\" [authorizationHeader]=\"field.authorizationHeader\"></easy-record>  \n  \n    <easy-form-content-actions *ngSwitchCase=\"'actions'\" [actions]=\"field.actions\"></easy-form-content-actions>    \n\n    <easy-divider *ngSwitchCase=\"'divider'\"></easy-divider>  \n  \n  </div>",
                styles: [".checkbox-group-container {\n    display: flex;\n    flex-direction: column;\n    margin-top: 20px;\n  }\n  \n  .checkbox-group {\n    display: flex;\n    flex-direction: column;\n    padding-left: 20px;\n  }\n  \n  .easy-checkbox {\n    margin-top: 100px;\n  }\n  \n  .button-row {\n    display: flex;\n    align-items: right;\n    justify-content: flex-end;\n  }\n  \n  .easy-date-picker {\n    margin-top: 20px;\n    width: 100%;\n  }\n  \n  .easy-select {\n    margin-top: 20px;\n    width: 100%;\n  }\n  \n  .easy-input {\n    margin-top: 20px;\n    width: 100%;\n  }\n  \n  .easy-autocomplete {\n    margin-top: 20px;\n    width: 100%;\n  }\n  \n  .easy-button {\n    margin: 8px;\n    text-transform: uppercase;\n  }\n  \n  .input-icon {\n    font-size: 24px;\n    height: 24px;\n    width: 24px;\n  }\n  \n  .full-width {\n    width: 100vw;\n  }"]
            },] },
];
EasyFormFieldComponent.propDecorators = {
    "field": [{ type: Input },],
    "containerReadonly": [{ type: Input },],
};
var EasyFormContentComponent = /** @class */ (function () {
    function EasyFormContentComponent() {
    }
    return EasyFormContentComponent;
}());
EasyFormContentComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-form-content',
                template: "<div fxLayout=\"row wrap\" style=\"overflow-y:hidden\">\n              <div *ngFor=\"let field of container.fields\" [fxFlex.xl]=\"container.getXlColumnSize(field)\" [fxFlex.lg]=\"container.getLgColumnSize(field)\"\n                  [fxFlex.md]=\"container.getMdColumnSize(field)\" [fxFlex.sm]=\"container.getSmColumnSize(field)\" [fxFlex.xs]=\"container.getXsColumnSize(field)\"\n                  fxLayoutAlign=\"start\">\n                  <easy-form-field fxFlex=\"auto\" *ngIf=\"!field.hide\" style=\"margin-left:10px\" [field]=\"field\" [containerReadonly]=\"container.readonly\"></easy-form-field>\n              </div>\n            </div>",
                styles: [".checkbox-group-container {\n              display: flex;\n              flex-direction: column;\n              margin-top: 20px;\n            }\n            \n            .checkbox-group {\n              display: flex;\n              flex-direction: column;\n              padding-left: 20px;\n            }\n            \n            .easy-checkbox {\n              margin-top: 100px;\n            }\n            \n            .button-row {\n              display: flex;\n              align-items: right;\n              justify-content: flex-end;\n            }\n            \n            .easy-date-picker {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-select {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-input {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-autocomplete {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-button {\n              margin: 8px;\n              text-transform: uppercase;\n            }\n            \n            .input-icon {\n              font-size: 24px;\n              height: 24px;\n              width: 24px;\n            }\n            \n            .full-width {\n              width: 100vw;\n            }"]
            },] },
];
EasyFormContentComponent.propDecorators = {
    "container": [{ type: Input },],
};
var EasyFormContentActionsComponent = /** @class */ (function () {
    function EasyFormContentActionsComponent() {
    }
    EasyFormContentActionsComponent.prototype.click = function (action) {
        action();
    };
    return EasyFormContentActionsComponent;
}());
EasyFormContentActionsComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-form-content-actions',
                template: "<div fxLayout=\"row wrap\" fxLayoutAlign=\"end\">\n              <div *ngFor=\"let action of actions\">\n                  <easy-button [key]=\"action.key\" *ngIf=\"!action.hide\" [icon]=\"action.icon\" [color]=\"action.color\" [displayValue]=\"action.label\" [type]='action.type'\n                    [showLoader]=\"action.showLoader\" (onClicked)=\"click(action.action)\"></easy-button>\n              </div>\n            </div>",
                styles: [".checkbox-group-container {\n              display: flex;\n              flex-direction: column;\n              margin-top: 20px;\n            }\n            \n            .checkbox-group {\n              display: flex;\n              flex-direction: column;\n              padding-left: 20px;\n            }\n            \n            .easy-checkbox {\n              margin-top: 100px;\n            }\n            \n            .button-row {\n              display: flex;\n              align-items: right;\n              justify-content: flex-end;\n            }\n            \n            .easy-date-picker {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-select {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-input {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-autocomplete {\n              margin-top: 20px;\n              width: 100%;\n            }\n            \n            .easy-button {\n              margin: 8px;\n              text-transform: uppercase;\n            }\n            \n            .input-icon {\n              font-size: 24px;\n              height: 24px;\n              width: 24px;\n            }\n            \n            .full-width {\n              width: 100vw;\n            }"]
            },] },
];
EasyFormContentActionsComponent.propDecorators = {
    "actions": [{ type: Input },],
};
var EasyDateTimePickerComponent = /** @class */ (function (_super) {
    __extends(EasyDateTimePickerComponent, _super);
    function EasyDateTimePickerComponent(validatorService) {
        var _this = _super.call(this, validatorService) || this;
        _this.fieldValueChange = new EventEmitter();
        _this.hourValue = 0;
        _this.minuteValue = 0;
        _this.amPmValue = 'AM';
        _this.hint = '';
        _this.value = null;
        _this.minuteValid = false;
        _this.hourValid = false;
        _this.dateValid = false;
        _this.timeOfDayItems = ['AM', 'PM'];
        _this.hourValidators = [];
        _this.minuteValidators = [];
        return _this;
    }
    EasyDateTimePickerComponent.prototype.ngOnInit = function () {
        this.hourValidators.add(EasyValidator.Pattern("^([1-9]|1[012])$", "Hour not valid"));
        this.minuteValidators.add(EasyValidator.Pattern("^([0-5]?[0-9]|60)$", "Minute not valid"));
        if (this.validators.any(function (x) { return x.validatorType == ValidatorType.required; })) {
            this.hourValidators.add(EasyValidator.Required("Hour is required"));
            this.minuteValidators.add(EasyValidator.Required("Minute is required"));
        }
        var date = new Date(this.value);
        var hours = date.getHours();
        this.minuteValue = date.getMinutes();
        if (hours > 12 || hours == 0) {
            this.amPmValue = "PM";
            if (hours == 0)
                this.hourValue = 12;
            else
                this.hourValue = hours - 12;
        }
        else
            this.hourValue = hours;
        _super.prototype.ngOnInit.call(this);
    };
    EasyDateTimePickerComponent.prototype.amPmValueChanged = function (event) {
        this.amPmValue = event.value;
        this.onChange();
    };
    EasyDateTimePickerComponent.prototype.hourValueChanged = function (event) {
        this.hourValue = event.value;
        this.hourValid = event.valid;
        this.onChange();
    };
    EasyDateTimePickerComponent.prototype.minuteValueChanged = function (event) {
        this.minuteValue = event.value;
        this.minuteValid = event.valid;
        this.onChange();
    };
    EasyDateTimePickerComponent.prototype.dateValueChanged = function (event) {
        this.value = event.value;
        this.dateValid = event.valid;
        this.onChange();
    };
    EasyDateTimePickerComponent.prototype.onChange = function () {
        if (!this.hourValue || this.hourValue == null)
            this.hourValue = 0;
        if (!this.minuteValue || this.minuteValue == null)
            this.minuteValue = 0;
        var date = new Date(this.value);
        date.setMinutes(this.minuteValue);
        if (this.amPmValue == 'PM')
            if (this.hourValue == 12)
                date.setHours(0);
            else
                date.setHours(this.hourValue + 12);
        else
            date.setHours(this.hourValue);
        var valid = this.dateValid && this.minuteValid && this.hourValid;
        this.fieldValueChange.emit(new FieldChangeDto(this.key, date, valid));
    };
    EasyDateTimePickerComponent.prototype.ngOnChanges = function (changes) {
        this.dateKey = this.dateKey + "1";
        _super.prototype.ngOnChanges.call(this, changes);
    };
    return EasyDateTimePickerComponent;
}(EasyFormComponent));
EasyDateTimePickerComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-date-time-picker',
                template: "<div fxLayout=\"row wrap\" fxLayoutGap=\"10px\">\n            <easy-date-picker fxFlex=\"47%\" [readonly]=\"readonly\" [placeholder]=\"placeholder\" [hint]=\"hint\" [value]=\"value\" [validators]=\"validators\" (fieldValueChange)=\"dateValueChanged($event)\" [options]=\"options\"></easy-date-picker>\n        <div fxLayout=\"row wrap\" fxFlex=\"47%\" fxLayoutGap=\"10px\">\n            <easy-input fxFlex type=\"number\" [readonly]=\"readonly\" placeholder=\"Hours\" [value]=\"hourValue\" [validators]=\"hourValidators\" (fieldValueChange)=\"hourValueChanged($event)\" [options]=\"options\"></easy-input>\n            <easy-input fxFlex type=\"number\" [readonly]=\"readonly\" placeholder=\"Minutes\" [value]=\"minuteValue\" [validators]=\"minuteValidators\" (fieldValueChange)=\"minuteValueChanged($event)\" [options]=\"options\"></easy-input>\n            <easy-select fxFlex [easy-required]=\"validators\" [readonly]=\"readonly\" [validators]=\"validators\" placeholder=\"\" [selectedValue]=\"amPmValue\" [items]=\"timeOfDayItems\" (fieldValueChange)=\"amPmValueChanged($event)\" [options]=\"options\"></easy-select>\n        </div>\n    </div>\n    "
            },] },
];
EasyDateTimePickerComponent.ctorParameters = function () { return [
    { type: ValidatorService, },
]; };
EasyDateTimePickerComponent.propDecorators = {
    "fieldValueChange": [{ type: Output },],
    "hourValue": [{ type: Input, args: ['hourValue',] },],
    "minuteValue": [{ type: Input, args: ['minuteValue',] },],
    "amPmValue": [{ type: Input, args: ['amPmValue',] },],
    "readonly": [{ type: Input, args: ['readonly',] },],
    "hint": [{ type: Input, args: ['hint',] },],
    "placeholder": [{ type: Input, args: ['placeholder',] },],
    "value": [{ type: Input, args: ['value',] },],
};
var EasyDividerComponent = /** @class */ (function () {
    function EasyDividerComponent() {
    }
    return EasyDividerComponent;
}());
EasyDividerComponent.decorators = [
    { type: Component, args: [{
                selector: 'easy-divider',
                template: "<mat-divider></mat-divider>"
            },] },
];
var EasyModule = /** @class */ (function () {
    function EasyModule() {
    }
    return EasyModule;
}());
EasyModule.decorators = [
    { type: NgModule, args: [{
                entryComponents: [EasyModalDialog],
                imports: [ReactiveFormsModule, PdfViewerModule, EasyMaterialModule, CommonModule, FormsModule, FlexLayoutModule, FileUploadModule],
                declarations: [
                    EasyDatePickerComponent,
                    EasyButtonComponent,
                    EasyFabComponent,
                    EasyFabMobileComponent,
                    EasyInputComponent,
                    EasyRecordComponent,
                    EasyCheckBoxComponent,
                    EasyCheckBoxGroupComponent,
                    EasyAutocompleteComponent,
                    EasyAutocompleteKeyValueComponent,
                    EasyFormComponent$1,
                    EasyFormFieldComponent,
                    EasyTableComponent,
                    EasyModalDialog,
                    SpinnerComponent,
                    EasySelectComponent,
                    EasySelectKeyValueComponent,
                    EasyRadioButtonComponent,
                    EasyFormContentComponent,
                    EasyFormContentActionsComponent,
                    MaxLengthDirective,
                    RequiredDirective,
                    EasyTextAreaComponent,
                    EasyContainerComponent,
                    EasyFileUploadComponent,
                    EasyDateTimePickerComponent,
                    EasyDividerComponent
                ],
                providers: [EasyFormService, EasyNotification, EasyModalService, ValidatorService, FileDownloadService, FileUploadModule, FileUploadOptions],
                exports: [
                    EasyButtonComponent,
                    EasyFabComponent,
                    EasyFabMobileComponent,
                    EasyInputComponent,
                    EasyRecordComponent,
                    EasyCheckBoxComponent,
                    EasyCheckBoxGroupComponent,
                    EasyAutocompleteComponent,
                    EasyAutocompleteKeyValueComponent,
                    EasyFormComponent$1,
                    EasyFormFieldComponent,
                    EasyTableComponent,
                    EasyModalDialog,
                    EasyDatePickerComponent,
                    SpinnerComponent,
                    EasySelectKeyValueComponent,
                    EasyRadioButtonComponent,
                    EasySelectComponent,
                    EasyFormContentComponent,
                    EasyFormContentActionsComponent,
                    MaxLengthDirective,
                    RequiredDirective,
                    EasyTextAreaComponent,
                    EasyContainerComponent,
                    FileUploadModule,
                    PdfViewerModule,
                    EasyDateTimePickerComponent,
                    EasyDividerComponent
                ]
            },] },
];

export { EasyDateTimePickerComponent, CheckboxListItem, EasyFabService, EasyMaterialModule, EasyStepperField, EasyValidator, FileDownloadService, EasyCardField, EasyAccordionField, EasyButtonField, EasyToolbarTextField, EasyDatePickerField, EasyExpansionPanelField, EasyFileUploadField, EasyRadioButtonField, EasySelectField, EasySelectKeyValueField, EasyTabField, EasyTableField, EasyTextAreaField, EasyDividerField, EasyField, EasyForm, ButtonTypes, Colors, ColumnTypes, DateFormats, FieldWithSameKeyAlreadyExistsException, FieldWithKeyDoesNotExistException, MultipleFieldsWithSameKeyExistException, FieldOptions, FieldChangeDto, FileUploadOptions, Icons, InputTypes, KeyValue, SelectOption, TableFieldOptions, TextAlign, EasyButtonComponent, EasyModalDialog, EasyModule, EasyNotification, EasyFormService, EasyModalService, EasyContainer, ModalContainer, EasyAutocompleteKeyValueComponent as ɵm, EasyAutocompleteComponent as ɵl, EasyCheckBoxGroupComponent as ɵa, EasyCheckBoxComponent as ɵk, EasyDatePickerComponent as ɵf, EasyDividerComponent as ɵbb, EasyFileUploadComponent as ɵba, EasyInputComponent as ɵi, EasyRadioButtonComponent as ɵt, EasyRecordComponent as ɵj, EasySelectKeyValueComponent as ɵs, EasySelectComponent as ɵr, SpinnerComponent as ɵq, EasyTableComponent as ɵp, EasyTextAreaComponent as ɵy, EasyContainerComponent as ɵz, EasyFabMobileComponent as ɵh, EasyFabComponent as ɵg, EasyFormContentActionsComponent as ɵv, EasyFormContentComponent as ɵu, EasyFormFieldComponent as ɵo, EasyFormComponent$1 as ɵn, MaxLengthDirective as ɵw, RequiredDirective as ɵx, ContainerValidation as ɵd, EasyFieldValidator as ɵe, EasyFormComponent as ɵc, ValidatorService as ɵb };
//# sourceMappingURL=easy-suite.js.map
